package androidx.appcompat.widget;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.view.View;
import android.view.ViewGroup;
import android.view.accessibility.AccessibilityEvent;
import android.view.accessibility.AccessibilityNodeInfo;
import android.widget.LinearLayout;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RestrictTo;
import androidx.appcompat.R;
import androidx.constraintlayout.solver.widgets.analyzer.BasicMeasure;
import androidx.core.view.GravityCompat;
import androidx.core.view.InputDeviceCompat;
import androidx.core.view.ViewCompat;
import com.google.android.material.badge.BadgeDrawable;
import d.b.a.a.a;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

public class LinearLayoutCompat extends ViewGroup {
    private static final String ACCESSIBILITY_CLASS_NAME = "androidx.appcompat.widget.LinearLayoutCompat";
    public static final int HORIZONTAL = 0;
    private static final int INDEX_BOTTOM = 2;
    private static final int INDEX_CENTER_VERTICAL = 0;
    private static final int INDEX_FILL = 3;
    private static final int INDEX_TOP = 1;
    public static final int SHOW_DIVIDER_BEGINNING = 1;
    public static final int SHOW_DIVIDER_END = 4;
    public static final int SHOW_DIVIDER_MIDDLE = 2;
    public static final int SHOW_DIVIDER_NONE = 0;
    public static final int VERTICAL = 1;
    private static final int VERTICAL_GRAVITY_COUNT = 4;
    private boolean mBaselineAligned;
    private int mBaselineAlignedChildIndex;
    private int mBaselineChildTop;
    private Drawable mDivider;
    private int mDividerHeight;
    private int mDividerPadding;
    private int mDividerWidth;
    private int mGravity;
    private int[] mMaxAscent;
    private int[] mMaxDescent;
    private int mOrientation;
    private int mShowDividers;
    private int mTotalLength;
    private boolean mUseLargestChild;
    private float mWeightSum;

    @Retention(RetentionPolicy.SOURCE)
    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public @interface DividerMode {
    }

    public static class LayoutParams extends LinearLayout.LayoutParams {
        public LayoutParams(Context context, AttributeSet attributeSet) {
            super(context, attributeSet);
        }

        public LayoutParams(int i2, int i3) {
            super(i2, i3);
        }

        public LayoutParams(int i2, int i3, float f2) {
            super(i2, i3, f2);
        }

        public LayoutParams(ViewGroup.LayoutParams layoutParams) {
            super(layoutParams);
        }

        public LayoutParams(ViewGroup.MarginLayoutParams marginLayoutParams) {
            super(marginLayoutParams);
        }
    }

    @Retention(RetentionPolicy.SOURCE)
    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public @interface OrientationMode {
    }

    public LinearLayoutCompat(@NonNull Context context) {
        this(context, null);
    }

    private void forceUniformHeight(int i2, int i3) {
        int makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(getMeasuredHeight(), BasicMeasure.EXACTLY);
        for (int i4 = 0; i4 < i2; i4++) {
            View virtualChildAt = getVirtualChildAt(i4);
            if (virtualChildAt.getVisibility() != 8) {
                LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                if (((LinearLayout.LayoutParams) layoutParams).height == -1) {
                    int i5 = ((LinearLayout.LayoutParams) layoutParams).width;
                    ((LinearLayout.LayoutParams) layoutParams).width = virtualChildAt.getMeasuredWidth();
                    measureChildWithMargins(virtualChildAt, i3, 0, makeMeasureSpec, 0);
                    ((LinearLayout.LayoutParams) layoutParams).width = i5;
                }
            }
        }
    }

    private void forceUniformWidth(int i2, int i3) {
        int makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(getMeasuredWidth(), BasicMeasure.EXACTLY);
        for (int i4 = 0; i4 < i2; i4++) {
            View virtualChildAt = getVirtualChildAt(i4);
            if (virtualChildAt.getVisibility() != 8) {
                LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                if (((LinearLayout.LayoutParams) layoutParams).width == -1) {
                    int i5 = ((LinearLayout.LayoutParams) layoutParams).height;
                    ((LinearLayout.LayoutParams) layoutParams).height = virtualChildAt.getMeasuredHeight();
                    measureChildWithMargins(virtualChildAt, makeMeasureSpec, 0, i3, 0);
                    ((LinearLayout.LayoutParams) layoutParams).height = i5;
                }
            }
        }
    }

    private void setChildFrame(View view, int i2, int i3, int i4, int i5) {
        view.layout(i2, i3, i4 + i2, i5 + i3);
    }

    public boolean checkLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return layoutParams instanceof LayoutParams;
    }

    public void drawDividersHorizontal(Canvas canvas) {
        int i2;
        int i3;
        int i4;
        int i5;
        int virtualChildCount = getVirtualChildCount();
        boolean isLayoutRtl = ViewUtils.isLayoutRtl(this);
        for (int i6 = 0; i6 < virtualChildCount; i6++) {
            View virtualChildAt = getVirtualChildAt(i6);
            if (!(virtualChildAt == null || virtualChildAt.getVisibility() == 8 || !hasDividerBeforeChildAt(i6))) {
                LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                if (isLayoutRtl) {
                    i5 = virtualChildAt.getRight() + ((LinearLayout.LayoutParams) layoutParams).rightMargin;
                } else {
                    i5 = (virtualChildAt.getLeft() - ((LinearLayout.LayoutParams) layoutParams).leftMargin) - this.mDividerWidth;
                }
                drawVerticalDivider(canvas, i5);
            }
        }
        if (hasDividerBeforeChildAt(virtualChildCount)) {
            View virtualChildAt2 = getVirtualChildAt(virtualChildCount - 1);
            if (virtualChildAt2 != null) {
                LayoutParams layoutParams2 = (LayoutParams) virtualChildAt2.getLayoutParams();
                if (isLayoutRtl) {
                    i4 = virtualChildAt2.getLeft() - ((LinearLayout.LayoutParams) layoutParams2).leftMargin;
                    i3 = this.mDividerWidth;
                } else {
                    i2 = virtualChildAt2.getRight() + ((LinearLayout.LayoutParams) layoutParams2).rightMargin;
                    drawVerticalDivider(canvas, i2);
                }
            } else if (isLayoutRtl) {
                i2 = getPaddingLeft();
                drawVerticalDivider(canvas, i2);
            } else {
                i4 = getWidth() - getPaddingRight();
                i3 = this.mDividerWidth;
            }
            i2 = i4 - i3;
            drawVerticalDivider(canvas, i2);
        }
    }

    public void drawDividersVertical(Canvas canvas) {
        int i2;
        int virtualChildCount = getVirtualChildCount();
        for (int i3 = 0; i3 < virtualChildCount; i3++) {
            View virtualChildAt = getVirtualChildAt(i3);
            if (!(virtualChildAt == null || virtualChildAt.getVisibility() == 8 || !hasDividerBeforeChildAt(i3))) {
                drawHorizontalDivider(canvas, (virtualChildAt.getTop() - ((LinearLayout.LayoutParams) ((LayoutParams) virtualChildAt.getLayoutParams())).topMargin) - this.mDividerHeight);
            }
        }
        if (hasDividerBeforeChildAt(virtualChildCount)) {
            View virtualChildAt2 = getVirtualChildAt(virtualChildCount - 1);
            if (virtualChildAt2 == null) {
                i2 = (getHeight() - getPaddingBottom()) - this.mDividerHeight;
            } else {
                i2 = virtualChildAt2.getBottom() + ((LinearLayout.LayoutParams) ((LayoutParams) virtualChildAt2.getLayoutParams())).bottomMargin;
            }
            drawHorizontalDivider(canvas, i2);
        }
    }

    public void drawHorizontalDivider(Canvas canvas, int i2) {
        this.mDivider.setBounds(getPaddingLeft() + this.mDividerPadding, i2, (getWidth() - getPaddingRight()) - this.mDividerPadding, this.mDividerHeight + i2);
        this.mDivider.draw(canvas);
    }

    public void drawVerticalDivider(Canvas canvas, int i2) {
        this.mDivider.setBounds(i2, getPaddingTop() + this.mDividerPadding, this.mDividerWidth + i2, (getHeight() - getPaddingBottom()) - this.mDividerPadding);
        this.mDivider.draw(canvas);
    }

    public int getBaseline() {
        int i2;
        if (this.mBaselineAlignedChildIndex < 0) {
            return super.getBaseline();
        }
        int childCount = getChildCount();
        int i3 = this.mBaselineAlignedChildIndex;
        if (childCount > i3) {
            View childAt = getChildAt(i3);
            int baseline = childAt.getBaseline();
            if (baseline != -1) {
                int i4 = this.mBaselineChildTop;
                if (this.mOrientation == 1 && (i2 = this.mGravity & 112) != 48) {
                    if (i2 == 16) {
                        i4 += ((((getBottom() - getTop()) - getPaddingTop()) - getPaddingBottom()) - this.mTotalLength) / 2;
                    } else if (i2 == 80) {
                        i4 = ((getBottom() - getTop()) - getPaddingBottom()) - this.mTotalLength;
                    }
                }
                return i4 + ((LinearLayout.LayoutParams) ((LayoutParams) childAt.getLayoutParams())).topMargin + baseline;
            } else if (this.mBaselineAlignedChildIndex == 0) {
                return -1;
            } else {
                throw new RuntimeException("mBaselineAlignedChildIndex of LinearLayout points to a View that doesn't know how to get its baseline.");
            }
        } else {
            throw new RuntimeException("mBaselineAlignedChildIndex of LinearLayout set to an index that is out of bounds.");
        }
    }

    public int getBaselineAlignedChildIndex() {
        return this.mBaselineAlignedChildIndex;
    }

    public int getChildrenSkipCount(View view, int i2) {
        return 0;
    }

    public Drawable getDividerDrawable() {
        return this.mDivider;
    }

    public int getDividerPadding() {
        return this.mDividerPadding;
    }

    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public int getDividerWidth() {
        return this.mDividerWidth;
    }

    public int getGravity() {
        return this.mGravity;
    }

    public int getLocationOffset(View view) {
        return 0;
    }

    public int getNextLocationOffset(View view) {
        return 0;
    }

    public int getOrientation() {
        return this.mOrientation;
    }

    public int getShowDividers() {
        return this.mShowDividers;
    }

    public View getVirtualChildAt(int i2) {
        return getChildAt(i2);
    }

    public int getVirtualChildCount() {
        return getChildCount();
    }

    public float getWeightSum() {
        return this.mWeightSum;
    }

    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public boolean hasDividerBeforeChildAt(int i2) {
        if (i2 == 0) {
            return (this.mShowDividers & 1) != 0;
        }
        if (i2 == getChildCount()) {
            if ((this.mShowDividers & 4) != 0) {
                return true;
            }
            return false;
        } else if ((this.mShowDividers & 2) == 0) {
            return false;
        } else {
            for (int i3 = i2 - 1; i3 >= 0; i3--) {
                if (getChildAt(i3).getVisibility() != 8) {
                    return true;
                }
            }
            return false;
        }
    }

    public boolean isBaselineAligned() {
        return this.mBaselineAligned;
    }

    public boolean isMeasureWithLargestChildEnabled() {
        return this.mUseLargestChild;
    }

    /* JADX WARNING: Removed duplicated region for block: B:27:0x00a8  */
    /* JADX WARNING: Removed duplicated region for block: B:30:0x00b1  */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x00e6  */
    /* JADX WARNING: Removed duplicated region for block: B:45:0x00fa  */
    public void layoutHorizontal(int i2, int i3, int i4, int i5) {
        int i6;
        int i7;
        int i8;
        int i9;
        int i10;
        int i11;
        int i12;
        int i13;
        int i14;
        int i15;
        boolean isLayoutRtl = ViewUtils.isLayoutRtl(this);
        int paddingTop = getPaddingTop();
        int i16 = i5 - i3;
        int paddingBottom = i16 - getPaddingBottom();
        int paddingBottom2 = (i16 - paddingTop) - getPaddingBottom();
        int virtualChildCount = getVirtualChildCount();
        int i17 = this.mGravity;
        int i18 = i17 & 112;
        boolean z = this.mBaselineAligned;
        int[] iArr = this.mMaxAscent;
        int[] iArr2 = this.mMaxDescent;
        int absoluteGravity = GravityCompat.getAbsoluteGravity(8388615 & i17, ViewCompat.getLayoutDirection(this));
        if (absoluteGravity == 1) {
            i6 = getPaddingLeft() + (((i4 - i2) - this.mTotalLength) / 2);
        } else if (absoluteGravity != 5) {
            i6 = getPaddingLeft();
        } else {
            i6 = ((getPaddingLeft() + i4) - i2) - this.mTotalLength;
        }
        if (isLayoutRtl) {
            i8 = virtualChildCount - 1;
            i7 = -1;
        } else {
            i8 = 0;
            i7 = 1;
        }
        int i19 = 0;
        while (i19 < virtualChildCount) {
            int i20 = (i7 * i19) + i8;
            View virtualChildAt = getVirtualChildAt(i20);
            if (virtualChildAt == null) {
                i6 = measureNullChild(i20) + i6;
            } else if (virtualChildAt.getVisibility() != 8) {
                int measuredWidth = virtualChildAt.getMeasuredWidth();
                int measuredHeight = virtualChildAt.getMeasuredHeight();
                LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                if (z) {
                    i11 = virtualChildCount;
                    if (((LinearLayout.LayoutParams) layoutParams).height != -1) {
                        i12 = virtualChildAt.getBaseline();
                        i13 = ((LinearLayout.LayoutParams) layoutParams).gravity;
                        if (i13 < 0) {
                            i13 = i18;
                        }
                        i14 = i13 & 112;
                        i10 = i18;
                        if (i14 != 16) {
                            i15 = ((((paddingBottom2 - measuredHeight) / 2) + paddingTop) + ((LinearLayout.LayoutParams) layoutParams).topMargin) - ((LinearLayout.LayoutParams) layoutParams).bottomMargin;
                        } else if (i14 == 48) {
                            i15 = ((LinearLayout.LayoutParams) layoutParams).topMargin + paddingTop;
                            if (i12 != -1) {
                                i15 = (iArr[1] - i12) + i15;
                            }
                        } else if (i14 != 80) {
                            i15 = paddingTop;
                        } else {
                            i15 = (paddingBottom - measuredHeight) - ((LinearLayout.LayoutParams) layoutParams).bottomMargin;
                            if (i12 != -1) {
                                i15 -= iArr2[2] - (virtualChildAt.getMeasuredHeight() - i12);
                            }
                        }
                        if (hasDividerBeforeChildAt(i20)) {
                            i6 += this.mDividerWidth;
                        }
                        int i21 = ((LinearLayout.LayoutParams) layoutParams).leftMargin + i6;
                        i9 = paddingTop;
                        setChildFrame(virtualChildAt, getLocationOffset(virtualChildAt) + i21, i15, measuredWidth, measuredHeight);
                        i6 = getNextLocationOffset(virtualChildAt) + measuredWidth + ((LinearLayout.LayoutParams) layoutParams).rightMargin + i21;
                        i19 = getChildrenSkipCount(virtualChildAt, i20) + i19;
                        i19++;
                        virtualChildCount = i11;
                        i18 = i10;
                        paddingTop = i9;
                    }
                } else {
                    i11 = virtualChildCount;
                }
                i12 = -1;
                i13 = ((LinearLayout.LayoutParams) layoutParams).gravity;
                if (i13 < 0) {
                }
                i14 = i13 & 112;
                i10 = i18;
                if (i14 != 16) {
                }
                if (hasDividerBeforeChildAt(i20)) {
                }
                int i212 = ((LinearLayout.LayoutParams) layoutParams).leftMargin + i6;
                i9 = paddingTop;
                setChildFrame(virtualChildAt, getLocationOffset(virtualChildAt) + i212, i15, measuredWidth, measuredHeight);
                i6 = getNextLocationOffset(virtualChildAt) + measuredWidth + ((LinearLayout.LayoutParams) layoutParams).rightMargin + i212;
                i19 = getChildrenSkipCount(virtualChildAt, i20) + i19;
                i19++;
                virtualChildCount = i11;
                i18 = i10;
                paddingTop = i9;
            }
            i9 = paddingTop;
            i11 = virtualChildCount;
            i10 = i18;
            i19++;
            virtualChildCount = i11;
            i18 = i10;
            paddingTop = i9;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:27:0x00a0  */
    public void layoutVertical(int i2, int i3, int i4, int i5) {
        int i6;
        int i7;
        int i8;
        int i9;
        int paddingLeft = getPaddingLeft();
        int i10 = i4 - i2;
        int paddingRight = i10 - getPaddingRight();
        int paddingRight2 = (i10 - paddingLeft) - getPaddingRight();
        int virtualChildCount = getVirtualChildCount();
        int i11 = this.mGravity;
        int i12 = i11 & 112;
        int i13 = i11 & GravityCompat.RELATIVE_HORIZONTAL_GRAVITY_MASK;
        if (i12 == 16) {
            i6 = getPaddingTop() + (((i5 - i3) - this.mTotalLength) / 2);
        } else if (i12 != 80) {
            i6 = getPaddingTop();
        } else {
            i6 = ((getPaddingTop() + i5) - i3) - this.mTotalLength;
        }
        int i14 = 0;
        while (i14 < virtualChildCount) {
            View virtualChildAt = getVirtualChildAt(i14);
            if (virtualChildAt == null) {
                i6 = measureNullChild(i14) + i6;
            } else if (virtualChildAt.getVisibility() != 8) {
                int measuredWidth = virtualChildAt.getMeasuredWidth();
                int measuredHeight = virtualChildAt.getMeasuredHeight();
                LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                int i15 = ((LinearLayout.LayoutParams) layoutParams).gravity;
                if (i15 < 0) {
                    i15 = i13;
                }
                int absoluteGravity = GravityCompat.getAbsoluteGravity(i15, ViewCompat.getLayoutDirection(this)) & 7;
                if (absoluteGravity == 1) {
                    i9 = ((paddingRight2 - measuredWidth) / 2) + paddingLeft + ((LinearLayout.LayoutParams) layoutParams).leftMargin;
                    i8 = ((LinearLayout.LayoutParams) layoutParams).rightMargin;
                } else if (absoluteGravity != 5) {
                    i7 = ((LinearLayout.LayoutParams) layoutParams).leftMargin + paddingLeft;
                    if (hasDividerBeforeChildAt(i14)) {
                        i6 += this.mDividerHeight;
                    }
                    int i16 = i6 + ((LinearLayout.LayoutParams) layoutParams).topMargin;
                    setChildFrame(virtualChildAt, i7, getLocationOffset(virtualChildAt) + i16, measuredWidth, measuredHeight);
                    i6 = getNextLocationOffset(virtualChildAt) + measuredHeight + ((LinearLayout.LayoutParams) layoutParams).bottomMargin + i16;
                    i14 += getChildrenSkipCount(virtualChildAt, i14);
                } else {
                    i9 = paddingRight - measuredWidth;
                    i8 = ((LinearLayout.LayoutParams) layoutParams).rightMargin;
                }
                i7 = i9 - i8;
                if (hasDividerBeforeChildAt(i14)) {
                }
                int i162 = i6 + ((LinearLayout.LayoutParams) layoutParams).topMargin;
                setChildFrame(virtualChildAt, i7, getLocationOffset(virtualChildAt) + i162, measuredWidth, measuredHeight);
                i6 = getNextLocationOffset(virtualChildAt) + measuredHeight + ((LinearLayout.LayoutParams) layoutParams).bottomMargin + i162;
                i14 += getChildrenSkipCount(virtualChildAt, i14);
            }
            i14++;
        }
    }

    public void measureChildBeforeLayout(View view, int i2, int i3, int i4, int i5, int i6) {
        measureChildWithMargins(view, i3, i4, i5, i6);
    }

    /* JADX WARNING: Removed duplicated region for block: B:186:0x044e  */
    /* JADX WARNING: Removed duplicated region for block: B:65:0x0195  */
    /* JADX WARNING: Removed duplicated region for block: B:75:0x01c9  */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x01d4  */
    public void measureHorizontal(int i2, int i3) {
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        int i10;
        int i11;
        int i12;
        float f2;
        int i13;
        boolean z;
        int baseline;
        int i14;
        int i15;
        int i16;
        boolean z2;
        boolean z3;
        int i17;
        int i18;
        View view;
        int i19;
        boolean z4;
        int measuredHeight;
        int baseline2;
        int i20;
        int i21;
        this.mTotalLength = 0;
        int virtualChildCount = getVirtualChildCount();
        int mode = View.MeasureSpec.getMode(i2);
        int mode2 = View.MeasureSpec.getMode(i3);
        if (this.mMaxAscent == null || this.mMaxDescent == null) {
            this.mMaxAscent = new int[4];
            this.mMaxDescent = new int[4];
        }
        int[] iArr = this.mMaxAscent;
        int[] iArr2 = this.mMaxDescent;
        iArr[3] = -1;
        iArr[2] = -1;
        iArr[1] = -1;
        iArr[0] = -1;
        iArr2[3] = -1;
        iArr2[2] = -1;
        iArr2[1] = -1;
        iArr2[0] = -1;
        boolean z5 = this.mBaselineAligned;
        boolean z6 = this.mUseLargestChild;
        int i22 = BasicMeasure.EXACTLY;
        boolean z7 = mode == 1073741824;
        float f3 = 0.0f;
        int i23 = 0;
        int i24 = 0;
        int i25 = 0;
        int i26 = 0;
        int i27 = 0;
        boolean z8 = false;
        int i28 = 0;
        boolean z9 = true;
        boolean z10 = false;
        while (i23 < virtualChildCount) {
            View virtualChildAt = getVirtualChildAt(i23);
            if (virtualChildAt == null) {
                this.mTotalLength = measureNullChild(i23) + this.mTotalLength;
            } else if (virtualChildAt.getVisibility() == 8) {
                i23 += getChildrenSkipCount(virtualChildAt, i23);
            } else {
                if (hasDividerBeforeChildAt(i23)) {
                    this.mTotalLength += this.mDividerWidth;
                }
                LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                float f4 = ((LinearLayout.LayoutParams) layoutParams).weight;
                float f5 = f3 + f4;
                if (mode == i22 && ((LinearLayout.LayoutParams) layoutParams).width == 0 && f4 > 0.0f) {
                    if (z7) {
                        this.mTotalLength = ((LinearLayout.LayoutParams) layoutParams).leftMargin + ((LinearLayout.LayoutParams) layoutParams).rightMargin + this.mTotalLength;
                    } else {
                        int i29 = this.mTotalLength;
                        this.mTotalLength = Math.max(i29, ((LinearLayout.LayoutParams) layoutParams).leftMargin + i29 + ((LinearLayout.LayoutParams) layoutParams).rightMargin);
                    }
                    if (z5) {
                        int makeMeasureSpec = View.MeasureSpec.makeMeasureSpec(0, 0);
                        virtualChildAt.measure(makeMeasureSpec, makeMeasureSpec);
                        i18 = i23;
                        z3 = z6;
                        z2 = z5;
                        view = virtualChildAt;
                    } else {
                        i18 = i23;
                        z3 = z6;
                        z2 = z5;
                        view = virtualChildAt;
                        i19 = BasicMeasure.EXACTLY;
                        z8 = true;
                        if (mode2 == i19 && ((LinearLayout.LayoutParams) layoutParams).height == -1) {
                            z4 = true;
                            z10 = true;
                        } else {
                            z4 = false;
                        }
                        int i30 = ((LinearLayout.LayoutParams) layoutParams).topMargin + ((LinearLayout.LayoutParams) layoutParams).bottomMargin;
                        measuredHeight = view.getMeasuredHeight() + i30;
                        i28 = View.combineMeasuredStates(i28, view.getMeasuredState());
                        if (z2 && (baseline2 = view.getBaseline()) != -1) {
                            i20 = ((LinearLayout.LayoutParams) layoutParams).gravity;
                            if (i20 < 0) {
                                i20 = this.mGravity;
                            }
                            int i31 = (((i20 & 112) >> 4) & -2) >> 1;
                            iArr[i31] = Math.max(iArr[i31], baseline2);
                            iArr2[i31] = Math.max(iArr2[i31], measuredHeight - baseline2);
                        }
                        i25 = Math.max(i25, measuredHeight);
                        z9 = !z9 && ((LinearLayout.LayoutParams) layoutParams).height == -1;
                        if (((LinearLayout.LayoutParams) layoutParams).weight <= 0.0f) {
                            if (!z4) {
                                i30 = measuredHeight;
                            }
                            i27 = Math.max(i27, i30);
                        } else {
                            if (!z4) {
                                i30 = measuredHeight;
                            }
                            i26 = Math.max(i26, i30);
                            i27 = i27;
                        }
                        i17 = getChildrenSkipCount(view, i18) + i18;
                        f3 = f5;
                        i23 = i17 + 1;
                        iArr2 = iArr2;
                        z6 = z3;
                        z5 = z2;
                        i22 = BasicMeasure.EXACTLY;
                    }
                } else {
                    if (((LinearLayout.LayoutParams) layoutParams).width != 0 || f4 <= 0.0f) {
                        i21 = Integer.MIN_VALUE;
                    } else {
                        ((LinearLayout.LayoutParams) layoutParams).width = -2;
                        i21 = 0;
                    }
                    i18 = i23;
                    z3 = z6;
                    z2 = z5;
                    measureChildBeforeLayout(virtualChildAt, i18, i2, f5 == 0.0f ? this.mTotalLength : 0, i3, 0);
                    if (i21 != Integer.MIN_VALUE) {
                        ((LinearLayout.LayoutParams) layoutParams).width = i21;
                    }
                    int measuredWidth = virtualChildAt.getMeasuredWidth();
                    if (z7) {
                        view = virtualChildAt;
                        this.mTotalLength = getNextLocationOffset(view) + ((LinearLayout.LayoutParams) layoutParams).leftMargin + measuredWidth + ((LinearLayout.LayoutParams) layoutParams).rightMargin + this.mTotalLength;
                    } else {
                        view = virtualChildAt;
                        int i32 = this.mTotalLength;
                        this.mTotalLength = Math.max(i32, getNextLocationOffset(view) + i32 + measuredWidth + ((LinearLayout.LayoutParams) layoutParams).leftMargin + ((LinearLayout.LayoutParams) layoutParams).rightMargin);
                    }
                    if (z3) {
                        i24 = Math.max(measuredWidth, i24);
                    }
                }
                i19 = BasicMeasure.EXACTLY;
                if (mode2 == i19) {
                }
                z4 = false;
                int i302 = ((LinearLayout.LayoutParams) layoutParams).topMargin + ((LinearLayout.LayoutParams) layoutParams).bottomMargin;
                measuredHeight = view.getMeasuredHeight() + i302;
                i28 = View.combineMeasuredStates(i28, view.getMeasuredState());
                i20 = ((LinearLayout.LayoutParams) layoutParams).gravity;
                if (i20 < 0) {
                }
                int i312 = (((i20 & 112) >> 4) & -2) >> 1;
                iArr[i312] = Math.max(iArr[i312], baseline2);
                iArr2[i312] = Math.max(iArr2[i312], measuredHeight - baseline2);
                i25 = Math.max(i25, measuredHeight);
                if (!z9) {
                }
                if (((LinearLayout.LayoutParams) layoutParams).weight <= 0.0f) {
                }
                i17 = getChildrenSkipCount(view, i18) + i18;
                f3 = f5;
                i23 = i17 + 1;
                iArr2 = iArr2;
                z6 = z3;
                z5 = z2;
                i22 = BasicMeasure.EXACTLY;
            }
            i17 = i23;
            z3 = z6;
            z2 = z5;
            i23 = i17 + 1;
            iArr2 = iArr2;
            z6 = z3;
            z5 = z2;
            i22 = BasicMeasure.EXACTLY;
        }
        if (this.mTotalLength > 0 && hasDividerBeforeChildAt(virtualChildCount)) {
            this.mTotalLength += this.mDividerWidth;
        }
        if (iArr[1] == -1 && iArr[0] == -1 && iArr[2] == -1 && iArr[3] == -1) {
            i5 = i25;
            i4 = i28;
        } else {
            i4 = i28;
            i5 = Math.max(i25, Math.max(iArr2[3], Math.max(iArr2[0], Math.max(iArr2[1], iArr2[2]))) + Math.max(iArr[3], Math.max(iArr[0], Math.max(iArr[1], iArr[2]))));
        }
        if (z6 && (mode == Integer.MIN_VALUE || mode == 0)) {
            this.mTotalLength = 0;
            int i33 = 0;
            while (i33 < virtualChildCount) {
                View virtualChildAt2 = getVirtualChildAt(i33);
                if (virtualChildAt2 == null) {
                    this.mTotalLength = measureNullChild(i33) + this.mTotalLength;
                } else if (virtualChildAt2.getVisibility() == 8) {
                    i33 += getChildrenSkipCount(virtualChildAt2, i33);
                } else {
                    LayoutParams layoutParams2 = (LayoutParams) virtualChildAt2.getLayoutParams();
                    if (z7) {
                        this.mTotalLength = getNextLocationOffset(virtualChildAt2) + ((LinearLayout.LayoutParams) layoutParams2).leftMargin + i24 + ((LinearLayout.LayoutParams) layoutParams2).rightMargin + this.mTotalLength;
                    } else {
                        int i34 = this.mTotalLength;
                        i16 = i5;
                        this.mTotalLength = Math.max(i34, getNextLocationOffset(virtualChildAt2) + i34 + i24 + ((LinearLayout.LayoutParams) layoutParams2).leftMargin + ((LinearLayout.LayoutParams) layoutParams2).rightMargin);
                        i33++;
                        i5 = i16;
                    }
                }
                i16 = i5;
                i33++;
                i5 = i16;
            }
        }
        int paddingRight = getPaddingRight() + getPaddingLeft() + this.mTotalLength;
        this.mTotalLength = paddingRight;
        int resolveSizeAndState = View.resolveSizeAndState(Math.max(paddingRight, getSuggestedMinimumWidth()), i2, 0);
        int i35 = (16777215 & resolveSizeAndState) - this.mTotalLength;
        if (z8 || (i35 != 0 && f3 > 0.0f)) {
            float f6 = this.mWeightSum;
            if (f6 > 0.0f) {
                f3 = f6;
            }
            iArr[3] = -1;
            iArr[2] = -1;
            iArr[1] = -1;
            iArr[0] = -1;
            iArr2[3] = -1;
            iArr2[2] = -1;
            iArr2[1] = -1;
            iArr2[0] = -1;
            this.mTotalLength = 0;
            int i36 = i26;
            int i37 = i4;
            int i38 = -1;
            int i39 = 0;
            while (i39 < virtualChildCount) {
                View virtualChildAt3 = getVirtualChildAt(i39);
                if (virtualChildAt3 == null || virtualChildAt3.getVisibility() == 8) {
                    i12 = i35;
                    i11 = virtualChildCount;
                } else {
                    LayoutParams layoutParams3 = (LayoutParams) virtualChildAt3.getLayoutParams();
                    float f7 = ((LinearLayout.LayoutParams) layoutParams3).weight;
                    if (f7 > 0.0f) {
                        int i40 = (int) ((((float) i35) * f7) / f3);
                        float f8 = f3 - f7;
                        int i41 = i35 - i40;
                        i11 = virtualChildCount;
                        int childMeasureSpec = ViewGroup.getChildMeasureSpec(i3, getPaddingBottom() + getPaddingTop() + ((LinearLayout.LayoutParams) layoutParams3).topMargin + ((LinearLayout.LayoutParams) layoutParams3).bottomMargin, ((LinearLayout.LayoutParams) layoutParams3).height);
                        if (((LinearLayout.LayoutParams) layoutParams3).width == 0) {
                            i15 = BasicMeasure.EXACTLY;
                            if (mode == 1073741824) {
                                if (i40 <= 0) {
                                    i40 = 0;
                                }
                                virtualChildAt3.measure(View.MeasureSpec.makeMeasureSpec(i40, BasicMeasure.EXACTLY), childMeasureSpec);
                                i37 = View.combineMeasuredStates(i37, virtualChildAt3.getMeasuredState() & ViewCompat.MEASURED_STATE_MASK);
                                f3 = f8;
                                i12 = i41;
                            }
                        } else {
                            i15 = BasicMeasure.EXACTLY;
                        }
                        int measuredWidth2 = virtualChildAt3.getMeasuredWidth() + i40;
                        if (measuredWidth2 < 0) {
                            measuredWidth2 = 0;
                        }
                        virtualChildAt3.measure(View.MeasureSpec.makeMeasureSpec(measuredWidth2, i15), childMeasureSpec);
                        i37 = View.combineMeasuredStates(i37, virtualChildAt3.getMeasuredState() & ViewCompat.MEASURED_STATE_MASK);
                        f3 = f8;
                        i12 = i41;
                    } else {
                        i12 = i35;
                        i11 = virtualChildCount;
                    }
                    if (z7) {
                        this.mTotalLength = getNextLocationOffset(virtualChildAt3) + virtualChildAt3.getMeasuredWidth() + ((LinearLayout.LayoutParams) layoutParams3).leftMargin + ((LinearLayout.LayoutParams) layoutParams3).rightMargin + this.mTotalLength;
                        f2 = f3;
                    } else {
                        int i42 = this.mTotalLength;
                        f2 = f3;
                        this.mTotalLength = Math.max(i42, getNextLocationOffset(virtualChildAt3) + virtualChildAt3.getMeasuredWidth() + i42 + ((LinearLayout.LayoutParams) layoutParams3).leftMargin + ((LinearLayout.LayoutParams) layoutParams3).rightMargin);
                    }
                    boolean z11 = mode2 != 1073741824 && ((LinearLayout.LayoutParams) layoutParams3).height == -1;
                    int i43 = ((LinearLayout.LayoutParams) layoutParams3).topMargin + ((LinearLayout.LayoutParams) layoutParams3).bottomMargin;
                    int measuredHeight2 = virtualChildAt3.getMeasuredHeight() + i43;
                    i38 = Math.max(i38, measuredHeight2);
                    if (!z11) {
                        i43 = measuredHeight2;
                    }
                    int max = Math.max(i36, i43);
                    if (z9) {
                        i13 = -1;
                        if (((LinearLayout.LayoutParams) layoutParams3).height == -1) {
                            z = true;
                            if (z5 && (baseline = virtualChildAt3.getBaseline()) != i13) {
                                i14 = ((LinearLayout.LayoutParams) layoutParams3).gravity;
                                if (i14 < 0) {
                                    i14 = this.mGravity;
                                }
                                int i44 = (((i14 & 112) >> 4) & -2) >> 1;
                                iArr[i44] = Math.max(iArr[i44], baseline);
                                iArr2[i44] = Math.max(iArr2[i44], measuredHeight2 - baseline);
                            }
                            z9 = z;
                            i36 = max;
                            f3 = f2;
                        }
                    } else {
                        i13 = -1;
                    }
                    z = false;
                    i14 = ((LinearLayout.LayoutParams) layoutParams3).gravity;
                    if (i14 < 0) {
                    }
                    int i442 = (((i14 & 112) >> 4) & -2) >> 1;
                    iArr[i442] = Math.max(iArr[i442], baseline);
                    iArr2[i442] = Math.max(iArr2[i442], measuredHeight2 - baseline);
                    z9 = z;
                    i36 = max;
                    f3 = f2;
                }
                i39++;
                i35 = i12;
                virtualChildCount = i11;
            }
            i8 = i3;
            i6 = virtualChildCount;
            this.mTotalLength = getPaddingRight() + getPaddingLeft() + this.mTotalLength;
            if (iArr[1] == -1 && iArr[0] == -1 && iArr[2] == -1 && iArr[3] == -1) {
                i10 = i38;
            } else {
                i10 = Math.max(i38, Math.max(iArr2[3], Math.max(iArr2[0], Math.max(iArr2[1], iArr2[2]))) + Math.max(iArr[3], Math.max(iArr[0], Math.max(iArr[1], iArr[2]))));
            }
            i7 = i10;
            i9 = i36;
            i4 = i37;
        } else {
            i9 = Math.max(i26, i27);
            if (z6 && mode != 1073741824) {
                for (int i45 = 0; i45 < virtualChildCount; i45++) {
                    View virtualChildAt4 = getVirtualChildAt(i45);
                    if (!(virtualChildAt4 == null || virtualChildAt4.getVisibility() == 8 || ((LinearLayout.LayoutParams) ((LayoutParams) virtualChildAt4.getLayoutParams())).weight <= 0.0f)) {
                        virtualChildAt4.measure(View.MeasureSpec.makeMeasureSpec(i24, BasicMeasure.EXACTLY), View.MeasureSpec.makeMeasureSpec(virtualChildAt4.getMeasuredHeight(), BasicMeasure.EXACTLY));
                    }
                }
            }
            i8 = i3;
            i6 = virtualChildCount;
            i7 = i5;
        }
        if (z9 || mode2 == 1073741824) {
            i9 = i7;
        }
        setMeasuredDimension(resolveSizeAndState | (i4 & ViewCompat.MEASURED_STATE_MASK), View.resolveSizeAndState(Math.max(getPaddingBottom() + getPaddingTop() + i9, getSuggestedMinimumHeight()), i8, i4 << 16));
        if (z10) {
            forceUniformHeight(i6, i2);
        }
    }

    public int measureNullChild(int i2) {
        return 0;
    }

    /* JADX WARNING: Removed duplicated region for block: B:140:0x0325  */
    public void measureVertical(int i2, int i3) {
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        int i9;
        int i10;
        boolean z;
        int i11;
        int i12;
        int i13;
        int i14;
        int i15;
        int i16;
        int i17;
        int i18;
        View view;
        int i19;
        boolean z2;
        int i20;
        int i21;
        this.mTotalLength = 0;
        int virtualChildCount = getVirtualChildCount();
        int mode = View.MeasureSpec.getMode(i2);
        int mode2 = View.MeasureSpec.getMode(i3);
        int i22 = this.mBaselineAlignedChildIndex;
        boolean z3 = this.mUseLargestChild;
        float f2 = 0.0f;
        int i23 = 0;
        int i24 = 0;
        int i25 = 0;
        int i26 = 0;
        int i27 = 0;
        int i28 = 0;
        boolean z4 = false;
        boolean z5 = true;
        boolean z6 = false;
        while (true) {
            int i29 = 8;
            if (i28 < virtualChildCount) {
                View virtualChildAt = getVirtualChildAt(i28);
                if (virtualChildAt == null) {
                    this.mTotalLength = measureNullChild(i28) + this.mTotalLength;
                    i12 = virtualChildCount;
                    i13 = mode2;
                    i26 = i26;
                } else if (virtualChildAt.getVisibility() == 8) {
                    i28 += getChildrenSkipCount(virtualChildAt, i28);
                    i12 = virtualChildCount;
                    i26 = i26;
                    i23 = i23;
                    i13 = mode2;
                } else {
                    if (hasDividerBeforeChildAt(i28)) {
                        this.mTotalLength += this.mDividerHeight;
                    }
                    LayoutParams layoutParams = (LayoutParams) virtualChildAt.getLayoutParams();
                    float f3 = ((LinearLayout.LayoutParams) layoutParams).weight;
                    float f4 = f2 + f3;
                    if (mode2 == 1073741824 && ((LinearLayout.LayoutParams) layoutParams).height == 0 && f3 > 0.0f) {
                        int i30 = this.mTotalLength;
                        this.mTotalLength = Math.max(i30, ((LinearLayout.LayoutParams) layoutParams).topMargin + i30 + ((LinearLayout.LayoutParams) layoutParams).bottomMargin);
                        i19 = i25;
                        view = virtualChildAt;
                        i14 = i27;
                        i18 = i23;
                        i15 = i24;
                        z4 = true;
                        i12 = virtualChildCount;
                        i13 = mode2;
                        i16 = i26;
                        i17 = i28;
                    } else {
                        if (((LinearLayout.LayoutParams) layoutParams).height != 0 || f3 <= 0.0f) {
                            i21 = Integer.MIN_VALUE;
                        } else {
                            ((LinearLayout.LayoutParams) layoutParams).height = -2;
                            i21 = 0;
                        }
                        i18 = i23;
                        i15 = i24;
                        i12 = virtualChildCount;
                        i13 = mode2;
                        i16 = i26;
                        i14 = i27;
                        i17 = i28;
                        measureChildBeforeLayout(virtualChildAt, i28, i2, 0, i3, f4 == 0.0f ? this.mTotalLength : 0);
                        if (i21 != Integer.MIN_VALUE) {
                            ((LinearLayout.LayoutParams) layoutParams).height = i21;
                        }
                        int measuredHeight = virtualChildAt.getMeasuredHeight();
                        int i31 = this.mTotalLength;
                        view = virtualChildAt;
                        this.mTotalLength = Math.max(i31, getNextLocationOffset(view) + i31 + measuredHeight + ((LinearLayout.LayoutParams) layoutParams).topMargin + ((LinearLayout.LayoutParams) layoutParams).bottomMargin);
                        i19 = z3 ? Math.max(measuredHeight, i25) : i25;
                    }
                    if (i22 >= 0 && i22 == i17 + 1) {
                        this.mBaselineChildTop = this.mTotalLength;
                    }
                    if (i17 >= i22 || ((LinearLayout.LayoutParams) layoutParams).weight <= 0.0f) {
                        if (mode == 1073741824 || ((LinearLayout.LayoutParams) layoutParams).width != -1) {
                            z2 = false;
                        } else {
                            z2 = true;
                            z6 = true;
                        }
                        int i32 = ((LinearLayout.LayoutParams) layoutParams).leftMargin + ((LinearLayout.LayoutParams) layoutParams).rightMargin;
                        int measuredWidth = view.getMeasuredWidth() + i32;
                        int max = Math.max(i15, measuredWidth);
                        int combineMeasuredStates = View.combineMeasuredStates(i18, view.getMeasuredState());
                        z5 = z5 && ((LinearLayout.LayoutParams) layoutParams).width == -1;
                        if (((LinearLayout.LayoutParams) layoutParams).weight > 0.0f) {
                            if (!z2) {
                                i32 = measuredWidth;
                            }
                            i26 = Math.max(i16, i32);
                            i20 = i14;
                        } else {
                            if (!z2) {
                                i32 = measuredWidth;
                            }
                            i20 = Math.max(i14, i32);
                            i26 = i16;
                        }
                        i25 = i19;
                        f2 = f4;
                        i27 = i20;
                        i23 = combineMeasuredStates;
                        i28 = getChildrenSkipCount(view, i17) + i17;
                        i24 = max;
                    } else {
                        throw new RuntimeException("A child of LinearLayout with index less than mBaselineAlignedChildIndex has weight > 0, which won't work.  Either remove the weight, or don't set mBaselineAlignedChildIndex.");
                    }
                }
                i28++;
                mode2 = i13;
                virtualChildCount = i12;
            } else {
                int i33 = i24;
                if (this.mTotalLength > 0) {
                    i4 = virtualChildCount;
                    if (hasDividerBeforeChildAt(i4)) {
                        this.mTotalLength += this.mDividerHeight;
                    }
                } else {
                    i4 = virtualChildCount;
                }
                if (z3 && (mode2 == Integer.MIN_VALUE || mode2 == 0)) {
                    this.mTotalLength = 0;
                    int i34 = 0;
                    while (i34 < i4) {
                        View virtualChildAt2 = getVirtualChildAt(i34);
                        if (virtualChildAt2 == null) {
                            this.mTotalLength = measureNullChild(i34) + this.mTotalLength;
                        } else if (virtualChildAt2.getVisibility() == i29) {
                            i34 += getChildrenSkipCount(virtualChildAt2, i34);
                        } else {
                            LayoutParams layoutParams2 = (LayoutParams) virtualChildAt2.getLayoutParams();
                            int i35 = this.mTotalLength;
                            this.mTotalLength = Math.max(i35, getNextLocationOffset(virtualChildAt2) + i35 + i25 + ((LinearLayout.LayoutParams) layoutParams2).topMargin + ((LinearLayout.LayoutParams) layoutParams2).bottomMargin);
                        }
                        i34++;
                        i29 = 8;
                    }
                }
                int paddingBottom = getPaddingBottom() + getPaddingTop() + this.mTotalLength;
                this.mTotalLength = paddingBottom;
                int resolveSizeAndState = View.resolveSizeAndState(Math.max(paddingBottom, getSuggestedMinimumHeight()), i3, 0);
                int i36 = (16777215 & resolveSizeAndState) - this.mTotalLength;
                if (z4 || (i36 != 0 && f2 > 0.0f)) {
                    float f5 = this.mWeightSum;
                    if (f5 > 0.0f) {
                        f2 = f5;
                    }
                    this.mTotalLength = 0;
                    int i37 = i36;
                    int i38 = i27;
                    i6 = i23;
                    int i39 = 0;
                    while (i39 < i4) {
                        View virtualChildAt3 = getVirtualChildAt(i39);
                        if (virtualChildAt3.getVisibility() == 8) {
                            i8 = i37;
                        } else {
                            LayoutParams layoutParams3 = (LayoutParams) virtualChildAt3.getLayoutParams();
                            float f6 = ((LinearLayout.LayoutParams) layoutParams3).weight;
                            if (f6 > 0.0f) {
                                int i40 = (int) ((((float) i37) * f6) / f2);
                                float f7 = f2 - f6;
                                i8 = i37 - i40;
                                int childMeasureSpec = ViewGroup.getChildMeasureSpec(i2, getPaddingRight() + getPaddingLeft() + ((LinearLayout.LayoutParams) layoutParams3).leftMargin + ((LinearLayout.LayoutParams) layoutParams3).rightMargin, ((LinearLayout.LayoutParams) layoutParams3).width);
                                if (((LinearLayout.LayoutParams) layoutParams3).height == 0) {
                                    i11 = BasicMeasure.EXACTLY;
                                    if (mode2 == 1073741824) {
                                        if (i40 <= 0) {
                                            i40 = 0;
                                        }
                                        virtualChildAt3.measure(childMeasureSpec, View.MeasureSpec.makeMeasureSpec(i40, BasicMeasure.EXACTLY));
                                        i6 = View.combineMeasuredStates(i6, virtualChildAt3.getMeasuredState() & InputDeviceCompat.SOURCE_ANY);
                                        f2 = f7;
                                    }
                                } else {
                                    i11 = BasicMeasure.EXACTLY;
                                }
                                int measuredHeight2 = virtualChildAt3.getMeasuredHeight() + i40;
                                if (measuredHeight2 < 0) {
                                    measuredHeight2 = 0;
                                }
                                virtualChildAt3.measure(childMeasureSpec, View.MeasureSpec.makeMeasureSpec(measuredHeight2, i11));
                                i6 = View.combineMeasuredStates(i6, virtualChildAt3.getMeasuredState() & InputDeviceCompat.SOURCE_ANY);
                                f2 = f7;
                            } else {
                                i8 = i37;
                            }
                            int i41 = ((LinearLayout.LayoutParams) layoutParams3).leftMargin + ((LinearLayout.LayoutParams) layoutParams3).rightMargin;
                            int measuredWidth2 = virtualChildAt3.getMeasuredWidth() + i41;
                            i33 = Math.max(i33, measuredWidth2);
                            if (mode != 1073741824) {
                                i9 = i6;
                                i10 = -1;
                                if (((LinearLayout.LayoutParams) layoutParams3).width == -1) {
                                    z = true;
                                    if (!z) {
                                        i41 = measuredWidth2;
                                    }
                                    int max2 = Math.max(i38, i41);
                                    boolean z7 = !z5 && ((LinearLayout.LayoutParams) layoutParams3).width == i10;
                                    int i42 = this.mTotalLength;
                                    this.mTotalLength = Math.max(i42, getNextLocationOffset(virtualChildAt3) + virtualChildAt3.getMeasuredHeight() + i42 + ((LinearLayout.LayoutParams) layoutParams3).topMargin + ((LinearLayout.LayoutParams) layoutParams3).bottomMargin);
                                    z5 = z7;
                                    i6 = i9;
                                    i38 = max2;
                                    f2 = f2;
                                }
                            } else {
                                i9 = i6;
                                i10 = -1;
                            }
                            z = false;
                            if (!z) {
                            }
                            int max22 = Math.max(i38, i41);
                            if (!z5) {
                            }
                            int i422 = this.mTotalLength;
                            this.mTotalLength = Math.max(i422, getNextLocationOffset(virtualChildAt3) + virtualChildAt3.getMeasuredHeight() + i422 + ((LinearLayout.LayoutParams) layoutParams3).topMargin + ((LinearLayout.LayoutParams) layoutParams3).bottomMargin);
                            z5 = z7;
                            i6 = i9;
                            i38 = max22;
                            f2 = f2;
                        }
                        i39++;
                        i37 = i8;
                    }
                    i5 = i2;
                    this.mTotalLength = getPaddingBottom() + getPaddingTop() + this.mTotalLength;
                    i7 = i38;
                } else {
                    i7 = Math.max(i27, i26);
                    if (z3 && mode2 != 1073741824) {
                        for (int i43 = 0; i43 < i4; i43++) {
                            View virtualChildAt4 = getVirtualChildAt(i43);
                            if (!(virtualChildAt4 == null || virtualChildAt4.getVisibility() == 8 || ((LinearLayout.LayoutParams) ((LayoutParams) virtualChildAt4.getLayoutParams())).weight <= 0.0f)) {
                                virtualChildAt4.measure(View.MeasureSpec.makeMeasureSpec(virtualChildAt4.getMeasuredWidth(), BasicMeasure.EXACTLY), View.MeasureSpec.makeMeasureSpec(i25, BasicMeasure.EXACTLY));
                            }
                        }
                    }
                    i5 = i2;
                    i6 = i23;
                }
                if (z5 || mode == 1073741824) {
                    i7 = i33;
                }
                setMeasuredDimension(View.resolveSizeAndState(Math.max(getPaddingRight() + getPaddingLeft() + i7, getSuggestedMinimumWidth()), i5, i6), resolveSizeAndState);
                if (z6) {
                    forceUniformWidth(i4, i3);
                    return;
                }
                return;
            }
        }
    }

    public void onDraw(Canvas canvas) {
        if (this.mDivider != null) {
            if (this.mOrientation == 1) {
                drawDividersVertical(canvas);
            } else {
                drawDividersHorizontal(canvas);
            }
        }
    }

    public void onInitializeAccessibilityEvent(AccessibilityEvent accessibilityEvent) {
        super.onInitializeAccessibilityEvent(accessibilityEvent);
        accessibilityEvent.setClassName(ACCESSIBILITY_CLASS_NAME);
    }

    public void onInitializeAccessibilityNodeInfo(AccessibilityNodeInfo accessibilityNodeInfo) {
        super.onInitializeAccessibilityNodeInfo(accessibilityNodeInfo);
        accessibilityNodeInfo.setClassName(ACCESSIBILITY_CLASS_NAME);
    }

    public void onLayout(boolean z, int i2, int i3, int i4, int i5) {
        if (this.mOrientation == 1) {
            layoutVertical(i2, i3, i4, i5);
        } else {
            layoutHorizontal(i2, i3, i4, i5);
        }
    }

    public void onMeasure(int i2, int i3) {
        if (this.mOrientation == 1) {
            measureVertical(i2, i3);
        } else {
            measureHorizontal(i2, i3);
        }
    }

    public void setBaselineAligned(boolean z) {
        this.mBaselineAligned = z;
    }

    public void setBaselineAlignedChildIndex(int i2) {
        if (i2 < 0 || i2 >= getChildCount()) {
            StringBuilder n = a.n("base aligned child index out of range (0, ");
            n.append(getChildCount());
            n.append(")");
            throw new IllegalArgumentException(n.toString());
        }
        this.mBaselineAlignedChildIndex = i2;
    }

    public void setDividerDrawable(Drawable drawable) {
        if (drawable != this.mDivider) {
            this.mDivider = drawable;
            boolean z = false;
            if (drawable != null) {
                this.mDividerWidth = drawable.getIntrinsicWidth();
                this.mDividerHeight = drawable.getIntrinsicHeight();
            } else {
                this.mDividerWidth = 0;
                this.mDividerHeight = 0;
            }
            if (drawable == null) {
                z = true;
            }
            setWillNotDraw(z);
            requestLayout();
        }
    }

    public void setDividerPadding(int i2) {
        this.mDividerPadding = i2;
    }

    public void setGravity(int i2) {
        if (this.mGravity != i2) {
            if ((8388615 & i2) == 0) {
                i2 |= GravityCompat.START;
            }
            if ((i2 & 112) == 0) {
                i2 |= 48;
            }
            this.mGravity = i2;
            requestLayout();
        }
    }

    public void setHorizontalGravity(int i2) {
        int i3 = i2 & GravityCompat.RELATIVE_HORIZONTAL_GRAVITY_MASK;
        int i4 = this.mGravity;
        if ((8388615 & i4) != i3) {
            this.mGravity = i3 | (-8388616 & i4);
            requestLayout();
        }
    }

    public void setMeasureWithLargestChildEnabled(boolean z) {
        this.mUseLargestChild = z;
    }

    public void setOrientation(int i2) {
        if (this.mOrientation != i2) {
            this.mOrientation = i2;
            requestLayout();
        }
    }

    public void setShowDividers(int i2) {
        if (i2 != this.mShowDividers) {
            requestLayout();
        }
        this.mShowDividers = i2;
    }

    public void setVerticalGravity(int i2) {
        int i3 = i2 & 112;
        int i4 = this.mGravity;
        if ((i4 & 112) != i3) {
            this.mGravity = i3 | (i4 & -113);
            requestLayout();
        }
    }

    public void setWeightSum(float f2) {
        this.mWeightSum = Math.max(0.0f, f2);
    }

    public boolean shouldDelayChildPressedState() {
        return false;
    }

    public LinearLayoutCompat(@NonNull Context context, @Nullable AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public LayoutParams generateDefaultLayoutParams() {
        int i2 = this.mOrientation;
        if (i2 == 0) {
            return new LayoutParams(-2, -2);
        }
        if (i2 == 1) {
            return new LayoutParams(-1, -2);
        }
        return null;
    }

    public LinearLayoutCompat(@NonNull Context context, @Nullable AttributeSet attributeSet, int i2) {
        super(context, attributeSet, i2);
        this.mBaselineAligned = true;
        this.mBaselineAlignedChildIndex = -1;
        this.mBaselineChildTop = 0;
        this.mGravity = BadgeDrawable.TOP_START;
        int[] iArr = R.styleable.LinearLayoutCompat;
        TintTypedArray obtainStyledAttributes = TintTypedArray.obtainStyledAttributes(context, attributeSet, iArr, i2, 0);
        ViewCompat.saveAttributeDataForStyleable(this, context, iArr, attributeSet, obtainStyledAttributes.getWrappedTypeArray(), i2, 0);
        int i3 = obtainStyledAttributes.getInt(R.styleable.LinearLayoutCompat_android_orientation, -1);
        if (i3 >= 0) {
            setOrientation(i3);
        }
        int i4 = obtainStyledAttributes.getInt(R.styleable.LinearLayoutCompat_android_gravity, -1);
        if (i4 >= 0) {
            setGravity(i4);
        }
        boolean z = obtainStyledAttributes.getBoolean(R.styleable.LinearLayoutCompat_android_baselineAligned, true);
        if (!z) {
            setBaselineAligned(z);
        }
        this.mWeightSum = obtainStyledAttributes.getFloat(R.styleable.LinearLayoutCompat_android_weightSum, -1.0f);
        this.mBaselineAlignedChildIndex = obtainStyledAttributes.getInt(R.styleable.LinearLayoutCompat_android_baselineAlignedChildIndex, -1);
        this.mUseLargestChild = obtainStyledAttributes.getBoolean(R.styleable.LinearLayoutCompat_measureWithLargestChild, false);
        setDividerDrawable(obtainStyledAttributes.getDrawable(R.styleable.LinearLayoutCompat_divider));
        this.mShowDividers = obtainStyledAttributes.getInt(R.styleable.LinearLayoutCompat_showDividers, 0);
        this.mDividerPadding = obtainStyledAttributes.getDimensionPixelSize(R.styleable.LinearLayoutCompat_dividerPadding, 0);
        obtainStyledAttributes.recycle();
    }

    @Override // android.view.ViewGroup
    public LayoutParams generateLayoutParams(AttributeSet attributeSet) {
        return new LayoutParams(getContext(), attributeSet);
    }

    @Override // android.view.ViewGroup
    public LayoutParams generateLayoutParams(ViewGroup.LayoutParams layoutParams) {
        return new LayoutParams(layoutParams);
    }
}
