package androidx.camera.core;

import androidx.annotation.GuardedBy;
import androidx.annotation.Nullable;

public final class ReferenceCountedImageProxy extends ForwardingImageProxy {
    @GuardedBy("this")
    private int mReferenceCount = 1;

    public ReferenceCountedImageProxy(ImageProxy imageProxy) {
        super(imageProxy);
    }

    @Override // androidx.camera.core.ImageProxy, androidx.camera.core.ForwardingImageProxy, java.lang.AutoCloseable
    public synchronized void close() {
        int i2 = this.mReferenceCount;
        if (i2 > 0) {
            int i3 = i2 - 1;
            this.mReferenceCount = i3;
            if (i3 <= 0) {
                super.close();
            }
        }
    }

    @Nullable
    public synchronized ImageProxy fork() {
        int i2 = this.mReferenceCount;
        if (i2 <= 0) {
            return null;
        }
        this.mReferenceCount = i2 + 1;
        return new SingleCloseImageProxy(this);
    }

    public synchronized int getReferenceCount() {
        return this.mReferenceCount;
    }
}
