package androidx.camera.core.impl;

import androidx.annotation.NonNull;
import androidx.camera.core.ImageInfo;
import androidx.camera.core.ImageProxy;
import androidx.camera.core.impl.utils.futures.Futures;
import d.g.b.a.a.a;
import java.util.Collections;
import java.util.List;

public final class SingleImageProxyBundle implements ImageProxyBundle {
    private final int mCaptureId;
    private final ImageProxy mImageProxy;

    public SingleImageProxyBundle(@NonNull ImageProxy imageProxy) {
        ImageInfo imageInfo = imageProxy.getImageInfo();
        if (imageInfo != null) {
            Object tag = imageInfo.getTag();
            if (tag == null) {
                throw new IllegalArgumentException("ImageProxy has no associated tag");
            } else if (tag instanceof Integer) {
                this.mCaptureId = ((Integer) tag).intValue();
                this.mImageProxy = imageProxy;
            } else {
                throw new IllegalArgumentException("ImageProxy has tag that isn't an integer");
            }
        } else {
            throw new IllegalArgumentException("ImageProxy has no associated ImageInfo");
        }
    }

    public void close() {
        this.mImageProxy.close();
    }

    @Override // androidx.camera.core.impl.ImageProxyBundle
    @NonNull
    public List<Integer> getCaptureIds() {
        return Collections.singletonList(Integer.valueOf(this.mCaptureId));
    }

    @Override // androidx.camera.core.impl.ImageProxyBundle
    @NonNull
    public a<ImageProxy> getImageProxy(int i2) {
        if (i2 != this.mCaptureId) {
            return Futures.immediateFailedFuture(new IllegalArgumentException("Capture id does not exist in the bundle"));
        }
        return Futures.immediateFuture(this.mImageProxy);
    }

    public SingleImageProxyBundle(@NonNull ImageProxy imageProxy, int i2) {
        this.mCaptureId = i2;
        this.mImageProxy = imageProxy;
    }
}
