package androidx.camera.core.impl.utils.futures;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.camera.core.impl.utils.executor.CameraXExecutors;
import androidx.concurrent.futures.CallbackToFutureAdapter;
import androidx.core.util.Preconditions;
import d.g.b.a.a.a;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.concurrent.CancellationException;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.Executor;
import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicInteger;

public class ListFuture<V> implements a<List<V>> {
    private final boolean mAllMustSucceed;
    @Nullable
    public List<? extends a<? extends V>> mFutures;
    @NonNull
    private final AtomicInteger mRemaining;
    @NonNull
    private final a<List<V>> mResult = CallbackToFutureAdapter.getFuture(new CallbackToFutureAdapter.Resolver<List<V>>() {
        /* class androidx.camera.core.impl.utils.futures.ListFuture.AnonymousClass1 */

        @Override // androidx.concurrent.futures.CallbackToFutureAdapter.Resolver
        public Object attachCompleter(@NonNull CallbackToFutureAdapter.Completer<List<V>> completer) {
            Preconditions.checkState(ListFuture.this.mResultNotifier == null, "The result can only set once!");
            ListFuture.this.mResultNotifier = completer;
            return "ListFuture[" + this + "]";
        }
    });
    public CallbackToFutureAdapter.Completer<List<V>> mResultNotifier;
    @Nullable
    public List<V> mValues;

    public ListFuture(@NonNull List<? extends a<? extends V>> list, boolean z, @NonNull Executor executor) {
        this.mFutures = (List) Preconditions.checkNotNull(list);
        this.mValues = new ArrayList(list.size());
        this.mAllMustSucceed = z;
        this.mRemaining = new AtomicInteger(list.size());
        init(executor);
    }

    private void callAllGets() {
        List<? extends a<? extends V>> list = this.mFutures;
        if (list != null && !isDone()) {
            Iterator<? extends a<? extends V>> it = list.iterator();
            while (it.hasNext()) {
                a aVar = (a) it.next();
                while (true) {
                    if (!aVar.isDone()) {
                        try {
                            aVar.get();
                        } catch (Error e2) {
                            throw e2;
                        } catch (InterruptedException e3) {
                            throw e3;
                        } catch (Throwable unused) {
                            if (this.mAllMustSucceed) {
                                return;
                            }
                        }
                    }
                }
            }
        }
    }

    private void init(@NonNull Executor executor) {
        addListener(new Runnable() {
            /* class androidx.camera.core.impl.utils.futures.ListFuture.AnonymousClass2 */

            public void run() {
                ListFuture listFuture = ListFuture.this;
                listFuture.mValues = null;
                listFuture.mFutures = null;
            }
        }, CameraXExecutors.directExecutor());
        if (this.mFutures.isEmpty()) {
            this.mResultNotifier.set(new ArrayList(this.mValues));
            return;
        }
        for (int i2 = 0; i2 < this.mFutures.size(); i2++) {
            this.mValues.add(null);
        }
        List<? extends a<? extends V>> list = this.mFutures;
        for (final int i3 = 0; i3 < list.size(); i3++) {
            final a aVar = (a) list.get(i3);
            aVar.addListener(new Runnable() {
                /* class androidx.camera.core.impl.utils.futures.ListFuture.AnonymousClass3 */

                public void run() {
                    ListFuture.this.setOneValue(i3, aVar);
                }
            }, executor);
        }
    }

    @Override // d.g.b.a.a.a
    public void addListener(@NonNull Runnable runnable, @NonNull Executor executor) {
        this.mResult.addListener(runnable, executor);
    }

    public boolean cancel(boolean z) {
        List<? extends a<? extends V>> list = this.mFutures;
        if (list != null) {
            Iterator<? extends a<? extends V>> it = list.iterator();
            while (it.hasNext()) {
                ((a) it.next()).cancel(z);
            }
        }
        return this.mResult.cancel(z);
    }

    public boolean isCancelled() {
        return this.mResult.isCancelled();
    }

    public boolean isDone() {
        return this.mResult.isDone();
    }

    /* JADX DEBUG: Multi-variable search result rejected for r1v0, resolved type: java.util.List<V> */
    /* JADX WARN: Multi-variable type inference failed */
    public void setOneValue(int i2, @NonNull Future<? extends V> future) {
        CallbackToFutureAdapter.Completer<List<V>> completer;
        ArrayList arrayList;
        List<V> list = this.mValues;
        if (isDone() || list == 0) {
            Preconditions.checkState(this.mAllMustSucceed, "Future was done before all dependencies completed");
            return;
        }
        boolean z = true;
        try {
            Preconditions.checkState(future.isDone(), "Tried to set value from future which is not done");
            list.set(i2, Futures.getUninterruptibly(future));
            int decrementAndGet = this.mRemaining.decrementAndGet();
            if (decrementAndGet < 0) {
                z = false;
            }
            Preconditions.checkState(z, "Less than 0 remaining futures");
            if (decrementAndGet == 0) {
                List<V> list2 = this.mValues;
                if (list2 != null) {
                    completer = this.mResultNotifier;
                    arrayList = new ArrayList(list2);
                    completer.set(arrayList);
                    return;
                }
                Preconditions.checkState(isDone());
            }
        } catch (CancellationException unused) {
            if (this.mAllMustSucceed) {
                cancel(false);
            }
            int decrementAndGet2 = this.mRemaining.decrementAndGet();
            if (decrementAndGet2 < 0) {
                z = false;
            }
            Preconditions.checkState(z, "Less than 0 remaining futures");
            if (decrementAndGet2 == 0) {
                List<V> list3 = this.mValues;
                if (list3 != null) {
                    completer = this.mResultNotifier;
                    arrayList = new ArrayList(list3);
                }
            }
        } catch (ExecutionException e2) {
            if (this.mAllMustSucceed) {
                this.mResultNotifier.setException(e2.getCause());
            }
            int decrementAndGet3 = this.mRemaining.decrementAndGet();
            if (decrementAndGet3 < 0) {
                z = false;
            }
            Preconditions.checkState(z, "Less than 0 remaining futures");
            if (decrementAndGet3 == 0) {
                List<V> list4 = this.mValues;
                if (list4 != null) {
                    completer = this.mResultNotifier;
                    arrayList = new ArrayList(list4);
                }
            }
        } catch (RuntimeException e3) {
            if (this.mAllMustSucceed) {
                this.mResultNotifier.setException(e3);
            }
            int decrementAndGet4 = this.mRemaining.decrementAndGet();
            if (decrementAndGet4 < 0) {
                z = false;
            }
            Preconditions.checkState(z, "Less than 0 remaining futures");
            if (decrementAndGet4 == 0) {
                List<V> list5 = this.mValues;
                if (list5 != null) {
                    completer = this.mResultNotifier;
                    arrayList = new ArrayList(list5);
                }
            }
        } catch (Error e4) {
            this.mResultNotifier.setException(e4);
            int decrementAndGet5 = this.mRemaining.decrementAndGet();
            if (decrementAndGet5 < 0) {
                z = false;
            }
            Preconditions.checkState(z, "Less than 0 remaining futures");
            if (decrementAndGet5 == 0) {
                List<V> list6 = this.mValues;
                if (list6 != null) {
                    completer = this.mResultNotifier;
                    arrayList = new ArrayList(list6);
                }
            }
        } catch (Throwable th) {
            int decrementAndGet6 = this.mRemaining.decrementAndGet();
            if (decrementAndGet6 < 0) {
                z = false;
            }
            Preconditions.checkState(z, "Less than 0 remaining futures");
            if (decrementAndGet6 == 0) {
                List<V> list7 = this.mValues;
                if (list7 != null) {
                    this.mResultNotifier.set(new ArrayList(list7));
                } else {
                    Preconditions.checkState(isDone());
                }
            }
            throw th;
        }
    }

    @Override // java.util.concurrent.Future
    @Nullable
    public List<V> get() {
        callAllGets();
        return this.mResult.get();
    }

    @Override // java.util.concurrent.Future
    public List<V> get(long j2, @NonNull TimeUnit timeUnit) {
        return this.mResult.get(j2, timeUnit);
    }
}
