package androidx.camera.view;

import android.graphics.Point;
import android.graphics.PointF;
import android.util.Size;
import android.view.Display;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.camera.core.CameraSelector;
import androidx.camera.core.DisplayOrientedMeteringPointFactory;
import androidx.camera.core.MeteringPoint;
import androidx.camera.core.MeteringPointFactory;
import androidx.camera.view.PreviewView;

public class PreviewViewMeteringPointFactory extends MeteringPointFactory {
    private DisplayOrientedMeteringPointFactory mDisplayOrientedMeteringPointFactory;
    private float mFactoryHeight;
    private float mFactoryWidth;
    private final boolean mIsValid;
    private final PreviewView.ScaleType mScaleType;
    private final float mViewHeight;
    private final float mViewWidth;

    public PreviewViewMeteringPointFactory(@NonNull Display display, @NonNull CameraSelector cameraSelector, @Nullable Size size, @NonNull PreviewView.ScaleType scaleType, int i2, int i3) {
        int i4;
        int i5;
        float f2;
        float f3 = (float) i2;
        this.mViewWidth = f3;
        float f4 = (float) i3;
        this.mViewHeight = f4;
        this.mScaleType = scaleType;
        boolean z = false;
        if (size == null || f3 <= 0.0f || f4 <= 0.0f) {
            this.mIsValid = false;
            return;
        }
        this.mIsValid = true;
        if (!isNaturalPortrait(display) ? display.getRotation() == 1 || display.getRotation() == 3 : display.getRotation() == 0 || display.getRotation() == 2) {
            z = true;
        }
        if (z) {
            i5 = size.getHeight();
            i4 = size.getWidth();
        } else {
            i5 = size.getWidth();
            i4 = size.getHeight();
        }
        if (scaleType == PreviewView.ScaleType.FILL_CENTER || scaleType == PreviewView.ScaleType.FILL_START || scaleType == PreviewView.ScaleType.FILL_END) {
            f2 = Math.max(f3 / ((float) i5), f4 / ((float) i4));
        } else if (scaleType == PreviewView.ScaleType.FIT_START || scaleType == PreviewView.ScaleType.FIT_CENTER || scaleType == PreviewView.ScaleType.FIT_END) {
            f2 = Math.min(f3 / ((float) i5), f4 / ((float) i4));
        } else {
            throw new IllegalArgumentException("Unknown scale type " + scaleType);
        }
        float f5 = ((float) i5) * f2;
        this.mFactoryWidth = f5;
        float f6 = ((float) i4) * f2;
        this.mFactoryHeight = f6;
        this.mDisplayOrientedMeteringPointFactory = new DisplayOrientedMeteringPointFactory(display, cameraSelector, f5, f6);
    }

    private boolean isNaturalPortrait(Display display) {
        Point point = new Point();
        display.getRealSize(point);
        int rotation = display.getRotation();
        int i2 = point.x;
        int i3 = point.y;
        if ((rotation == 0 || rotation == 2) && i2 < i3) {
            return true;
        }
        return (rotation == 1 || rotation == 3) && i2 >= i3;
    }

    @Override // androidx.camera.core.MeteringPointFactory
    @NonNull
    public PointF convertPoint(float f2, float f3) {
        float f4;
        if (!this.mIsValid) {
            return new PointF(2.0f, 2.0f);
        }
        PreviewView.ScaleType scaleType = this.mScaleType;
        float f5 = 0.0f;
        if (!(scaleType == PreviewView.ScaleType.FILL_START || scaleType == PreviewView.ScaleType.FIT_START)) {
            if (scaleType == PreviewView.ScaleType.FILL_CENTER || scaleType == PreviewView.ScaleType.FIT_CENTER) {
                f5 = (this.mFactoryWidth - this.mViewWidth) / 2.0f;
                f4 = (this.mFactoryHeight - this.mViewHeight) / 2.0f;
                float f6 = f3 + f4;
                MeteringPoint createPoint = this.mDisplayOrientedMeteringPointFactory.createPoint(f2 + f5, f6);
                return new PointF(createPoint.getX(), createPoint.getY());
            } else if (scaleType == PreviewView.ScaleType.FILL_END || scaleType == PreviewView.ScaleType.FIT_END) {
                f5 = this.mFactoryWidth - this.mViewWidth;
                f4 = this.mFactoryHeight - this.mViewHeight;
                float f62 = f3 + f4;
                MeteringPoint createPoint2 = this.mDisplayOrientedMeteringPointFactory.createPoint(f2 + f5, f62);
                return new PointF(createPoint2.getX(), createPoint2.getY());
            }
        }
        f4 = 0.0f;
        float f622 = f3 + f4;
        MeteringPoint createPoint22 = this.mDisplayOrientedMeteringPointFactory.createPoint(f2 + f5, f622);
        return new PointF(createPoint22.getX(), createPoint22.getY());
    }
}
