package androidx.camera.view.preview.transform;

import android.graphics.Point;
import android.util.Pair;
import android.util.Size;
import android.view.Display;
import android.view.View;
import androidx.annotation.NonNull;
import androidx.camera.view.preview.transform.transformation.PreviewCorrectionTransformation;

public final class PreviewCorrector {
    private PreviewCorrector() {
    }

    private static Pair<Float, Float> getCorrectionScale(@NonNull View view, @NonNull View view2, @NonNull Size size) {
        int i2;
        int i3;
        if (view.getWidth() == 0 || view.getHeight() == 0 || view2.getWidth() == 0 || view2.getHeight() == 0 || size.getWidth() == 0 || size.getHeight() == 0) {
            return new Pair<>(Float.valueOf(1.0f), Float.valueOf(1.0f));
        }
        if (isNaturalPortrait(view2)) {
            i3 = size.getHeight();
            i2 = size.getWidth();
        } else {
            i3 = size.getWidth();
            i2 = size.getHeight();
        }
        return new Pair<>(Float.valueOf(((float) i3) / ((float) view2.getWidth())), Float.valueOf(((float) i2) / ((float) view2.getHeight())));
    }

    @NonNull
    public static PreviewCorrectionTransformation getCorrectionTransformation(@NonNull View view, @NonNull View view2, @NonNull Size size) {
        Pair<Float, Float> correctionScale = getCorrectionScale(view, view2, size);
        return new PreviewCorrectionTransformation(((Float) correctionScale.first).floatValue(), ((Float) correctionScale.second).floatValue(), (float) (-((int) RotationTransform.getRotationDegrees(view2))));
    }

    private static boolean isNaturalPortrait(@NonNull View view) {
        Display display = view.getDisplay();
        if (display == null) {
            return true;
        }
        Point point = new Point();
        display.getRealSize(point);
        int i2 = point.x;
        int i3 = point.y;
        int rotationDegrees = (int) RotationTransform.getRotationDegrees(view);
        if ((rotationDegrees == 0 || rotationDegrees == 180) && i2 < i3) {
            return true;
        }
        if ((rotationDegrees == 90 || rotationDegrees == 270) && i2 >= i3) {
            return true;
        }
        return false;
    }
}
