package androidx.camera.view.preview.transform;

import android.util.Size;
import android.view.View;
import androidx.annotation.NonNull;
import androidx.annotation.RestrictTo;
import androidx.camera.view.PreviewView;
import androidx.camera.view.preview.transform.transformation.Transformation;

@RestrictTo({RestrictTo.Scope.LIBRARY})
public final class PreviewTransform {
    private static final PreviewView.ScaleType DEFAULT_SCALE_TYPE = PreviewView.ScaleType.FILL_CENTER;
    @NonNull
    private PreviewView.ScaleType mScaleType = DEFAULT_SCALE_TYPE;

    private void applyScaleTypeInternal(@NonNull View view, @NonNull View view2, @NonNull PreviewView.ScaleType scaleType) {
        applyTransformation(view2, Transformation.getTransformation(view2).add(ScaleTypeTransform.getTransformation(view, view2, scaleType)));
    }

    private void applyTransformation(@NonNull View view, @NonNull Transformation transformation) {
        view.setX(0.0f);
        view.setY(0.0f);
        view.setScaleX(transformation.getScaleX());
        view.setScaleY(transformation.getScaleY());
        view.setTranslationX(transformation.getTransX());
        view.setTranslationY(transformation.getTransY());
        view.setRotation(transformation.getRotation());
    }

    private void correctPreview(@NonNull View view, @NonNull View view2, @NonNull Size size) {
        applyTransformation(view2, PreviewCorrector.getCorrectionTransformation(view, view2, size));
    }

    private void resetPreview(@NonNull View view) {
        applyTransformation(view, new Transformation());
    }

    public void applyCurrentScaleType(@NonNull View view, @NonNull View view2, @NonNull Size size) {
        resetPreview(view2);
        correctPreview(view, view2, size);
        applyScaleTypeInternal(view, view2, this.mScaleType);
    }

    @NonNull
    public PreviewView.ScaleType getScaleType() {
        return this.mScaleType;
    }

    public void setScaleType(@NonNull PreviewView.ScaleType scaleType) {
        this.mScaleType = scaleType;
    }
}
