package androidx.constraintlayout.motion.widget;

import android.content.Context;
import android.content.res.Resources;
import android.util.Log;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import com.zhy.view.flowlayout.BuildConfig;
import d.b.a.a.a;
import java.io.PrintStream;
import java.lang.reflect.Field;
import java.lang.reflect.Modifier;

public class Debug {
    public static void dumpLayoutParams(ViewGroup viewGroup, String str) {
        StackTraceElement stackTraceElement = new Throwable().getStackTrace()[1];
        StringBuilder n = a.n(".(");
        n.append(stackTraceElement.getFileName());
        n.append(":");
        n.append(stackTraceElement.getLineNumber());
        n.append(") ");
        n.append(str);
        n.append("  ");
        String sb = n.toString();
        int childCount = viewGroup.getChildCount();
        System.out.println(str + " children " + childCount);
        for (int i2 = 0; i2 < childCount; i2++) {
            View childAt = viewGroup.getChildAt(i2);
            PrintStream printStream = System.out;
            StringBuilder q = a.q(sb, "     ");
            q.append(getName(childAt));
            printStream.println(q.toString());
            ViewGroup.LayoutParams layoutParams = childAt.getLayoutParams();
            Field[] fields = layoutParams.getClass().getFields();
            for (Field field : fields) {
                try {
                    Object obj = field.get(layoutParams);
                    if (field.getName().contains("To")) {
                        if (!obj.toString().equals("-1")) {
                            System.out.println(sb + "       " + field.getName() + " " + obj);
                        }
                    }
                } catch (IllegalAccessException unused) {
                }
            }
        }
    }

    public static void dumpPoc(Object obj) {
        StackTraceElement stackTraceElement = new Throwable().getStackTrace()[1];
        StringBuilder n = a.n(".(");
        n.append(stackTraceElement.getFileName());
        n.append(":");
        n.append(stackTraceElement.getLineNumber());
        n.append(")");
        String sb = n.toString();
        Class<?> cls = obj.getClass();
        PrintStream printStream = System.out;
        StringBuilder q = a.q(sb, "------------- ");
        q.append(cls.getName());
        q.append(" --------------------");
        printStream.println(q.toString());
        Field[] fields = cls.getFields();
        for (Field field : fields) {
            try {
                Object obj2 = field.get(obj);
                if (field.getName().startsWith("layout_constraint")) {
                    if (!(obj2 instanceof Integer) || !obj2.toString().equals("-1")) {
                        if (!(obj2 instanceof Integer) || !obj2.toString().equals("0")) {
                            if (!(obj2 instanceof Float) || !obj2.toString().equals(BuildConfig.VERSION_NAME)) {
                                if (!(obj2 instanceof Float) || !obj2.toString().equals("0.5")) {
                                    System.out.println(sb + "    " + field.getName() + " " + obj2);
                                }
                            }
                        }
                    }
                }
            } catch (IllegalAccessException unused) {
            }
        }
        PrintStream printStream2 = System.out;
        StringBuilder q2 = a.q(sb, "------------- ");
        q2.append(cls.getSimpleName());
        q2.append(" --------------------");
        printStream2.println(q2.toString());
    }

    public static String getActionType(MotionEvent motionEvent) {
        int action = motionEvent.getAction();
        Field[] fields = MotionEvent.class.getFields();
        for (Field field : fields) {
            try {
                if (Modifier.isStatic(field.getModifiers()) && field.getType().equals(Integer.TYPE) && field.getInt(null) == action) {
                    return field.getName();
                }
            } catch (IllegalAccessException unused) {
            }
        }
        return "---";
    }

    public static String getCallFrom(int i2) {
        StackTraceElement stackTraceElement = new Throwable().getStackTrace()[i2 + 2];
        StringBuilder n = a.n(".(");
        n.append(stackTraceElement.getFileName());
        n.append(":");
        n.append(stackTraceElement.getLineNumber());
        n.append(")");
        return n.toString();
    }

    public static String getLoc() {
        StackTraceElement stackTraceElement = new Throwable().getStackTrace()[1];
        StringBuilder n = a.n(".(");
        n.append(stackTraceElement.getFileName());
        n.append(":");
        n.append(stackTraceElement.getLineNumber());
        n.append(") ");
        n.append(stackTraceElement.getMethodName());
        n.append("()");
        return n.toString();
    }

    public static String getLocation() {
        StackTraceElement stackTraceElement = new Throwable().getStackTrace()[1];
        StringBuilder n = a.n(".(");
        n.append(stackTraceElement.getFileName());
        n.append(":");
        n.append(stackTraceElement.getLineNumber());
        n.append(")");
        return n.toString();
    }

    public static String getLocation2() {
        StackTraceElement stackTraceElement = new Throwable().getStackTrace()[2];
        StringBuilder n = a.n(".(");
        n.append(stackTraceElement.getFileName());
        n.append(":");
        n.append(stackTraceElement.getLineNumber());
        n.append(")");
        return n.toString();
    }

    public static String getName(View view) {
        try {
            return view.getContext().getResources().getResourceEntryName(view.getId());
        } catch (Exception unused) {
            return "UNKNOWN";
        }
    }

    public static String getState(MotionLayout motionLayout, int i2) {
        if (i2 == -1) {
            return "UNDEFINED";
        }
        return motionLayout.getContext().getResources().getResourceEntryName(i2);
    }

    public static void logStack(String str, String str2, int i2) {
        StackTraceElement[] stackTrace = new Throwable().getStackTrace();
        int min = Math.min(i2, stackTrace.length - 1);
        String str3 = " ";
        for (int i3 = 1; i3 <= min; i3++) {
            StackTraceElement stackTraceElement = stackTrace[i3];
            StringBuilder n = a.n(".(");
            n.append(stackTrace[i3].getFileName());
            n.append(":");
            n.append(stackTrace[i3].getLineNumber());
            n.append(") ");
            n.append(stackTrace[i3].getMethodName());
            String sb = n.toString();
            str3 = a.g(str3, " ");
            Log.v(str, str2 + str3 + sb + str3);
        }
    }

    public static void printStack(String str, int i2) {
        StackTraceElement[] stackTrace = new Throwable().getStackTrace();
        int min = Math.min(i2, stackTrace.length - 1);
        String str2 = " ";
        for (int i3 = 1; i3 <= min; i3++) {
            StackTraceElement stackTraceElement = stackTrace[i3];
            StringBuilder n = a.n(".(");
            n.append(stackTrace[i3].getFileName());
            n.append(":");
            n.append(stackTrace[i3].getLineNumber());
            n.append(") ");
            String sb = n.toString();
            str2 = a.g(str2, " ");
            PrintStream printStream = System.out;
            printStream.println(str + str2 + sb + str2);
        }
    }

    public static String getName(Context context, int i2) {
        if (i2 == -1) {
            return "UNKNOWN";
        }
        try {
            return context.getResources().getResourceEntryName(i2);
        } catch (Exception unused) {
            return a.x("?", i2);
        }
    }

    public static String getName(Context context, int[] iArr) {
        String str;
        try {
            String str2 = iArr.length + "[";
            int i2 = 0;
            while (i2 < iArr.length) {
                StringBuilder sb = new StringBuilder();
                sb.append(str2);
                sb.append(i2 == 0 ? "" : " ");
                String sb2 = sb.toString();
                try {
                    str = context.getResources().getResourceEntryName(iArr[i2]);
                } catch (Resources.NotFoundException unused) {
                    str = "? " + iArr[i2] + " ";
                }
                str2 = sb2 + str;
                i2++;
            }
            return str2 + "]";
        } catch (Exception e2) {
            Log.v("DEBUG", e2.toString());
            return "UNKNOWN";
        }
    }

    public static void dumpLayoutParams(ViewGroup.LayoutParams layoutParams, String str) {
        StackTraceElement stackTraceElement = new Throwable().getStackTrace()[1];
        StringBuilder n = a.n(".(");
        n.append(stackTraceElement.getFileName());
        n.append(":");
        n.append(stackTraceElement.getLineNumber());
        n.append(") ");
        n.append(str);
        n.append("  ");
        String sb = n.toString();
        PrintStream printStream = System.out;
        StringBuilder r = a.r(" >>>>>>>>>>>>>>>>>>. dump ", sb, "  ");
        r.append(layoutParams.getClass().getName());
        printStream.println(r.toString());
        Field[] fields = layoutParams.getClass().getFields();
        for (Field field : fields) {
            try {
                Object obj = field.get(layoutParams);
                String name = field.getName();
                if (name.contains("To")) {
                    if (!obj.toString().equals("-1")) {
                        System.out.println(sb + "       " + name + " " + obj);
                    }
                }
            } catch (IllegalAccessException unused) {
            }
        }
        System.out.println(" <<<<<<<<<<<<<<<<< dump " + sb);
    }
}
