package androidx.constraintlayout.solver.widgets;

import androidx.constraintlayout.solver.LinearSystem;
import androidx.constraintlayout.solver.widgets.ConstraintWidget;
import java.util.ArrayList;
import java.util.HashMap;

public class Flow extends VirtualLayout {
    public static final int HORIZONTAL_ALIGN_CENTER = 2;
    public static final int HORIZONTAL_ALIGN_END = 1;
    public static final int HORIZONTAL_ALIGN_START = 0;
    public static final int VERTICAL_ALIGN_BASELINE = 3;
    public static final int VERTICAL_ALIGN_BOTTOM = 1;
    public static final int VERTICAL_ALIGN_CENTER = 2;
    public static final int VERTICAL_ALIGN_TOP = 0;
    public static final int WRAP_ALIGNED = 2;
    public static final int WRAP_CHAIN = 1;
    public static final int WRAP_NONE = 0;
    private ConstraintWidget[] mAlignedBiggestElementsInCols = null;
    private ConstraintWidget[] mAlignedBiggestElementsInRows = null;
    private int[] mAlignedDimensions = null;
    private ArrayList<WidgetsList> mChainList = new ArrayList<>();
    private ConstraintWidget[] mDisplayedWidgets;
    private int mDisplayedWidgetsCount = 0;
    private float mFirstHorizontalBias = 0.5f;
    private int mFirstHorizontalStyle = -1;
    private float mFirstVerticalBias = 0.5f;
    private int mFirstVerticalStyle = -1;
    private int mHorizontalAlign = 2;
    private float mHorizontalBias = 0.5f;
    private int mHorizontalGap = 0;
    private int mHorizontalStyle = -1;
    private float mLastHorizontalBias = 0.5f;
    private int mLastHorizontalStyle = -1;
    private float mLastVerticalBias = 0.5f;
    private int mLastVerticalStyle = -1;
    private int mMaxElementsWrap = -1;
    private int mOrientation = 0;
    private int mVerticalAlign = 2;
    private float mVerticalBias = 0.5f;
    private int mVerticalGap = 0;
    private int mVerticalStyle = -1;
    private int mWrapMode = 0;

    public class WidgetsList {
        private ConstraintWidget biggest = null;
        public int biggestDimension = 0;
        private ConstraintAnchor mBottom;
        private int mCount = 0;
        private int mHeight = 0;
        private ConstraintAnchor mLeft;
        private int mMax = 0;
        private int mNbMatchConstraintsWidgets = 0;
        private int mOrientation = 0;
        private int mPaddingBottom = 0;
        private int mPaddingLeft = 0;
        private int mPaddingRight = 0;
        private int mPaddingTop = 0;
        private ConstraintAnchor mRight;
        private int mStartIndex = 0;
        private ConstraintAnchor mTop;
        private int mWidth = 0;

        public WidgetsList(int i2, ConstraintAnchor constraintAnchor, ConstraintAnchor constraintAnchor2, ConstraintAnchor constraintAnchor3, ConstraintAnchor constraintAnchor4, int i3) {
            this.mOrientation = i2;
            this.mLeft = constraintAnchor;
            this.mTop = constraintAnchor2;
            this.mRight = constraintAnchor3;
            this.mBottom = constraintAnchor4;
            this.mPaddingLeft = Flow.this.getPaddingLeft();
            this.mPaddingTop = Flow.this.getPaddingTop();
            this.mPaddingRight = Flow.this.getPaddingRight();
            this.mPaddingBottom = Flow.this.getPaddingBottom();
            this.mMax = i3;
        }

        private void recomputeDimensions() {
            this.mWidth = 0;
            this.mHeight = 0;
            this.biggest = null;
            this.biggestDimension = 0;
            int i2 = this.mCount;
            int i3 = 0;
            while (i3 < i2 && this.mStartIndex + i3 < Flow.this.mDisplayedWidgetsCount) {
                ConstraintWidget constraintWidget = Flow.this.mDisplayedWidgets[this.mStartIndex + i3];
                if (this.mOrientation == 0) {
                    int width = constraintWidget.getWidth();
                    int i4 = Flow.this.mHorizontalGap;
                    if (constraintWidget.getVisibility() == 8) {
                        i4 = 0;
                    }
                    this.mWidth = width + i4 + this.mWidth;
                    int widgetHeight = Flow.this.getWidgetHeight(constraintWidget, this.mMax);
                    if (this.biggest == null || this.biggestDimension < widgetHeight) {
                        this.biggest = constraintWidget;
                        this.biggestDimension = widgetHeight;
                        this.mHeight = widgetHeight;
                    }
                } else {
                    int widgetWidth = Flow.this.getWidgetWidth(constraintWidget, this.mMax);
                    int widgetHeight2 = Flow.this.getWidgetHeight(constraintWidget, this.mMax);
                    int i5 = Flow.this.mVerticalGap;
                    if (constraintWidget.getVisibility() == 8) {
                        i5 = 0;
                    }
                    this.mHeight = widgetHeight2 + i5 + this.mHeight;
                    if (this.biggest == null || this.biggestDimension < widgetWidth) {
                        this.biggest = constraintWidget;
                        this.biggestDimension = widgetWidth;
                        this.mWidth = widgetWidth;
                    }
                }
                i3++;
            }
        }

        public void add(ConstraintWidget constraintWidget) {
            int i2 = 0;
            if (this.mOrientation == 0) {
                int widgetWidth = Flow.this.getWidgetWidth(constraintWidget, this.mMax);
                if (constraintWidget.getHorizontalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                    this.mNbMatchConstraintsWidgets++;
                    widgetWidth = 0;
                }
                int i3 = Flow.this.mHorizontalGap;
                if (constraintWidget.getVisibility() != 8) {
                    i2 = i3;
                }
                this.mWidth = widgetWidth + i2 + this.mWidth;
                int widgetHeight = Flow.this.getWidgetHeight(constraintWidget, this.mMax);
                if (this.biggest == null || this.biggestDimension < widgetHeight) {
                    this.biggest = constraintWidget;
                    this.biggestDimension = widgetHeight;
                    this.mHeight = widgetHeight;
                }
            } else {
                int widgetWidth2 = Flow.this.getWidgetWidth(constraintWidget, this.mMax);
                int widgetHeight2 = Flow.this.getWidgetHeight(constraintWidget, this.mMax);
                if (constraintWidget.getVerticalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                    this.mNbMatchConstraintsWidgets++;
                    widgetHeight2 = 0;
                }
                int i4 = Flow.this.mVerticalGap;
                if (constraintWidget.getVisibility() != 8) {
                    i2 = i4;
                }
                this.mHeight = widgetHeight2 + i2 + this.mHeight;
                if (this.biggest == null || this.biggestDimension < widgetWidth2) {
                    this.biggest = constraintWidget;
                    this.biggestDimension = widgetWidth2;
                    this.mWidth = widgetWidth2;
                }
            }
            this.mCount++;
        }

        public void clear() {
            this.biggestDimension = 0;
            this.biggest = null;
            this.mWidth = 0;
            this.mHeight = 0;
            this.mStartIndex = 0;
            this.mCount = 0;
            this.mNbMatchConstraintsWidgets = 0;
        }

        /* JADX WARNING: Removed duplicated region for block: B:55:0x00df  */
        public void createConstraints(boolean z, int i2, boolean z2) {
            ConstraintWidget constraintWidget;
            int i3;
            int i4 = this.mCount;
            int i5 = 0;
            while (i5 < i4 && this.mStartIndex + i5 < Flow.this.mDisplayedWidgetsCount) {
                ConstraintWidget constraintWidget2 = Flow.this.mDisplayedWidgets[this.mStartIndex + i5];
                if (constraintWidget2 != null) {
                    constraintWidget2.resetAnchors();
                }
                i5++;
            }
            if (!(i4 == 0 || this.biggest == null)) {
                boolean z3 = z2 && i2 == 0;
                int i6 = -1;
                int i7 = -1;
                for (int i8 = 0; i8 < i4; i8++) {
                    int i9 = z ? (i4 - 1) - i8 : i8;
                    if (this.mStartIndex + i9 >= Flow.this.mDisplayedWidgetsCount) {
                        break;
                    }
                    if (Flow.this.mDisplayedWidgets[this.mStartIndex + i9].getVisibility() == 0) {
                        if (i6 == -1) {
                            i6 = i8;
                        }
                        i7 = i8;
                    }
                }
                ConstraintWidget constraintWidget3 = null;
                if (this.mOrientation == 0) {
                    ConstraintWidget constraintWidget4 = this.biggest;
                    constraintWidget4.setVerticalChainStyle(Flow.this.mVerticalStyle);
                    int i10 = this.mPaddingTop;
                    if (i2 > 0) {
                        i10 += Flow.this.mVerticalGap;
                    }
                    constraintWidget4.mTop.connect(this.mTop, i10);
                    if (z2) {
                        constraintWidget4.mBottom.connect(this.mBottom, this.mPaddingBottom);
                    }
                    if (i2 > 0) {
                        this.mTop.mOwner.mBottom.connect(constraintWidget4.mTop, 0);
                    }
                    if (Flow.this.mVerticalAlign == 3 && !constraintWidget4.hasBaseline()) {
                        int i11 = 0;
                        while (true) {
                            if (i11 >= i4) {
                                break;
                            }
                            int i12 = z ? (i4 - 1) - i11 : i11;
                            if (this.mStartIndex + i12 >= Flow.this.mDisplayedWidgetsCount) {
                                break;
                            }
                            constraintWidget = Flow.this.mDisplayedWidgets[this.mStartIndex + i12];
                            if (constraintWidget.hasBaseline()) {
                                break;
                            }
                            i11++;
                        }
                        i3 = 0;
                        while (i3 < i4) {
                            int i13 = z ? (i4 - 1) - i3 : i3;
                            if (this.mStartIndex + i13 < Flow.this.mDisplayedWidgetsCount) {
                                ConstraintWidget constraintWidget5 = Flow.this.mDisplayedWidgets[this.mStartIndex + i13];
                                if (i3 == 0) {
                                    constraintWidget5.connect(constraintWidget5.mLeft, this.mLeft, this.mPaddingLeft);
                                }
                                if (i13 == 0) {
                                    int i14 = Flow.this.mHorizontalStyle;
                                    float f2 = Flow.this.mHorizontalBias;
                                    if (this.mStartIndex == 0 && Flow.this.mFirstHorizontalStyle != -1) {
                                        i14 = Flow.this.mFirstHorizontalStyle;
                                        f2 = Flow.this.mFirstHorizontalBias;
                                    } else if (z2 && Flow.this.mLastHorizontalStyle != -1) {
                                        i14 = Flow.this.mLastHorizontalStyle;
                                        f2 = Flow.this.mLastHorizontalBias;
                                    }
                                    constraintWidget5.setHorizontalChainStyle(i14);
                                    constraintWidget5.setHorizontalBiasPercent(f2);
                                }
                                if (i3 == i4 - 1) {
                                    constraintWidget5.connect(constraintWidget5.mRight, this.mRight, this.mPaddingRight);
                                }
                                if (constraintWidget3 != null) {
                                    constraintWidget5.mLeft.connect(constraintWidget3.mRight, Flow.this.mHorizontalGap);
                                    if (i3 == i6) {
                                        constraintWidget5.mLeft.setGoneMargin(this.mPaddingLeft);
                                    }
                                    constraintWidget3.mRight.connect(constraintWidget5.mLeft, 0);
                                    if (i3 == i7 + 1) {
                                        constraintWidget3.mRight.setGoneMargin(this.mPaddingRight);
                                    }
                                }
                                if (constraintWidget5 != constraintWidget4) {
                                    if (Flow.this.mVerticalAlign != 3 || !constraintWidget.hasBaseline() || constraintWidget5 == constraintWidget || !constraintWidget5.hasBaseline()) {
                                        int i15 = Flow.this.mVerticalAlign;
                                        if (i15 == 0) {
                                            constraintWidget5.mTop.connect(constraintWidget4.mTop, 0);
                                        } else if (i15 == 1) {
                                            constraintWidget5.mBottom.connect(constraintWidget4.mBottom, 0);
                                        } else if (z3) {
                                            constraintWidget5.mTop.connect(this.mTop, this.mPaddingTop);
                                            constraintWidget5.mBottom.connect(this.mBottom, this.mPaddingBottom);
                                        } else {
                                            constraintWidget5.mTop.connect(constraintWidget4.mTop, 0);
                                            constraintWidget5.mBottom.connect(constraintWidget4.mBottom, 0);
                                        }
                                    } else {
                                        constraintWidget5.mBaseline.connect(constraintWidget.mBaseline, 0);
                                    }
                                }
                                i3++;
                                constraintWidget3 = constraintWidget5;
                            } else {
                                return;
                            }
                        }
                        return;
                    }
                    constraintWidget = constraintWidget4;
                    i3 = 0;
                    while (i3 < i4) {
                    }
                    return;
                }
                ConstraintWidget constraintWidget6 = this.biggest;
                constraintWidget6.setHorizontalChainStyle(Flow.this.mHorizontalStyle);
                int i16 = this.mPaddingLeft;
                if (i2 > 0) {
                    i16 += Flow.this.mHorizontalGap;
                }
                if (z) {
                    constraintWidget6.mRight.connect(this.mRight, i16);
                    if (z2) {
                        constraintWidget6.mLeft.connect(this.mLeft, this.mPaddingRight);
                    }
                    if (i2 > 0) {
                        this.mRight.mOwner.mLeft.connect(constraintWidget6.mRight, 0);
                    }
                } else {
                    constraintWidget6.mLeft.connect(this.mLeft, i16);
                    if (z2) {
                        constraintWidget6.mRight.connect(this.mRight, this.mPaddingRight);
                    }
                    if (i2 > 0) {
                        this.mLeft.mOwner.mRight.connect(constraintWidget6.mLeft, 0);
                    }
                }
                int i17 = 0;
                while (i17 < i4 && this.mStartIndex + i17 < Flow.this.mDisplayedWidgetsCount) {
                    ConstraintWidget constraintWidget7 = Flow.this.mDisplayedWidgets[this.mStartIndex + i17];
                    if (i17 == 0) {
                        constraintWidget7.connect(constraintWidget7.mTop, this.mTop, this.mPaddingTop);
                        int i18 = Flow.this.mVerticalStyle;
                        float f3 = Flow.this.mVerticalBias;
                        if (this.mStartIndex == 0 && Flow.this.mFirstVerticalStyle != -1) {
                            i18 = Flow.this.mFirstVerticalStyle;
                            f3 = Flow.this.mFirstVerticalBias;
                        } else if (z2 && Flow.this.mLastVerticalStyle != -1) {
                            i18 = Flow.this.mLastVerticalStyle;
                            f3 = Flow.this.mLastVerticalBias;
                        }
                        constraintWidget7.setVerticalChainStyle(i18);
                        constraintWidget7.setVerticalBiasPercent(f3);
                    }
                    if (i17 == i4 - 1) {
                        constraintWidget7.connect(constraintWidget7.mBottom, this.mBottom, this.mPaddingBottom);
                    }
                    if (constraintWidget3 != null) {
                        constraintWidget7.mTop.connect(constraintWidget3.mBottom, Flow.this.mVerticalGap);
                        if (i17 == i6) {
                            constraintWidget7.mTop.setGoneMargin(this.mPaddingTop);
                        }
                        constraintWidget3.mBottom.connect(constraintWidget7.mTop, 0);
                        if (i17 == i7 + 1) {
                            constraintWidget3.mBottom.setGoneMargin(this.mPaddingBottom);
                        }
                    }
                    if (constraintWidget7 != constraintWidget6) {
                        if (z) {
                            int i19 = Flow.this.mHorizontalAlign;
                            if (i19 == 0) {
                                constraintWidget7.mRight.connect(constraintWidget6.mRight, 0);
                            } else if (i19 == 1) {
                                constraintWidget7.mLeft.connect(constraintWidget6.mLeft, 0);
                            } else if (i19 == 2) {
                                constraintWidget7.mLeft.connect(constraintWidget6.mLeft, 0);
                                constraintWidget7.mRight.connect(constraintWidget6.mRight, 0);
                            }
                        } else {
                            int i20 = Flow.this.mHorizontalAlign;
                            if (i20 == 0) {
                                constraintWidget7.mLeft.connect(constraintWidget6.mLeft, 0);
                            } else if (i20 == 1) {
                                constraintWidget7.mRight.connect(constraintWidget6.mRight, 0);
                            } else if (i20 == 2) {
                                if (z3) {
                                    constraintWidget7.mLeft.connect(this.mLeft, this.mPaddingLeft);
                                    constraintWidget7.mRight.connect(this.mRight, this.mPaddingRight);
                                } else {
                                    constraintWidget7.mLeft.connect(constraintWidget6.mLeft, 0);
                                    constraintWidget7.mRight.connect(constraintWidget6.mRight, 0);
                                }
                            }
                            i17++;
                            constraintWidget3 = constraintWidget7;
                        }
                    }
                    i17++;
                    constraintWidget3 = constraintWidget7;
                }
            }
        }

        public int getHeight() {
            if (this.mOrientation == 1) {
                return this.mHeight - Flow.this.mVerticalGap;
            }
            return this.mHeight;
        }

        public int getWidth() {
            if (this.mOrientation == 0) {
                return this.mWidth - Flow.this.mHorizontalGap;
            }
            return this.mWidth;
        }

        public void measureMatchConstraints(int i2) {
            int i3 = this.mNbMatchConstraintsWidgets;
            if (i3 != 0) {
                int i4 = this.mCount;
                int i5 = i2 / i3;
                int i6 = 0;
                while (i6 < i4 && this.mStartIndex + i6 < Flow.this.mDisplayedWidgetsCount) {
                    ConstraintWidget constraintWidget = Flow.this.mDisplayedWidgets[this.mStartIndex + i6];
                    if (this.mOrientation == 0) {
                        if (constraintWidget != null && constraintWidget.getHorizontalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT && constraintWidget.mMatchConstraintDefaultWidth == 0) {
                            Flow.this.measure(constraintWidget, ConstraintWidget.DimensionBehaviour.FIXED, i5, constraintWidget.getVerticalDimensionBehaviour(), constraintWidget.getHeight());
                        }
                    } else if (constraintWidget != null && constraintWidget.getVerticalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT && constraintWidget.mMatchConstraintDefaultHeight == 0) {
                        Flow.this.measure(constraintWidget, constraintWidget.getHorizontalDimensionBehaviour(), constraintWidget.getWidth(), ConstraintWidget.DimensionBehaviour.FIXED, i5);
                    }
                    i6++;
                }
                recomputeDimensions();
            }
        }

        public void setStartIndex(int i2) {
            this.mStartIndex = i2;
        }

        public void setup(int i2, ConstraintAnchor constraintAnchor, ConstraintAnchor constraintAnchor2, ConstraintAnchor constraintAnchor3, ConstraintAnchor constraintAnchor4, int i3, int i4, int i5, int i6, int i7) {
            this.mOrientation = i2;
            this.mLeft = constraintAnchor;
            this.mTop = constraintAnchor2;
            this.mRight = constraintAnchor3;
            this.mBottom = constraintAnchor4;
            this.mPaddingLeft = i3;
            this.mPaddingTop = i4;
            this.mPaddingRight = i5;
            this.mPaddingBottom = i6;
            this.mMax = i7;
        }
    }

    private void createAlignedConstraints(boolean z) {
        ConstraintWidget constraintWidget;
        if (!(this.mAlignedDimensions == null || this.mAlignedBiggestElementsInCols == null || this.mAlignedBiggestElementsInRows == null)) {
            for (int i2 = 0; i2 < this.mDisplayedWidgetsCount; i2++) {
                this.mDisplayedWidgets[i2].resetAnchors();
            }
            int[] iArr = this.mAlignedDimensions;
            int i3 = iArr[0];
            int i4 = iArr[1];
            ConstraintWidget constraintWidget2 = null;
            for (int i5 = 0; i5 < i3; i5++) {
                ConstraintWidget constraintWidget3 = this.mAlignedBiggestElementsInCols[z ? (i3 - i5) - 1 : i5];
                if (!(constraintWidget3 == null || constraintWidget3.getVisibility() == 8)) {
                    if (i5 == 0) {
                        constraintWidget3.connect(constraintWidget3.mLeft, this.mLeft, getPaddingLeft());
                        constraintWidget3.setHorizontalChainStyle(this.mHorizontalStyle);
                        constraintWidget3.setHorizontalBiasPercent(this.mHorizontalBias);
                    }
                    if (i5 == i3 - 1) {
                        constraintWidget3.connect(constraintWidget3.mRight, this.mRight, getPaddingRight());
                    }
                    if (i5 > 0) {
                        constraintWidget3.connect(constraintWidget3.mLeft, constraintWidget2.mRight, this.mHorizontalGap);
                        constraintWidget2.connect(constraintWidget2.mRight, constraintWidget3.mLeft, 0);
                    }
                    constraintWidget2 = constraintWidget3;
                }
            }
            for (int i6 = 0; i6 < i4; i6++) {
                ConstraintWidget constraintWidget4 = this.mAlignedBiggestElementsInRows[i6];
                if (!(constraintWidget4 == null || constraintWidget4.getVisibility() == 8)) {
                    if (i6 == 0) {
                        constraintWidget4.connect(constraintWidget4.mTop, this.mTop, getPaddingTop());
                        constraintWidget4.setVerticalChainStyle(this.mVerticalStyle);
                        constraintWidget4.setVerticalBiasPercent(this.mVerticalBias);
                    }
                    if (i6 == i4 - 1) {
                        constraintWidget4.connect(constraintWidget4.mBottom, this.mBottom, getPaddingBottom());
                    }
                    if (i6 > 0) {
                        constraintWidget4.connect(constraintWidget4.mTop, constraintWidget2.mBottom, this.mVerticalGap);
                        constraintWidget2.connect(constraintWidget2.mBottom, constraintWidget4.mTop, 0);
                    }
                    constraintWidget2 = constraintWidget4;
                }
            }
            for (int i7 = 0; i7 < i3; i7++) {
                for (int i8 = 0; i8 < i4; i8++) {
                    int i9 = (i8 * i3) + i7;
                    if (this.mOrientation == 1) {
                        i9 = (i7 * i4) + i8;
                    }
                    ConstraintWidget[] constraintWidgetArr = this.mDisplayedWidgets;
                    if (!(i9 >= constraintWidgetArr.length || (constraintWidget = constraintWidgetArr[i9]) == null || constraintWidget.getVisibility() == 8)) {
                        ConstraintWidget constraintWidget5 = this.mAlignedBiggestElementsInCols[i7];
                        ConstraintWidget constraintWidget6 = this.mAlignedBiggestElementsInRows[i8];
                        if (constraintWidget != constraintWidget5) {
                            constraintWidget.connect(constraintWidget.mLeft, constraintWidget5.mLeft, 0);
                            constraintWidget.connect(constraintWidget.mRight, constraintWidget5.mRight, 0);
                        }
                        if (constraintWidget != constraintWidget6) {
                            constraintWidget.connect(constraintWidget.mTop, constraintWidget6.mTop, 0);
                            constraintWidget.connect(constraintWidget.mBottom, constraintWidget6.mBottom, 0);
                        }
                    }
                }
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private final int getWidgetHeight(ConstraintWidget constraintWidget, int i2) {
        if (constraintWidget == null) {
            return 0;
        }
        if (constraintWidget.getVerticalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
            int i3 = constraintWidget.mMatchConstraintDefaultHeight;
            if (i3 == 0) {
                return 0;
            }
            if (i3 == 2) {
                int i4 = (int) (constraintWidget.mMatchConstraintPercentHeight * ((float) i2));
                if (i4 != constraintWidget.getHeight()) {
                    constraintWidget.setMeasureRequested(true);
                    measure(constraintWidget, constraintWidget.getHorizontalDimensionBehaviour(), constraintWidget.getWidth(), ConstraintWidget.DimensionBehaviour.FIXED, i4);
                }
                return i4;
            } else if (i3 == 1) {
                return constraintWidget.getHeight();
            } else {
                if (i3 == 3) {
                    return (int) ((((float) constraintWidget.getWidth()) * constraintWidget.mDimensionRatio) + 0.5f);
                }
            }
        }
        return constraintWidget.getHeight();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private final int getWidgetWidth(ConstraintWidget constraintWidget, int i2) {
        if (constraintWidget == null) {
            return 0;
        }
        if (constraintWidget.getHorizontalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
            int i3 = constraintWidget.mMatchConstraintDefaultWidth;
            if (i3 == 0) {
                return 0;
            }
            if (i3 == 2) {
                int i4 = (int) (constraintWidget.mMatchConstraintPercentWidth * ((float) i2));
                if (i4 != constraintWidget.getWidth()) {
                    constraintWidget.setMeasureRequested(true);
                    measure(constraintWidget, ConstraintWidget.DimensionBehaviour.FIXED, i4, constraintWidget.getVerticalDimensionBehaviour(), constraintWidget.getHeight());
                }
                return i4;
            } else if (i3 == 1) {
                return constraintWidget.getWidth();
            } else {
                if (i3 == 3) {
                    return (int) ((((float) constraintWidget.getHeight()) * constraintWidget.mDimensionRatio) + 0.5f);
                }
            }
        }
        return constraintWidget.getWidth();
    }

    /*  JADX ERROR: JadxOverflowException in pass: RegionMakerVisitor
        jadx.core.utils.exceptions.JadxOverflowException: Regions count limit reached
        	at jadx.core.utils.ErrorsCounter.addError(ErrorsCounter.java:57)
        	at jadx.core.utils.ErrorsCounter.error(ErrorsCounter.java:31)
        	at jadx.core.dex.attributes.nodes.NotificationAttrNode.addError(NotificationAttrNode.java:15)
        */
    /* JADX WARNING: Removed duplicated region for block: B:116:0x012b A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:39:0x0068  */
    private void measureAligned(androidx.constraintlayout.solver.widgets.ConstraintWidget[] r17, int r18, int r19, int r20, int[] r21) {
        /*
        // Method dump skipped, instructions count: 306
        */
        throw new UnsupportedOperationException("Method not decompiled: androidx.constraintlayout.solver.widgets.Flow.measureAligned(androidx.constraintlayout.solver.widgets.ConstraintWidget[], int, int, int, int[]):void");
    }

    private void measureChainWrap(ConstraintWidget[] constraintWidgetArr, int i2, int i3, int i4, int[] iArr) {
        int i5;
        ConstraintAnchor constraintAnchor;
        int i6;
        int i7;
        int i8;
        ConstraintAnchor constraintAnchor2;
        int i9;
        int i10;
        if (i2 != 0) {
            this.mChainList.clear();
            WidgetsList widgetsList = new WidgetsList(i3, this.mLeft, this.mTop, this.mRight, this.mBottom, i4);
            this.mChainList.add(widgetsList);
            if (i3 == 0) {
                i5 = 0;
                int i11 = 0;
                int i12 = 0;
                while (i12 < i2) {
                    ConstraintWidget constraintWidget = constraintWidgetArr[i12];
                    int widgetWidth = getWidgetWidth(constraintWidget, i4);
                    if (constraintWidget.getHorizontalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                        i5++;
                    }
                    boolean z = (i11 == i4 || (this.mHorizontalGap + i11) + widgetWidth > i4) && widgetsList.biggest != null;
                    if (!z && i12 > 0 && (i10 = this.mMaxElementsWrap) > 0 && i12 % i10 == 0) {
                        z = true;
                    }
                    if (z) {
                        widgetsList = new WidgetsList(i3, this.mLeft, this.mTop, this.mRight, this.mBottom, i4);
                        widgetsList.setStartIndex(i12);
                        this.mChainList.add(widgetsList);
                    } else if (i12 > 0) {
                        i11 = this.mHorizontalGap + widgetWidth + i11;
                        widgetsList.add(constraintWidget);
                        i12++;
                        i5 = i5;
                    }
                    i11 = widgetWidth;
                    widgetsList.add(constraintWidget);
                    i12++;
                    i5 = i5;
                }
            } else {
                i5 = 0;
                int i13 = 0;
                int i14 = 0;
                while (i14 < i2) {
                    ConstraintWidget constraintWidget2 = constraintWidgetArr[i14];
                    int widgetHeight = getWidgetHeight(constraintWidget2, i4);
                    if (constraintWidget2.getVerticalDimensionBehaviour() == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                        i5++;
                    }
                    boolean z2 = (i13 == i4 || (this.mVerticalGap + i13) + widgetHeight > i4) && widgetsList.biggest != null;
                    if (!z2 && i14 > 0 && (i9 = this.mMaxElementsWrap) > 0 && i14 % i9 == 0) {
                        z2 = true;
                    }
                    if (z2) {
                        widgetsList = new WidgetsList(i3, this.mLeft, this.mTop, this.mRight, this.mBottom, i4);
                        widgetsList.setStartIndex(i14);
                        this.mChainList.add(widgetsList);
                    } else if (i14 > 0) {
                        i13 = this.mVerticalGap + widgetHeight + i13;
                        widgetsList.add(constraintWidget2);
                        i14++;
                        i5 = i5;
                    }
                    i13 = widgetHeight;
                    widgetsList.add(constraintWidget2);
                    i14++;
                    i5 = i5;
                }
            }
            int size = this.mChainList.size();
            ConstraintAnchor constraintAnchor3 = this.mLeft;
            ConstraintAnchor constraintAnchor4 = this.mTop;
            ConstraintAnchor constraintAnchor5 = this.mRight;
            ConstraintAnchor constraintAnchor6 = this.mBottom;
            int paddingLeft = getPaddingLeft();
            int paddingTop = getPaddingTop();
            int paddingRight = getPaddingRight();
            int paddingBottom = getPaddingBottom();
            ConstraintWidget.DimensionBehaviour horizontalDimensionBehaviour = getHorizontalDimensionBehaviour();
            ConstraintWidget.DimensionBehaviour dimensionBehaviour = ConstraintWidget.DimensionBehaviour.WRAP_CONTENT;
            boolean z3 = horizontalDimensionBehaviour == dimensionBehaviour || getVerticalDimensionBehaviour() == dimensionBehaviour;
            if (i5 > 0 && z3) {
                for (int i15 = 0; i15 < size; i15++) {
                    WidgetsList widgetsList2 = this.mChainList.get(i15);
                    if (i3 == 0) {
                        widgetsList2.measureMatchConstraints(i4 - widgetsList2.getWidth());
                    } else {
                        widgetsList2.measureMatchConstraints(i4 - widgetsList2.getHeight());
                    }
                }
            }
            int i16 = paddingTop;
            int i17 = paddingRight;
            int i18 = 0;
            int i19 = 0;
            int i20 = 0;
            int i21 = paddingLeft;
            ConstraintAnchor constraintAnchor7 = constraintAnchor4;
            ConstraintAnchor constraintAnchor8 = constraintAnchor3;
            int i22 = paddingBottom;
            while (i20 < size) {
                WidgetsList widgetsList3 = this.mChainList.get(i20);
                if (i3 == 0) {
                    if (i20 < size - 1) {
                        constraintAnchor2 = this.mChainList.get(i20 + 1).biggest.mTop;
                        i8 = 0;
                    } else {
                        constraintAnchor2 = this.mBottom;
                        i8 = getPaddingBottom();
                    }
                    ConstraintAnchor constraintAnchor9 = widgetsList3.biggest.mBottom;
                    i6 = i20;
                    widgetsList3.setup(i3, constraintAnchor8, constraintAnchor7, constraintAnchor5, constraintAnchor2, i21, i16, i17, i8, i4);
                    int max = Math.max(i19, widgetsList3.getWidth());
                    int height = widgetsList3.getHeight() + i18;
                    if (i6 > 0) {
                        height += this.mVerticalGap;
                    }
                    constraintAnchor8 = constraintAnchor8;
                    i19 = max;
                    i18 = height;
                    constraintAnchor7 = constraintAnchor9;
                    i16 = 0;
                    constraintAnchor = constraintAnchor5;
                    constraintAnchor6 = constraintAnchor2;
                    i22 = i8;
                } else {
                    i6 = i20;
                    if (i6 < size - 1) {
                        constraintAnchor = this.mChainList.get(i6 + 1).biggest.mLeft;
                        i7 = 0;
                    } else {
                        constraintAnchor = this.mRight;
                        i7 = getPaddingRight();
                    }
                    ConstraintAnchor constraintAnchor10 = widgetsList3.biggest.mRight;
                    widgetsList3.setup(i3, constraintAnchor8, constraintAnchor7, constraintAnchor, constraintAnchor6, i21, i16, i7, i22, i4);
                    int width = widgetsList3.getWidth() + i19;
                    int max2 = Math.max(i18, widgetsList3.getHeight());
                    if (i6 > 0) {
                        width += this.mHorizontalGap;
                    }
                    i18 = max2;
                    i19 = width;
                    i17 = i7;
                    constraintAnchor8 = constraintAnchor10;
                    i21 = 0;
                }
                i20 = i6 + 1;
                constraintAnchor5 = constraintAnchor;
            }
            iArr[0] = i19;
            iArr[1] = i18;
        }
    }

    private void measureNoWrap(ConstraintWidget[] constraintWidgetArr, int i2, int i3, int i4, int[] iArr) {
        WidgetsList widgetsList;
        if (i2 != 0) {
            if (this.mChainList.size() == 0) {
                widgetsList = new WidgetsList(i3, this.mLeft, this.mTop, this.mRight, this.mBottom, i4);
                this.mChainList.add(widgetsList);
            } else {
                WidgetsList widgetsList2 = this.mChainList.get(0);
                widgetsList2.clear();
                widgetsList = widgetsList2;
                widgetsList.setup(i3, this.mLeft, this.mTop, this.mRight, this.mBottom, getPaddingLeft(), getPaddingTop(), getPaddingRight(), getPaddingBottom(), i4);
            }
            for (int i5 = 0; i5 < i2; i5++) {
                widgetsList.add(constraintWidgetArr[i5]);
            }
            iArr[0] = widgetsList.getWidth();
            iArr[1] = widgetsList.getHeight();
        }
    }

    @Override // androidx.constraintlayout.solver.widgets.ConstraintWidget
    public void addToSolver(LinearSystem linearSystem, boolean z) {
        super.addToSolver(linearSystem, z);
        boolean isRtl = getParent() != null ? ((ConstraintWidgetContainer) getParent()).isRtl() : false;
        int i2 = this.mWrapMode;
        if (i2 != 0) {
            if (i2 == 1) {
                int size = this.mChainList.size();
                int i3 = 0;
                while (i3 < size) {
                    this.mChainList.get(i3).createConstraints(isRtl, i3, i3 == size + -1);
                    i3++;
                }
            } else if (i2 == 2) {
                createAlignedConstraints(isRtl);
            }
        } else if (this.mChainList.size() > 0) {
            this.mChainList.get(0).createConstraints(isRtl, 0, true);
        }
        needsCallbackFromSolver(false);
    }

    @Override // androidx.constraintlayout.solver.widgets.ConstraintWidget, androidx.constraintlayout.solver.widgets.HelperWidget
    public void copy(ConstraintWidget constraintWidget, HashMap<ConstraintWidget, ConstraintWidget> hashMap) {
        super.copy(constraintWidget, hashMap);
        Flow flow = (Flow) constraintWidget;
        this.mHorizontalStyle = flow.mHorizontalStyle;
        this.mVerticalStyle = flow.mVerticalStyle;
        this.mFirstHorizontalStyle = flow.mFirstHorizontalStyle;
        this.mFirstVerticalStyle = flow.mFirstVerticalStyle;
        this.mLastHorizontalStyle = flow.mLastHorizontalStyle;
        this.mLastVerticalStyle = flow.mLastVerticalStyle;
        this.mHorizontalBias = flow.mHorizontalBias;
        this.mVerticalBias = flow.mVerticalBias;
        this.mFirstHorizontalBias = flow.mFirstHorizontalBias;
        this.mFirstVerticalBias = flow.mFirstVerticalBias;
        this.mLastHorizontalBias = flow.mLastHorizontalBias;
        this.mLastVerticalBias = flow.mLastVerticalBias;
        this.mHorizontalGap = flow.mHorizontalGap;
        this.mVerticalGap = flow.mVerticalGap;
        this.mHorizontalAlign = flow.mHorizontalAlign;
        this.mVerticalAlign = flow.mVerticalAlign;
        this.mWrapMode = flow.mWrapMode;
        this.mMaxElementsWrap = flow.mMaxElementsWrap;
        this.mOrientation = flow.mOrientation;
    }

    /* JADX WARNING: Removed duplicated region for block: B:53:0x00da  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x00dc  */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x00e9  */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x00eb  */
    /* JADX WARNING: Removed duplicated region for block: B:66:0x0104  */
    @Override // androidx.constraintlayout.solver.widgets.VirtualLayout
    public void measure(int i2, int i3, int i4, int i5) {
        int i6;
        int i7;
        int[] iArr;
        boolean z;
        char c2;
        if (this.mWidgetsCount <= 0 || measureChildren()) {
            int paddingLeft = getPaddingLeft();
            int paddingRight = getPaddingRight();
            int paddingTop = getPaddingTop();
            int paddingBottom = getPaddingBottom();
            int[] iArr2 = new int[2];
            int i8 = (i3 - paddingLeft) - paddingRight;
            int i9 = this.mOrientation;
            if (i9 == 1) {
                i8 = (i5 - paddingTop) - paddingBottom;
            }
            if (i9 == 0) {
                if (this.mHorizontalStyle == -1) {
                    this.mHorizontalStyle = 0;
                }
                if (this.mVerticalStyle == -1) {
                    this.mVerticalStyle = 0;
                }
            } else {
                if (this.mHorizontalStyle == -1) {
                    this.mHorizontalStyle = 0;
                }
                if (this.mVerticalStyle == -1) {
                    this.mVerticalStyle = 0;
                }
            }
            ConstraintWidget[] constraintWidgetArr = this.mWidgets;
            int i10 = 0;
            int i11 = 0;
            while (true) {
                i6 = this.mWidgetsCount;
                if (i10 >= i6) {
                    break;
                }
                if (this.mWidgets[i10].getVisibility() == 8) {
                    i11++;
                }
                i10++;
            }
            if (i11 > 0) {
                constraintWidgetArr = new ConstraintWidget[(i6 - i11)];
                int i12 = 0;
                for (int i13 = 0; i13 < this.mWidgetsCount; i13++) {
                    ConstraintWidget constraintWidget = this.mWidgets[i13];
                    if (constraintWidget.getVisibility() != 8) {
                        constraintWidgetArr[i12] = constraintWidget;
                        i12++;
                    }
                }
                i7 = i12;
            } else {
                i7 = i6;
            }
            this.mDisplayedWidgets = constraintWidgetArr;
            this.mDisplayedWidgetsCount = i7;
            int i14 = this.mWrapMode;
            if (i14 == 0) {
                iArr = iArr2;
                z = true;
                measureNoWrap(constraintWidgetArr, i7, this.mOrientation, i8, iArr2);
            } else if (i14 == 1) {
                iArr = iArr2;
                z = true;
                measureChainWrap(constraintWidgetArr, i7, this.mOrientation, i8, iArr2);
            } else if (i14 != 2) {
                iArr = iArr2;
                c2 = 0;
                z = true;
                int i15 = iArr[c2] + paddingLeft + paddingRight;
                char c3 = z ? 1 : 0;
                char c4 = z ? 1 : 0;
                char c5 = z ? 1 : 0;
                char c6 = z ? 1 : 0;
                char c7 = z ? 1 : 0;
                char c8 = z ? 1 : 0;
                char c9 = z ? 1 : 0;
                int i16 = iArr[c3] + paddingTop + paddingBottom;
                if (i2 != 1073741824) {
                    i15 = i3;
                } else if (i2 == Integer.MIN_VALUE) {
                    i15 = Math.min(i15, i3);
                } else if (i2 != 0) {
                    i15 = 0;
                }
                if (i4 != 1073741824) {
                    i16 = i5;
                } else if (i4 == Integer.MIN_VALUE) {
                    i16 = Math.min(i16, i5);
                } else if (i4 != 0) {
                    i16 = 0;
                }
                setMeasure(i15, i16);
                setWidth(i15);
                setHeight(i16);
                if (this.mWidgetsCount <= 0) {
                    z = false;
                }
                needsCallbackFromSolver(z);
                return;
            } else {
                z = true;
                iArr = iArr2;
                measureAligned(constraintWidgetArr, i7, this.mOrientation, i8, iArr2);
            }
            c2 = 0;
            int i152 = iArr[c2] + paddingLeft + paddingRight;
            char c32 = z ? 1 : 0;
            char c42 = z ? 1 : 0;
            char c52 = z ? 1 : 0;
            char c62 = z ? 1 : 0;
            char c72 = z ? 1 : 0;
            char c82 = z ? 1 : 0;
            char c92 = z ? 1 : 0;
            int i162 = iArr[c32] + paddingTop + paddingBottom;
            if (i2 != 1073741824) {
            }
            if (i4 != 1073741824) {
            }
            setMeasure(i152, i162);
            setWidth(i152);
            setHeight(i162);
            if (this.mWidgetsCount <= 0) {
            }
            needsCallbackFromSolver(z);
            return;
        }
        setMeasure(0, 0);
        needsCallbackFromSolver(false);
    }

    public void setFirstHorizontalBias(float f2) {
        this.mFirstHorizontalBias = f2;
    }

    public void setFirstHorizontalStyle(int i2) {
        this.mFirstHorizontalStyle = i2;
    }

    public void setFirstVerticalBias(float f2) {
        this.mFirstVerticalBias = f2;
    }

    public void setFirstVerticalStyle(int i2) {
        this.mFirstVerticalStyle = i2;
    }

    public void setHorizontalAlign(int i2) {
        this.mHorizontalAlign = i2;
    }

    public void setHorizontalBias(float f2) {
        this.mHorizontalBias = f2;
    }

    public void setHorizontalGap(int i2) {
        this.mHorizontalGap = i2;
    }

    public void setHorizontalStyle(int i2) {
        this.mHorizontalStyle = i2;
    }

    public void setLastHorizontalBias(float f2) {
        this.mLastHorizontalBias = f2;
    }

    public void setLastHorizontalStyle(int i2) {
        this.mLastHorizontalStyle = i2;
    }

    public void setLastVerticalBias(float f2) {
        this.mLastVerticalBias = f2;
    }

    public void setLastVerticalStyle(int i2) {
        this.mLastVerticalStyle = i2;
    }

    public void setMaxElementsWrap(int i2) {
        this.mMaxElementsWrap = i2;
    }

    public void setOrientation(int i2) {
        this.mOrientation = i2;
    }

    public void setVerticalAlign(int i2) {
        this.mVerticalAlign = i2;
    }

    public void setVerticalBias(float f2) {
        this.mVerticalBias = f2;
    }

    public void setVerticalGap(int i2) {
        this.mVerticalGap = i2;
    }

    public void setVerticalStyle(int i2) {
        this.mVerticalStyle = i2;
    }

    public void setWrapMode(int i2) {
        this.mWrapMode = i2;
    }
}
