package androidx.constraintlayout.solver.widgets.analyzer;

import androidx.constraintlayout.solver.widgets.ConstraintAnchor;
import androidx.constraintlayout.solver.widgets.ConstraintWidget;
import androidx.constraintlayout.solver.widgets.ConstraintWidgetContainer;
import d.b.a.a.a;
import java.util.ArrayList;
import java.util.Iterator;

public class ChainRun extends WidgetRun {
    private int chainStyle;
    public ArrayList<WidgetRun> widgets = new ArrayList<>();

    public ChainRun(ConstraintWidget constraintWidget, int i2) {
        super(constraintWidget);
        this.orientation = i2;
        build();
    }

    private void build() {
        ConstraintWidget constraintWidget = this.widget;
        ConstraintWidget previousChainMember = constraintWidget.getPreviousChainMember(this.orientation);
        while (true) {
            constraintWidget = previousChainMember;
            if (constraintWidget == null) {
                break;
            }
            previousChainMember = constraintWidget.getPreviousChainMember(this.orientation);
        }
        this.widget = constraintWidget;
        this.widgets.add(constraintWidget.getRun(this.orientation));
        ConstraintWidget nextChainMember = constraintWidget.getNextChainMember(this.orientation);
        while (nextChainMember != null) {
            this.widgets.add(nextChainMember.getRun(this.orientation));
            nextChainMember = nextChainMember.getNextChainMember(this.orientation);
        }
        Iterator<WidgetRun> it = this.widgets.iterator();
        while (it.hasNext()) {
            WidgetRun next = it.next();
            int i2 = this.orientation;
            if (i2 == 0) {
                next.widget.horizontalChainRun = this;
            } else if (i2 == 1) {
                next.widget.verticalChainRun = this;
            }
        }
        if ((this.orientation == 0 && ((ConstraintWidgetContainer) this.widget.getParent()).isRtl()) && this.widgets.size() > 1) {
            ArrayList<WidgetRun> arrayList = this.widgets;
            this.widget = arrayList.get(arrayList.size() - 1).widget;
        }
        this.chainStyle = this.orientation == 0 ? this.widget.getHorizontalChainStyle() : this.widget.getVerticalChainStyle();
    }

    private ConstraintWidget getFirstVisibleWidget() {
        for (int i2 = 0; i2 < this.widgets.size(); i2++) {
            WidgetRun widgetRun = this.widgets.get(i2);
            if (widgetRun.widget.getVisibility() != 8) {
                return widgetRun.widget;
            }
        }
        return null;
    }

    private ConstraintWidget getLastVisibleWidget() {
        for (int size = this.widgets.size() - 1; size >= 0; size--) {
            WidgetRun widgetRun = this.widgets.get(size);
            if (widgetRun.widget.getVisibility() != 8) {
                return widgetRun.widget;
            }
        }
        return null;
    }

    @Override // androidx.constraintlayout.solver.widgets.analyzer.WidgetRun
    public void apply() {
        Iterator<WidgetRun> it = this.widgets.iterator();
        while (it.hasNext()) {
            it.next().apply();
        }
        int size = this.widgets.size();
        if (size >= 1) {
            ConstraintWidget constraintWidget = this.widgets.get(0).widget;
            ConstraintWidget constraintWidget2 = this.widgets.get(size - 1).widget;
            if (this.orientation == 0) {
                ConstraintAnchor constraintAnchor = constraintWidget.mLeft;
                ConstraintAnchor constraintAnchor2 = constraintWidget2.mRight;
                DependencyNode target = getTarget(constraintAnchor, 0);
                int margin = constraintAnchor.getMargin();
                ConstraintWidget firstVisibleWidget = getFirstVisibleWidget();
                if (firstVisibleWidget != null) {
                    margin = firstVisibleWidget.mLeft.getMargin();
                }
                if (target != null) {
                    addTarget(this.start, target, margin);
                }
                DependencyNode target2 = getTarget(constraintAnchor2, 0);
                int margin2 = constraintAnchor2.getMargin();
                ConstraintWidget lastVisibleWidget = getLastVisibleWidget();
                if (lastVisibleWidget != null) {
                    margin2 = lastVisibleWidget.mRight.getMargin();
                }
                if (target2 != null) {
                    addTarget(this.end, target2, -margin2);
                }
            } else {
                ConstraintAnchor constraintAnchor3 = constraintWidget.mTop;
                ConstraintAnchor constraintAnchor4 = constraintWidget2.mBottom;
                DependencyNode target3 = getTarget(constraintAnchor3, 1);
                int margin3 = constraintAnchor3.getMargin();
                ConstraintWidget firstVisibleWidget2 = getFirstVisibleWidget();
                if (firstVisibleWidget2 != null) {
                    margin3 = firstVisibleWidget2.mTop.getMargin();
                }
                if (target3 != null) {
                    addTarget(this.start, target3, margin3);
                }
                DependencyNode target4 = getTarget(constraintAnchor4, 1);
                int margin4 = constraintAnchor4.getMargin();
                ConstraintWidget lastVisibleWidget2 = getLastVisibleWidget();
                if (lastVisibleWidget2 != null) {
                    margin4 = lastVisibleWidget2.mBottom.getMargin();
                }
                if (target4 != null) {
                    addTarget(this.end, target4, -margin4);
                }
            }
            this.start.updateDelegate = this;
            this.end.updateDelegate = this;
        }
    }

    @Override // androidx.constraintlayout.solver.widgets.analyzer.WidgetRun
    public void applyToWidget() {
        for (int i2 = 0; i2 < this.widgets.size(); i2++) {
            this.widgets.get(i2).applyToWidget();
        }
    }

    @Override // androidx.constraintlayout.solver.widgets.analyzer.WidgetRun
    public void clear() {
        this.runGroup = null;
        Iterator<WidgetRun> it = this.widgets.iterator();
        while (it.hasNext()) {
            it.next().clear();
        }
    }

    @Override // androidx.constraintlayout.solver.widgets.analyzer.WidgetRun
    public long getWrapDimension() {
        int size = this.widgets.size();
        long j2 = 0;
        for (int i2 = 0; i2 < size; i2++) {
            WidgetRun widgetRun = this.widgets.get(i2);
            j2 = ((long) widgetRun.end.margin) + widgetRun.getWrapDimension() + j2 + ((long) widgetRun.start.margin);
        }
        return j2;
    }

    @Override // androidx.constraintlayout.solver.widgets.analyzer.WidgetRun
    public void reset() {
        this.start.resolved = false;
        this.end.resolved = false;
    }

    @Override // androidx.constraintlayout.solver.widgets.analyzer.WidgetRun
    public boolean supportsWrapComputation() {
        int size = this.widgets.size();
        for (int i2 = 0; i2 < size; i2++) {
            if (!this.widgets.get(i2).supportsWrapComputation()) {
                return false;
            }
        }
        return true;
    }

    public String toString() {
        StringBuilder n = a.n("ChainRun ");
        n.append(this.orientation == 0 ? "horizontal : " : "vertical : ");
        String sb = n.toString();
        Iterator<WidgetRun> it = this.widgets.iterator();
        while (it.hasNext()) {
            String g2 = a.g(sb, "<");
            sb = a.g(g2 + it.next(), "> ");
        }
        return sb;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:104:0x01a6, code lost:
        if (r1 != r7) goto L_0x01ce;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:112:0x01cc, code lost:
        if (r1 != r7) goto L_0x01ce;
     */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x00d9  */
    /* JADX WARNING: Removed duplicated region for block: B:63:0x00eb  */
    @Override // androidx.constraintlayout.solver.widgets.analyzer.Dependency, androidx.constraintlayout.solver.widgets.analyzer.WidgetRun
    public void update(Dependency dependency) {
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        float f2;
        int i7;
        boolean z;
        int i8;
        int i9;
        float f3;
        int i10;
        int i11;
        boolean z2;
        float f4;
        int i12;
        int i13;
        int i14;
        int i15;
        int i16;
        int i17;
        if (this.start.resolved && this.end.resolved) {
            ConstraintWidget parent = this.widget.getParent();
            boolean isRtl = (parent == null || !(parent instanceof ConstraintWidgetContainer)) ? false : ((ConstraintWidgetContainer) parent).isRtl();
            int i18 = this.end.value - this.start.value;
            int size = this.widgets.size();
            int i19 = 0;
            while (true) {
                i2 = -1;
                i3 = 8;
                if (i19 >= size) {
                    i19 = -1;
                    break;
                }
                if (this.widgets.get(i19).widget.getVisibility() != 8) {
                    break;
                }
                i19++;
            }
            int i20 = size - 1;
            int i21 = i20;
            while (true) {
                if (i21 < 0) {
                    break;
                }
                if (this.widgets.get(i21).widget.getVisibility() != 8) {
                    i2 = i21;
                    break;
                }
                i21--;
            }
            int i22 = 0;
            while (true) {
                if (i22 >= 2) {
                    i4 = 0;
                    i5 = 0;
                    i6 = 0;
                    f2 = 0.0f;
                    break;
                }
                int i23 = 0;
                i5 = 0;
                i6 = 0;
                i15 = 0;
                f2 = 0.0f;
                while (i23 < size) {
                    WidgetRun widgetRun = this.widgets.get(i23);
                    if (widgetRun.widget.getVisibility() != i3) {
                        i15++;
                        if (i23 > 0 && i23 >= i19) {
                            i5 += widgetRun.start.margin;
                        }
                        DimensionDependency dimensionDependency = widgetRun.dimension;
                        int i24 = dimensionDependency.value;
                        boolean z3 = widgetRun.dimensionBehavior != ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT;
                        if (z3) {
                            int i25 = this.orientation;
                            if (i25 == 0 && !widgetRun.widget.horizontalRun.dimension.resolved) {
                                return;
                            }
                            if (i25 != 1 || widgetRun.widget.verticalRun.dimension.resolved) {
                                i17 = i24;
                            } else {
                                return;
                            }
                        } else {
                            i17 = i24;
                            if (widgetRun.matchConstraintsType == 1 && i22 == 0) {
                                i16 = dimensionDependency.wrapValue;
                                i6++;
                            } else if (dimensionDependency.resolved) {
                                i16 = i17;
                            }
                            z3 = true;
                            if (z3) {
                                i6++;
                                float f5 = widgetRun.widget.mWeight[this.orientation];
                                if (f5 >= 0.0f) {
                                    f2 += f5;
                                }
                            } else {
                                i5 += i16;
                            }
                            if (i23 < i20 && i23 < i2) {
                                i5 += -widgetRun.end.margin;
                            }
                        }
                        i16 = i17;
                        if (z3) {
                        }
                        i5 += -widgetRun.end.margin;
                    }
                    i23++;
                    i3 = 8;
                }
                if (i5 < i18 || i6 == 0) {
                    i4 = i15;
                } else {
                    i22++;
                    i3 = 8;
                }
            }
            i4 = i15;
            int i26 = this.start.value;
            if (isRtl) {
                i26 = this.end.value;
            }
            if (i5 > i18) {
                i26 = isRtl ? i26 + ((int) ((((float) (i5 - i18)) / 2.0f) + 0.5f)) : i26 - ((int) ((((float) (i5 - i18)) / 2.0f) + 0.5f));
            }
            if (i6 > 0) {
                float f6 = (float) (i18 - i5);
                int i27 = (int) ((f6 / ((float) i6)) + 0.5f);
                int i28 = 0;
                int i29 = 0;
                while (i28 < size) {
                    WidgetRun widgetRun2 = this.widgets.get(i28);
                    if (widgetRun2.widget.getVisibility() != 8 && widgetRun2.dimensionBehavior == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                        DimensionDependency dimensionDependency2 = widgetRun2.dimension;
                        if (!dimensionDependency2.resolved) {
                            if (f2 > 0.0f) {
                                i12 = i26;
                                i13 = (int) (((widgetRun2.widget.mWeight[this.orientation] * f6) / f2) + 0.5f);
                            } else {
                                i12 = i26;
                                i13 = i27;
                            }
                            if (this.orientation == 0) {
                                ConstraintWidget constraintWidget = widgetRun2.widget;
                                f4 = f6;
                                int i30 = constraintWidget.mMatchConstraintMaxWidth;
                                z2 = isRtl;
                                i11 = i4;
                                i14 = Math.max(constraintWidget.mMatchConstraintMinWidth, widgetRun2.matchConstraintsType == 1 ? Math.min(i13, dimensionDependency2.wrapValue) : i13);
                                if (i30 > 0) {
                                    i14 = Math.min(i30, i14);
                                }
                            } else {
                                z2 = isRtl;
                                i11 = i4;
                                f4 = f6;
                                ConstraintWidget constraintWidget2 = widgetRun2.widget;
                                int i31 = constraintWidget2.mMatchConstraintMaxHeight;
                                i14 = Math.max(constraintWidget2.mMatchConstraintMinHeight, widgetRun2.matchConstraintsType == 1 ? Math.min(i13, dimensionDependency2.wrapValue) : i13);
                                if (i31 > 0) {
                                    i14 = Math.min(i31, i14);
                                }
                            }
                            i29++;
                            i13 = i14;
                            widgetRun2.dimension.resolve(i13);
                            i28++;
                            i27 = i27;
                            i5 = i5;
                            i26 = i12;
                            f6 = f4;
                            isRtl = z2;
                            i4 = i11;
                        }
                    }
                    z2 = isRtl;
                    i11 = i4;
                    i12 = i26;
                    f4 = f6;
                    i28++;
                    i27 = i27;
                    i5 = i5;
                    i26 = i12;
                    f6 = f4;
                    isRtl = z2;
                    i4 = i11;
                }
                z = isRtl;
                i7 = i4;
                i8 = i26;
                if (i29 > 0) {
                    i6 -= i29;
                    int i32 = 0;
                    for (int i33 = 0; i33 < size; i33++) {
                        WidgetRun widgetRun3 = this.widgets.get(i33);
                        if (widgetRun3.widget.getVisibility() != 8) {
                            if (i33 > 0 && i33 >= i19) {
                                i32 += widgetRun3.start.margin;
                            }
                            i32 += widgetRun3.dimension.value;
                            if (i33 < i20 && i33 < i2) {
                                i32 += -widgetRun3.end.margin;
                            }
                        }
                    }
                    i5 = i32;
                } else {
                    i5 = i5;
                }
                i9 = 2;
                if (this.chainStyle == 2 && i29 == 0) {
                    this.chainStyle = 0;
                }
            } else {
                z = isRtl;
                i7 = i4;
                i8 = i26;
                i9 = 2;
            }
            if (i5 > i18) {
                this.chainStyle = i9;
            }
            if (i7 > 0 && i6 == 0 && i19 == i2) {
                this.chainStyle = i9;
            }
            int i34 = this.chainStyle;
            if (i34 == 1) {
                if (i7 > 1) {
                    i10 = (i18 - i5) / (i7 - 1);
                } else {
                    i10 = i7 == 1 ? (i18 - i5) / 2 : 0;
                }
                if (i6 > 0) {
                    i10 = 0;
                }
                int i35 = i8;
                for (int i36 = 0; i36 < size; i36++) {
                    WidgetRun widgetRun4 = this.widgets.get(z ? size - (i36 + 1) : i36);
                    if (widgetRun4.widget.getVisibility() == 8) {
                        widgetRun4.start.resolve(i35);
                        widgetRun4.end.resolve(i35);
                    } else {
                        if (i36 > 0) {
                            i35 = z ? i35 - i10 : i35 + i10;
                        }
                        if (i36 > 0 && i36 >= i19) {
                            if (z) {
                                i35 -= widgetRun4.start.margin;
                            } else {
                                i35 += widgetRun4.start.margin;
                            }
                        }
                        if (z) {
                            widgetRun4.end.resolve(i35);
                        } else {
                            widgetRun4.start.resolve(i35);
                        }
                        DimensionDependency dimensionDependency3 = widgetRun4.dimension;
                        int i37 = dimensionDependency3.value;
                        if (widgetRun4.dimensionBehavior == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT && widgetRun4.matchConstraintsType == 1) {
                            i37 = dimensionDependency3.wrapValue;
                        }
                        i35 = z ? i35 - i37 : i35 + i37;
                        if (z) {
                            widgetRun4.start.resolve(i35);
                        } else {
                            widgetRun4.end.resolve(i35);
                        }
                        widgetRun4.resolved = true;
                        if (i36 < i20 && i36 < i2) {
                            i35 = z ? i35 - (-widgetRun4.end.margin) : i35 + (-widgetRun4.end.margin);
                        }
                    }
                }
            } else if (i34 == 0) {
                int i38 = (i18 - i5) / (i7 + 1);
                if (i6 > 0) {
                    i38 = 0;
                }
                int i39 = i8;
                for (int i40 = 0; i40 < size; i40++) {
                    WidgetRun widgetRun5 = this.widgets.get(z ? size - (i40 + 1) : i40);
                    if (widgetRun5.widget.getVisibility() == 8) {
                        widgetRun5.start.resolve(i39);
                        widgetRun5.end.resolve(i39);
                    } else {
                        int i41 = z ? i39 - i38 : i39 + i38;
                        if (i40 > 0 && i40 >= i19) {
                            i41 = z ? i41 - widgetRun5.start.margin : i41 + widgetRun5.start.margin;
                        }
                        if (z) {
                            widgetRun5.end.resolve(i41);
                        } else {
                            widgetRun5.start.resolve(i41);
                        }
                        DimensionDependency dimensionDependency4 = widgetRun5.dimension;
                        int i42 = dimensionDependency4.value;
                        if (widgetRun5.dimensionBehavior == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT && widgetRun5.matchConstraintsType == 1) {
                            i42 = Math.min(i42, dimensionDependency4.wrapValue);
                        }
                        i39 = z ? i41 - i42 : i41 + i42;
                        if (z) {
                            widgetRun5.start.resolve(i39);
                        } else {
                            widgetRun5.end.resolve(i39);
                        }
                        if (i40 < i20 && i40 < i2) {
                            i39 = z ? i39 - (-widgetRun5.end.margin) : i39 + (-widgetRun5.end.margin);
                        }
                    }
                }
            } else if (i34 == 2) {
                if (this.orientation == 0) {
                    f3 = this.widget.getHorizontalBiasPercent();
                } else {
                    f3 = this.widget.getVerticalBiasPercent();
                }
                if (z) {
                    f3 = 1.0f - f3;
                }
                int i43 = (int) ((((float) (i18 - i5)) * f3) + 0.5f);
                if (i43 < 0 || i6 > 0) {
                    i43 = 0;
                }
                int i44 = z ? i8 - i43 : i8 + i43;
                for (int i45 = 0; i45 < size; i45++) {
                    WidgetRun widgetRun6 = this.widgets.get(z ? size - (i45 + 1) : i45);
                    if (widgetRun6.widget.getVisibility() == 8) {
                        widgetRun6.start.resolve(i44);
                        widgetRun6.end.resolve(i44);
                    } else {
                        if (i45 > 0 && i45 >= i19) {
                            if (z) {
                                i44 -= widgetRun6.start.margin;
                            } else {
                                i44 += widgetRun6.start.margin;
                            }
                        }
                        if (z) {
                            widgetRun6.end.resolve(i44);
                        } else {
                            widgetRun6.start.resolve(i44);
                        }
                        DimensionDependency dimensionDependency5 = widgetRun6.dimension;
                        int i46 = dimensionDependency5.value;
                        if (widgetRun6.dimensionBehavior == ConstraintWidget.DimensionBehaviour.MATCH_CONSTRAINT) {
                            if (widgetRun6.matchConstraintsType == 1) {
                                i46 = dimensionDependency5.wrapValue;
                            }
                        }
                        i44 = z ? i44 - i46 : i44 + i46;
                        if (z) {
                            widgetRun6.start.resolve(i44);
                        } else {
                            widgetRun6.end.resolve(i44);
                        }
                        if (i45 < i20 && i45 < i2) {
                            i44 = z ? i44 - (-widgetRun6.end.margin) : i44 + (-widgetRun6.end.margin);
                        }
                    }
                }
            }
        }
    }
}
