package androidx.lifecycle;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.arch.core.executor.ArchTaskExecutor;
import i.b.b;
import i.b.c;
import i.b.d;
import java.util.concurrent.atomic.AtomicReference;

public final class LiveDataReactiveStreams {

    public static final class LiveDataPublisher<T> implements b<T> {
        public final LifecycleOwner mLifecycle;
        public final LiveData<T> mLiveData;

        public static final class LiveDataSubscription<T> implements d, Observer<T> {
            public volatile boolean mCanceled;
            @Nullable
            public T mLatest;
            public final LifecycleOwner mLifecycle;
            public final LiveData<T> mLiveData;
            public boolean mObserving;
            public long mRequested;
            public final c<? super T> mSubscriber;

            public LiveDataSubscription(c<? super T> cVar, LifecycleOwner lifecycleOwner, LiveData<T> liveData) {
                this.mSubscriber = cVar;
                this.mLifecycle = lifecycleOwner;
                this.mLiveData = liveData;
            }

            @Override // i.b.d
            public void cancel() {
                if (!this.mCanceled) {
                    this.mCanceled = true;
                    ArchTaskExecutor.getInstance().executeOnMainThread(new Runnable() {
                        /* class androidx.lifecycle.LiveDataReactiveStreams.LiveDataPublisher.LiveDataSubscription.AnonymousClass2 */

                        public void run() {
                            LiveDataSubscription liveDataSubscription = LiveDataSubscription.this;
                            if (liveDataSubscription.mObserving) {
                                liveDataSubscription.mLiveData.removeObserver(liveDataSubscription);
                                LiveDataSubscription.this.mObserving = false;
                            }
                            LiveDataSubscription.this.mLatest = null;
                        }
                    });
                }
            }

            @Override // androidx.lifecycle.Observer
            public void onChanged(@Nullable T t) {
                if (!this.mCanceled) {
                    if (this.mRequested > 0) {
                        this.mLatest = null;
                        this.mSubscriber.onNext(t);
                        long j2 = this.mRequested;
                        if (j2 != Long.MAX_VALUE) {
                            this.mRequested = j2 - 1;
                            return;
                        }
                        return;
                    }
                    this.mLatest = t;
                }
            }

            @Override // i.b.d
            public void request(final long j2) {
                if (!this.mCanceled) {
                    ArchTaskExecutor.getInstance().executeOnMainThread(new Runnable() {
                        /* class androidx.lifecycle.LiveDataReactiveStreams.LiveDataPublisher.LiveDataSubscription.AnonymousClass1 */

                        public void run() {
                            if (!LiveDataSubscription.this.mCanceled) {
                                long j2 = j2;
                                if (j2 <= 0) {
                                    LiveDataSubscription.this.mCanceled = true;
                                    LiveDataSubscription liveDataSubscription = LiveDataSubscription.this;
                                    if (liveDataSubscription.mObserving) {
                                        liveDataSubscription.mLiveData.removeObserver(liveDataSubscription);
                                        LiveDataSubscription.this.mObserving = false;
                                    }
                                    LiveDataSubscription liveDataSubscription2 = LiveDataSubscription.this;
                                    liveDataSubscription2.mLatest = null;
                                    liveDataSubscription2.mSubscriber.onError(new IllegalArgumentException("Non-positive request"));
                                    return;
                                }
                                LiveDataSubscription liveDataSubscription3 = LiveDataSubscription.this;
                                long j3 = liveDataSubscription3.mRequested;
                                liveDataSubscription3.mRequested = j3 + j2 >= j3 ? j3 + j2 : Long.MAX_VALUE;
                                if (!liveDataSubscription3.mObserving) {
                                    liveDataSubscription3.mObserving = true;
                                    liveDataSubscription3.mLiveData.observe(liveDataSubscription3.mLifecycle, liveDataSubscription3);
                                    return;
                                }
                                T t = liveDataSubscription3.mLatest;
                                if (t != null) {
                                    liveDataSubscription3.onChanged(t);
                                    LiveDataSubscription.this.mLatest = null;
                                }
                            }
                        }
                    });
                }
            }
        }

        public LiveDataPublisher(LifecycleOwner lifecycleOwner, LiveData<T> liveData) {
            this.mLifecycle = lifecycleOwner;
            this.mLiveData = liveData;
        }

        @Override // i.b.b
        public void subscribe(c<? super T> cVar) {
            cVar.onSubscribe(new LiveDataSubscription(cVar, this.mLifecycle, this.mLiveData));
        }
    }

    public static class PublisherLiveData<T> extends LiveData<T> {
        private final b<T> mPublisher;
        public final AtomicReference<PublisherLiveData<T>.LiveDataSubscriber> mSubscriber = new AtomicReference<>();

        public final class LiveDataSubscriber extends AtomicReference<d> implements c<T> {
            public LiveDataSubscriber() {
            }

            public void cancelSubscription() {
                d dVar = (d) get();
                if (dVar != null) {
                    dVar.cancel();
                }
            }

            @Override // i.b.c
            public void onComplete() {
                PublisherLiveData.this.mSubscriber.compareAndSet(this, null);
            }

            @Override // i.b.c
            public void onError(final Throwable th) {
                PublisherLiveData.this.mSubscriber.compareAndSet(this, null);
                ArchTaskExecutor.getInstance().executeOnMainThread(new Runnable() {
                    /* class androidx.lifecycle.LiveDataReactiveStreams.PublisherLiveData.LiveDataSubscriber.AnonymousClass1 */

                    public void run() {
                        throw new RuntimeException("LiveData does not handle errors. Errors from publishers should be handled upstream and propagated as state", th);
                    }
                });
            }

            @Override // i.b.c
            public void onNext(T t) {
                PublisherLiveData.this.postValue(t);
            }

            @Override // i.b.c
            public void onSubscribe(d dVar) {
                if (compareAndSet(null, dVar)) {
                    dVar.request(Long.MAX_VALUE);
                } else {
                    dVar.cancel();
                }
            }
        }

        public PublisherLiveData(@NonNull b<T> bVar) {
            this.mPublisher = bVar;
        }

        @Override // androidx.lifecycle.LiveData
        public void onActive() {
            super.onActive();
            PublisherLiveData<T>.LiveDataSubscriber liveDataSubscriber = new LiveDataSubscriber();
            this.mSubscriber.set(liveDataSubscriber);
            this.mPublisher.subscribe(liveDataSubscriber);
        }

        @Override // androidx.lifecycle.LiveData
        public void onInactive() {
            super.onInactive();
            PublisherLiveData<T>.LiveDataSubscriber andSet = this.mSubscriber.getAndSet(null);
            if (andSet != null) {
                andSet.cancelSubscription();
            }
        }
    }

    private LiveDataReactiveStreams() {
    }

    @NonNull
    public static <T> LiveData<T> fromPublisher(@NonNull b<T> bVar) {
        return new PublisherLiveData(bVar);
    }

    @NonNull
    public static <T> b<T> toPublisher(@NonNull LifecycleOwner lifecycleOwner, @NonNull LiveData<T> liveData) {
        return new LiveDataPublisher(lifecycleOwner, liveData);
    }
}
