package com.luck.picture.lib;

import android.content.Context;
import android.content.Intent;
import android.media.MediaPlayer;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.os.Handler;
import android.os.Parcelable;
import android.os.SystemClock;
import android.text.TextUtils;
import android.view.View;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.Button;
import android.widget.CheckBox;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.SeekBar;
import android.widget.TextView;
import androidx.annotation.NonNull;
import androidx.core.content.ContextCompat;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.SimpleItemAnimator;
import com.luck.picture.lib.adapter.PictureImageGridAdapter;
import com.luck.picture.lib.animators.AlphaInAnimationAdapter;
import com.luck.picture.lib.animators.SlideInBottomAnimationAdapter;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.decoration.GridSpacingItemDecoration;
import com.luck.picture.lib.dialog.PhotoItemSelectedDialog;
import com.luck.picture.lib.dialog.PictureCustomDialog;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.listener.OnAlbumItemClickListener;
import com.luck.picture.lib.listener.OnCustomCameraInterfaceListener;
import com.luck.picture.lib.listener.OnCustomImagePreviewCallback;
import com.luck.picture.lib.listener.OnItemClickListener;
import com.luck.picture.lib.listener.OnPhotoSelectChangedListener;
import com.luck.picture.lib.listener.OnRecyclerViewPreloadMoreListener;
import com.luck.picture.lib.listener.OnResultCallbackListener;
import com.luck.picture.lib.listener.OnVideoSelectedPlayCallback;
import com.luck.picture.lib.model.LocalMediaLoader;
import com.luck.picture.lib.model.LocalMediaPageLoader;
import com.luck.picture.lib.observable.ImagesObservable;
import com.luck.picture.lib.permissions.PermissionChecker;
import com.luck.picture.lib.style.PictureParameterStyle;
import com.luck.picture.lib.style.PictureWindowAnimationStyle;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.AttrsUtils;
import com.luck.picture.lib.tools.BitmapUtils;
import com.luck.picture.lib.tools.DateUtils;
import com.luck.picture.lib.tools.DoubleUtils;
import com.luck.picture.lib.tools.JumpUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.ScreenUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.StringUtils;
import com.luck.picture.lib.tools.ToastUtils;
import com.luck.picture.lib.tools.ValueOf;
import com.luck.picture.lib.widget.FolderPopWindow;
import com.luck.picture.lib.widget.RecyclerPreloadView;
import com.yalantis.ucrop.UCrop;
import com.yalantis.ucrop.model.CutInfo;
import com.yalantis.ucrop.view.CropImageView;
import d.k.a.a.a0;
import d.k.a.a.b0;
import d.k.a.a.c0;
import d.k.a.a.d0;
import d.k.a.a.u;
import d.k.a.a.v;
import d.k.a.a.w;
import d.k.a.a.x;
import d.k.a.a.y;
import d.k.a.a.z;
import java.io.File;
import java.util.ArrayList;
import java.util.List;

public class PictureSelectorActivity extends PictureBaseActivity implements View.OnClickListener, OnAlbumItemClickListener, OnPhotoSelectChangedListener<LocalMedia>, OnItemClickListener, OnRecyclerViewPreloadMoreListener {
    private static final String TAG = PictureSelectorActivity.class.getSimpleName();
    private int allFolderSize;
    public Animation animation = null;
    public PictureCustomDialog audioDialog;
    public FolderPopWindow folderWindow;
    private long intervalClickTime = 0;
    public boolean isEnterSetting;
    public boolean isPlayAudio = false;
    public boolean isStartAnimation = false;
    public PictureImageGridAdapter mAdapter;
    public RelativeLayout mBottomLayout;
    public CheckBox mCbOriginal;
    public ImageView mIvArrow;
    public ImageView mIvPictureLeftBack;
    private int mOpenCameraCount;
    public RecyclerPreloadView mRecyclerView;
    public Runnable mRunnable = new Runnable() {
        /* class com.luck.picture.lib.PictureSelectorActivity.AnonymousClass4 */

        public void run() {
            try {
                PictureSelectorActivity pictureSelectorActivity = PictureSelectorActivity.this;
                MediaPlayer mediaPlayer = pictureSelectorActivity.mediaPlayer;
                if (mediaPlayer != null) {
                    pictureSelectorActivity.mTvMusicTime.setText(DateUtils.formatDurationTime((long) mediaPlayer.getCurrentPosition()));
                    PictureSelectorActivity pictureSelectorActivity2 = PictureSelectorActivity.this;
                    pictureSelectorActivity2.musicSeekBar.setProgress(pictureSelectorActivity2.mediaPlayer.getCurrentPosition());
                    PictureSelectorActivity pictureSelectorActivity3 = PictureSelectorActivity.this;
                    pictureSelectorActivity3.musicSeekBar.setMax(pictureSelectorActivity3.mediaPlayer.getDuration());
                    PictureSelectorActivity pictureSelectorActivity4 = PictureSelectorActivity.this;
                    pictureSelectorActivity4.mTvMusicTotal.setText(DateUtils.formatDurationTime((long) pictureSelectorActivity4.mediaPlayer.getDuration()));
                    PictureSelectorActivity pictureSelectorActivity5 = PictureSelectorActivity.this;
                    Handler handler = pictureSelectorActivity5.mHandler;
                    if (handler != null) {
                        handler.postDelayed(pictureSelectorActivity5.mRunnable, 200);
                    }
                }
            } catch (Exception e2) {
                e2.printStackTrace();
            }
        }
    };
    public TextView mTvEmpty;
    public TextView mTvMusicStatus;
    public TextView mTvMusicTime;
    public TextView mTvMusicTotal;
    public TextView mTvPictureImgNum;
    public TextView mTvPictureOk;
    public TextView mTvPicturePreview;
    public TextView mTvPictureRight;
    public TextView mTvPictureTitle;
    public TextView mTvPlayPause;
    public TextView mTvQuit;
    public TextView mTvStop;
    public MediaPlayer mediaPlayer;
    public SeekBar musicSeekBar;
    public int oldCurrentListSize;
    public View titleViewBg;

    public class AudioOnClick implements View.OnClickListener {
        private String path;

        public AudioOnClick(String str) {
            this.path = str;
        }

        public /* synthetic */ void a() {
            PictureSelectorActivity.this.stop(this.path);
        }

        public void onClick(View view) {
            Handler handler;
            int id = view.getId();
            if (id == R.id.tv_PlayPause) {
                PictureSelectorActivity.this.playAudio();
            }
            if (id == R.id.tv_Stop) {
                PictureSelectorActivity pictureSelectorActivity = PictureSelectorActivity.this;
                pictureSelectorActivity.mTvMusicStatus.setText(pictureSelectorActivity.getString(R.string.picture_stop_audio));
                PictureSelectorActivity pictureSelectorActivity2 = PictureSelectorActivity.this;
                pictureSelectorActivity2.mTvPlayPause.setText(pictureSelectorActivity2.getString(R.string.picture_play_audio));
                PictureSelectorActivity.this.stop(this.path);
            }
            if (id == R.id.tv_Quit && (handler = PictureSelectorActivity.this.mHandler) != null) {
                handler.postDelayed(new w(this), 30);
                try {
                    PictureCustomDialog pictureCustomDialog = PictureSelectorActivity.this.audioDialog;
                    if (pictureCustomDialog != null && pictureCustomDialog.isShowing()) {
                        PictureSelectorActivity.this.audioDialog.dismiss();
                    }
                } catch (Exception e2) {
                    e2.printStackTrace();
                }
                PictureSelectorActivity pictureSelectorActivity3 = PictureSelectorActivity.this;
                pictureSelectorActivity3.mHandler.removeCallbacks(pictureSelectorActivity3.mRunnable);
            }
        }
    }

    private void AudioDialog(String str) {
        if (!isFinishing()) {
            PictureCustomDialog pictureCustomDialog = new PictureCustomDialog(getContext(), R.layout.picture_audio_dialog);
            this.audioDialog = pictureCustomDialog;
            if (pictureCustomDialog.getWindow() != null) {
                this.audioDialog.getWindow().setWindowAnimations(R.style.Picture_Theme_Dialog_AudioStyle);
            }
            this.mTvMusicStatus = (TextView) this.audioDialog.findViewById(R.id.tv_musicStatus);
            this.mTvMusicTime = (TextView) this.audioDialog.findViewById(R.id.tv_musicTime);
            this.musicSeekBar = (SeekBar) this.audioDialog.findViewById(R.id.musicSeekBar);
            this.mTvMusicTotal = (TextView) this.audioDialog.findViewById(R.id.tv_musicTotal);
            this.mTvPlayPause = (TextView) this.audioDialog.findViewById(R.id.tv_PlayPause);
            this.mTvStop = (TextView) this.audioDialog.findViewById(R.id.tv_Stop);
            this.mTvQuit = (TextView) this.audioDialog.findViewById(R.id.tv_Quit);
            Handler handler = this.mHandler;
            if (handler != null) {
                handler.postDelayed(new c0(this, str), 30);
            }
            this.mTvPlayPause.setOnClickListener(new AudioOnClick(str));
            this.mTvStop.setOnClickListener(new AudioOnClick(str));
            this.mTvQuit.setOnClickListener(new AudioOnClick(str));
            this.musicSeekBar.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
                /* class com.luck.picture.lib.PictureSelectorActivity.AnonymousClass3 */

                public void onProgressChanged(SeekBar seekBar, int i2, boolean z) {
                    if (z) {
                        PictureSelectorActivity.this.mediaPlayer.seekTo(i2);
                    }
                }

                public void onStartTrackingTouch(SeekBar seekBar) {
                }

                public void onStopTrackingTouch(SeekBar seekBar) {
                }
            });
            this.audioDialog.setOnDismissListener(new v(this, str));
            Handler handler2 = this.mHandler;
            if (handler2 != null) {
                handler2.post(this.mRunnable);
            }
            this.audioDialog.show();
        }
    }

    private void bothMimeTypeWith(boolean z, List<LocalMedia> list) {
        int i2 = 0;
        LocalMedia localMedia = list.size() > 0 ? list.get(0) : null;
        if (localMedia != null) {
            PictureSelectionConfig pictureSelectionConfig = this.config;
            if (pictureSelectionConfig.enableCrop) {
                if (pictureSelectionConfig.selectionMode != 1 || !z) {
                    ArrayList<CutInfo> arrayList = new ArrayList<>();
                    int size = list.size();
                    int i3 = 0;
                    while (i2 < size) {
                        LocalMedia localMedia2 = list.get(i2);
                        if (localMedia2 != null && !TextUtils.isEmpty(localMedia2.getPath())) {
                            if (PictureMimeType.isHasImage(localMedia2.getMimeType())) {
                                i3++;
                            }
                            CutInfo cutInfo = new CutInfo();
                            cutInfo.setId(localMedia2.getId());
                            cutInfo.setPath(localMedia2.getPath());
                            cutInfo.setImageWidth(localMedia2.getWidth());
                            cutInfo.setImageHeight(localMedia2.getHeight());
                            cutInfo.setMimeType(localMedia2.getMimeType());
                            cutInfo.setDuration(localMedia2.getDuration());
                            cutInfo.setRealPath(localMedia2.getRealPath());
                            arrayList.add(cutInfo);
                        }
                        i2++;
                    }
                    if (i3 <= 0) {
                        onResult(list);
                    } else {
                        startCrop(arrayList);
                    }
                } else {
                    pictureSelectionConfig.originalPath = localMedia.getPath();
                    startCrop(this.config.originalPath, localMedia.getMimeType());
                }
            } else if (pictureSelectionConfig.isCompress) {
                int size2 = list.size();
                int i4 = 0;
                while (true) {
                    if (i4 >= size2) {
                        break;
                    } else if (PictureMimeType.isHasImage(list.get(i4).getMimeType())) {
                        i2 = 1;
                        break;
                    } else {
                        i4++;
                    }
                }
                if (i2 <= 0) {
                    onResult(list);
                } else {
                    compressImage(list);
                }
            } else {
                onResult(list);
            }
        }
    }

    private boolean checkVideoLegitimacy(LocalMedia localMedia) {
        if (!PictureMimeType.isHasVideo(localMedia.getMimeType())) {
            return true;
        }
        PictureSelectionConfig pictureSelectionConfig = this.config;
        int i2 = pictureSelectionConfig.videoMinSecond;
        if (i2 <= 0 || pictureSelectionConfig.videoMaxSecond <= 0) {
            if (i2 > 0) {
                long duration = localMedia.getDuration();
                int i3 = this.config.videoMinSecond;
                if (duration >= ((long) i3)) {
                    return true;
                }
                showPromptDialog(getString(R.string.picture_choose_min_seconds, new Object[]{Integer.valueOf(i3 / 1000)}));
            } else if (pictureSelectionConfig.videoMaxSecond <= 0) {
                return true;
            } else {
                long duration2 = localMedia.getDuration();
                int i4 = this.config.videoMaxSecond;
                if (duration2 <= ((long) i4)) {
                    return true;
                }
                showPromptDialog(getString(R.string.picture_choose_max_seconds, new Object[]{Integer.valueOf(i4 / 1000)}));
            }
        } else if (localMedia.getDuration() >= ((long) this.config.videoMinSecond) && localMedia.getDuration() <= ((long) this.config.videoMaxSecond)) {
            return true;
        } else {
            showPromptDialog(getString(R.string.picture_choose_limit_seconds, new Object[]{Integer.valueOf(this.config.videoMinSecond / 1000), Integer.valueOf(this.config.videoMaxSecond / 1000)}));
        }
        return false;
    }

    private void dispatchHandleCamera(final Intent intent) {
        PictureSelectionConfig pictureSelectionConfig = intent != null ? (PictureSelectionConfig) intent.getParcelableExtra(PictureConfig.EXTRA_CONFIG) : null;
        if (pictureSelectionConfig != null) {
            this.config = pictureSelectionConfig;
        }
        final boolean z = this.config.chooseMode == PictureMimeType.ofAudio();
        PictureSelectionConfig pictureSelectionConfig2 = this.config;
        pictureSelectionConfig2.cameraPath = z ? getAudioPath(intent) : pictureSelectionConfig2.cameraPath;
        if (!TextUtils.isEmpty(this.config.cameraPath)) {
            showPleaseDialog();
            PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<LocalMedia>() {
                /* class com.luck.picture.lib.PictureSelectorActivity.AnonymousClass5 */

                @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                public LocalMedia doInBackground() {
                    LocalMedia localMedia = new LocalMedia();
                    boolean z = z;
                    String str = z ? PictureMimeType.MIME_TYPE_AUDIO : "";
                    int[] iArr = new int[2];
                    long j2 = 0;
                    if (!z) {
                        if (PictureMimeType.isContent(PictureSelectorActivity.this.config.cameraPath)) {
                            String path = PictureFileUtils.getPath(PictureSelectorActivity.this.getContext(), Uri.parse(PictureSelectorActivity.this.config.cameraPath));
                            if (!TextUtils.isEmpty(path)) {
                                File file = new File(path);
                                String mimeType = PictureMimeType.getMimeType(PictureSelectorActivity.this.config.cameraMimeType);
                                localMedia.setSize(file.length());
                                str = mimeType;
                            }
                            if (PictureMimeType.isHasImage(str)) {
                                iArr = MediaUtils.getImageSizeForUrlToAndroidQ(PictureSelectorActivity.this.getContext(), PictureSelectorActivity.this.config.cameraPath);
                            } else if (PictureMimeType.isHasVideo(str)) {
                                iArr = MediaUtils.getVideoSizeForUri(PictureSelectorActivity.this.getContext(), Uri.parse(PictureSelectorActivity.this.config.cameraPath));
                                j2 = MediaUtils.extractDuration(PictureSelectorActivity.this.getContext(), SdkVersionUtils.checkedAndroid_Q(), PictureSelectorActivity.this.config.cameraPath);
                            }
                            int lastIndexOf = PictureSelectorActivity.this.config.cameraPath.lastIndexOf("/") + 1;
                            localMedia.setId(lastIndexOf > 0 ? ValueOf.toLong(PictureSelectorActivity.this.config.cameraPath.substring(lastIndexOf)) : -1);
                            localMedia.setRealPath(path);
                            Intent intent = intent;
                            localMedia.setAndroidQToPath(intent != null ? intent.getStringExtra(PictureConfig.EXTRA_MEDIA_PATH) : null);
                        } else {
                            File file2 = new File(PictureSelectorActivity.this.config.cameraPath);
                            str = PictureMimeType.getMimeType(PictureSelectorActivity.this.config.cameraMimeType);
                            localMedia.setSize(file2.length());
                            if (PictureMimeType.isHasImage(str)) {
                                BitmapUtils.rotateImage(PictureFileUtils.readPictureDegree(PictureSelectorActivity.this.getContext(), PictureSelectorActivity.this.config.cameraPath), PictureSelectorActivity.this.config.cameraPath);
                                iArr = MediaUtils.getImageSizeForUrl(PictureSelectorActivity.this.config.cameraPath);
                            } else if (PictureMimeType.isHasVideo(str)) {
                                iArr = MediaUtils.getVideoSizeForUrl(PictureSelectorActivity.this.config.cameraPath);
                                j2 = MediaUtils.extractDuration(PictureSelectorActivity.this.getContext(), SdkVersionUtils.checkedAndroid_Q(), PictureSelectorActivity.this.config.cameraPath);
                            }
                            localMedia.setId(System.currentTimeMillis());
                        }
                        localMedia.setPath(PictureSelectorActivity.this.config.cameraPath);
                        localMedia.setDuration(j2);
                        localMedia.setMimeType(str);
                        localMedia.setWidth(iArr[0]);
                        localMedia.setHeight(iArr[1]);
                        if (!SdkVersionUtils.checkedAndroid_Q() || !PictureMimeType.isHasVideo(localMedia.getMimeType())) {
                            localMedia.setParentFolderName("Camera");
                        } else {
                            localMedia.setParentFolderName(Environment.DIRECTORY_MOVIES);
                        }
                        localMedia.setChooseModel(PictureSelectorActivity.this.config.chooseMode);
                        localMedia.setBucketId(MediaUtils.getCameraFirstBucketId(PictureSelectorActivity.this.getContext()));
                        Context context = PictureSelectorActivity.this.getContext();
                        PictureSelectionConfig pictureSelectionConfig = PictureSelectorActivity.this.config;
                        MediaUtils.setOrientationSynchronous(context, localMedia, pictureSelectionConfig.isAndroidQChangeWH, pictureSelectionConfig.isAndroidQChangeVideoWH);
                    }
                    return localMedia;
                }

                public void onSuccess(LocalMedia localMedia) {
                    int dCIMLastImageId;
                    PictureSelectorActivity.this.dismissDialog();
                    if (!SdkVersionUtils.checkedAndroid_Q()) {
                        PictureSelectorActivity pictureSelectorActivity = PictureSelectorActivity.this;
                        if (pictureSelectorActivity.config.isFallbackVersion3) {
                            new PictureMediaScannerConnection(pictureSelectorActivity.getContext(), PictureSelectorActivity.this.config.cameraPath);
                        } else {
                            pictureSelectorActivity.sendBroadcast(new Intent("android.intent.action.MEDIA_SCANNER_SCAN_FILE", Uri.fromFile(new File(PictureSelectorActivity.this.config.cameraPath))));
                        }
                    }
                    PictureSelectorActivity.this.notifyAdapterData(localMedia);
                    if (!SdkVersionUtils.checkedAndroid_Q() && PictureMimeType.isHasImage(localMedia.getMimeType()) && (dCIMLastImageId = MediaUtils.getDCIMLastImageId(PictureSelectorActivity.this.getContext())) != -1) {
                        MediaUtils.removeMedia(PictureSelectorActivity.this.getContext(), dCIMLastImageId);
                    }
                }
            });
        }
    }

    private void dispatchHandleMultiple(LocalMedia localMedia) {
        int i2;
        List<LocalMedia> selectedData = this.mAdapter.getSelectedData();
        int size = selectedData.size();
        String mimeType = size > 0 ? selectedData.get(0).getMimeType() : "";
        boolean isMimeTypeSame = PictureMimeType.isMimeTypeSame(mimeType, localMedia.getMimeType());
        if (this.config.isWithVideoImage) {
            int i3 = 0;
            for (int i4 = 0; i4 < size; i4++) {
                if (PictureMimeType.isHasVideo(selectedData.get(i4).getMimeType())) {
                    i3++;
                }
            }
            if (PictureMimeType.isHasVideo(localMedia.getMimeType())) {
                if (this.config.maxVideoSelectNum <= 0) {
                    showPromptDialog(getString(R.string.picture_rule));
                    return;
                }
                int size2 = selectedData.size();
                PictureSelectionConfig pictureSelectionConfig = this.config;
                int i5 = pictureSelectionConfig.maxSelectNum;
                if (size2 >= i5) {
                    showPromptDialog(getString(R.string.picture_message_max_num, new Object[]{Integer.valueOf(i5)}));
                } else if (i3 < pictureSelectionConfig.maxVideoSelectNum) {
                    selectedData.add(0, localMedia);
                    this.mAdapter.bindSelectData(selectedData);
                } else {
                    showPromptDialog(StringUtils.getMsg(getContext(), localMedia.getMimeType(), this.config.maxVideoSelectNum));
                }
            } else if (selectedData.size() < this.config.maxSelectNum) {
                selectedData.add(0, localMedia);
                this.mAdapter.bindSelectData(selectedData);
            } else {
                showPromptDialog(StringUtils.getMsg(getContext(), localMedia.getMimeType(), this.config.maxSelectNum));
            }
        } else if (!PictureMimeType.isHasVideo(mimeType) || (i2 = this.config.maxVideoSelectNum) <= 0) {
            if (size >= this.config.maxSelectNum) {
                showPromptDialog(StringUtils.getMsg(getContext(), mimeType, this.config.maxSelectNum));
            } else if (isMimeTypeSame || size == 0) {
                selectedData.add(0, localMedia);
                this.mAdapter.bindSelectData(selectedData);
            }
        } else if (size >= i2) {
            showPromptDialog(StringUtils.getMsg(getContext(), mimeType, this.config.maxVideoSelectNum));
        } else if ((isMimeTypeSame || size == 0) && selectedData.size() < this.config.maxVideoSelectNum) {
            selectedData.add(0, localMedia);
            this.mAdapter.bindSelectData(selectedData);
        }
    }

    private void dispatchHandleSingle(LocalMedia localMedia) {
        if (this.config.isSingleDirectReturn) {
            List<LocalMedia> selectedData = this.mAdapter.getSelectedData();
            selectedData.add(localMedia);
            this.mAdapter.bindSelectData(selectedData);
            singleDirectReturnCameraHandleResult(localMedia.getMimeType());
            return;
        }
        List<LocalMedia> selectedData2 = this.mAdapter.getSelectedData();
        if (PictureMimeType.isMimeTypeSame(selectedData2.size() > 0 ? selectedData2.get(0).getMimeType() : "", localMedia.getMimeType()) || selectedData2.size() == 0) {
            singleRadioMediaImage();
            selectedData2.add(localMedia);
            this.mAdapter.bindSelectData(selectedData2);
        }
    }

    private int getPageLimit() {
        if (ValueOf.toInt(this.mTvPictureTitle.getTag(R.id.view_tag)) != -1) {
            return this.config.pageSize;
        }
        int i2 = this.mOpenCameraCount;
        int i3 = i2 > 0 ? this.config.pageSize - i2 : this.config.pageSize;
        this.mOpenCameraCount = 0;
        return i3;
    }

    private void hideDataNull() {
        if (this.mTvEmpty.getVisibility() == 0) {
            this.mTvEmpty.setVisibility(8);
        }
    }

    private void initPageModel(List<LocalMediaFolder> list) {
        if (list != null) {
            this.folderWindow.bindFolder(list);
            this.mPage = 1;
            LocalMediaFolder folder = this.folderWindow.getFolder(0);
            this.mTvPictureTitle.setTag(R.id.view_count_tag, Integer.valueOf(folder != null ? folder.getImageNum() : 0));
            this.mTvPictureTitle.setTag(R.id.view_index_tag, 0);
            long bucketId = folder != null ? folder.getBucketId() : -1;
            this.mRecyclerView.setEnabledLoadMore(true);
            LocalMediaPageLoader.getInstance(getContext(), this.config).loadPageMediaData(bucketId, this.mPage, new a0(this));
            return;
        }
        showDataNull(getString(R.string.picture_data_exception), R.drawable.picture_icon_data_error);
        dismissDialog();
    }

    /* access modifiers changed from: private */
    /* renamed from: initPlayer */
    public void C(String str) {
        MediaPlayer mediaPlayer2 = new MediaPlayer();
        this.mediaPlayer = mediaPlayer2;
        try {
            mediaPlayer2.setDataSource(str);
            this.mediaPlayer.prepare();
            this.mediaPlayer.setLooping(true);
            playAudio();
        } catch (Exception e2) {
            e2.printStackTrace();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void initStandardModel(List<LocalMediaFolder> list) {
        if (list == null) {
            showDataNull(getString(R.string.picture_data_exception), R.drawable.picture_icon_data_error);
        } else if (list.size() > 0) {
            this.folderWindow.bindFolder(list);
            LocalMediaFolder localMediaFolder = list.get(0);
            localMediaFolder.setChecked(true);
            this.mTvPictureTitle.setTag(R.id.view_count_tag, Integer.valueOf(localMediaFolder.getImageNum()));
            List<LocalMedia> data = localMediaFolder.getData();
            PictureImageGridAdapter pictureImageGridAdapter = this.mAdapter;
            if (pictureImageGridAdapter != null) {
                int size = pictureImageGridAdapter.getSize();
                int size2 = data.size();
                int i2 = this.oldCurrentListSize + size;
                this.oldCurrentListSize = i2;
                if (size2 >= size) {
                    if (size <= 0 || size >= size2 || i2 == size2) {
                        this.mAdapter.bindData(data);
                    } else {
                        this.mAdapter.getData().addAll(data);
                        LocalMedia localMedia = this.mAdapter.getData().get(0);
                        localMediaFolder.setFirstImagePath(localMedia.getPath());
                        localMediaFolder.getData().add(0, localMedia);
                        localMediaFolder.setCheckedNum(1);
                        localMediaFolder.setImageNum(localMediaFolder.getImageNum() + 1);
                        updateMediaFolder(this.folderWindow.getFolderData(), localMedia);
                    }
                }
                if (this.mAdapter.isDataEmpty()) {
                    showDataNull(getString(R.string.picture_empty), R.drawable.picture_icon_no_data);
                } else {
                    hideDataNull();
                }
            }
        } else {
            showDataNull(getString(R.string.picture_empty), R.drawable.picture_icon_no_data);
        }
        dismissDialog();
    }

    private boolean isAddSameImp(int i2) {
        int i3;
        return i2 != 0 && (i3 = this.allFolderSize) > 0 && i3 < i2;
    }

    private boolean isCurrentCacheFolderData(int i2) {
        this.mTvPictureTitle.setTag(R.id.view_index_tag, Integer.valueOf(i2));
        LocalMediaFolder folder = this.folderWindow.getFolder(i2);
        if (folder == null || folder.getData() == null || folder.getData().size() <= 0) {
            return false;
        }
        this.mAdapter.bindData(folder.getData());
        this.mPage = folder.getCurrentDataPage();
        this.isHasMore = folder.isHasMore();
        this.mRecyclerView.smoothScrollToPosition(0);
        return true;
    }

    private boolean isLocalMediaSame(LocalMedia localMedia) {
        LocalMedia item = this.mAdapter.getItem(0);
        if (!(item == null || localMedia == null)) {
            if (item.getPath().equals(localMedia.getPath())) {
                return true;
            }
            if (!PictureMimeType.isContent(localMedia.getPath()) || !PictureMimeType.isContent(item.getPath()) || TextUtils.isEmpty(localMedia.getPath()) || TextUtils.isEmpty(item.getPath()) || !localMedia.getPath().substring(localMedia.getPath().lastIndexOf("/") + 1).equals(item.getPath().substring(item.getPath().lastIndexOf("/") + 1))) {
                return false;
            }
            return true;
        }
        return false;
    }

    private void isNumComplete(boolean z) {
        if (z) {
            initCompleteText(0);
        }
    }

    private void loadAllMediaData() {
        if (!PermissionChecker.checkSelfPermission(this, "android.permission.READ_EXTERNAL_STORAGE") || !PermissionChecker.checkSelfPermission(this, "android.permission.WRITE_EXTERNAL_STORAGE")) {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.READ_EXTERNAL_STORAGE", "android.permission.WRITE_EXTERNAL_STORAGE"}, 1);
        } else {
            readLocalMedia();
        }
    }

    private void loadMoreData() {
        if (this.mAdapter != null && this.isHasMore) {
            this.mPage++;
            long j2 = ValueOf.toLong(this.mTvPictureTitle.getTag(R.id.view_tag));
            LocalMediaPageLoader.getInstance(getContext(), this.config).loadPageMediaData(j2, this.mPage, getPageLimit(), new d0(this, j2));
        }
    }

    private void manualSaveFolder(LocalMedia localMedia) {
        LocalMediaFolder localMediaFolder;
        try {
            boolean isEmpty = this.folderWindow.isEmpty();
            int imageNum = this.folderWindow.getFolder(0) != null ? this.folderWindow.getFolder(0).getImageNum() : 0;
            if (isEmpty) {
                createNewFolder(this.folderWindow.getFolderData());
                localMediaFolder = this.folderWindow.getFolderData().size() > 0 ? this.folderWindow.getFolderData().get(0) : null;
                if (localMediaFolder == null) {
                    localMediaFolder = new LocalMediaFolder();
                    this.folderWindow.getFolderData().add(0, localMediaFolder);
                }
            } else {
                localMediaFolder = this.folderWindow.getFolderData().get(0);
            }
            localMediaFolder.setFirstImagePath(localMedia.getPath());
            localMediaFolder.setData(this.mAdapter.getData());
            localMediaFolder.setBucketId(-1);
            localMediaFolder.setImageNum(isAddSameImp(imageNum) ? localMediaFolder.getImageNum() : localMediaFolder.getImageNum() + 1);
            LocalMediaFolder imageFolder = getImageFolder(localMedia.getPath(), localMedia.getRealPath(), this.folderWindow.getFolderData());
            if (imageFolder != null) {
                imageFolder.setImageNum(isAddSameImp(imageNum) ? imageFolder.getImageNum() : imageFolder.getImageNum() + 1);
                if (!isAddSameImp(imageNum)) {
                    imageFolder.getData().add(0, localMedia);
                }
                imageFolder.setBucketId(localMedia.getBucketId());
                imageFolder.setFirstImagePath(this.config.cameraPath);
            }
            FolderPopWindow folderPopWindow = this.folderWindow;
            folderPopWindow.bindFolder(folderPopWindow.getFolderData());
        } catch (Exception e2) {
            e2.printStackTrace();
        }
    }

    private void manualSaveFolderForPageModel(LocalMedia localMedia) {
        int i2;
        if (localMedia != null) {
            int size = this.folderWindow.getFolderData().size();
            boolean z = false;
            LocalMediaFolder localMediaFolder = size > 0 ? this.folderWindow.getFolderData().get(0) : new LocalMediaFolder();
            if (localMediaFolder != null) {
                int imageNum = localMediaFolder.getImageNum();
                localMediaFolder.setFirstImagePath(localMedia.getPath());
                localMediaFolder.setImageNum(isAddSameImp(imageNum) ? localMediaFolder.getImageNum() : localMediaFolder.getImageNum() + 1);
                if (size == 0) {
                    if (this.config.chooseMode == PictureMimeType.ofAudio()) {
                        i2 = R.string.picture_all_audio;
                    } else {
                        i2 = R.string.picture_camera_roll;
                    }
                    localMediaFolder.setName(getString(i2));
                    localMediaFolder.setOfAllType(this.config.chooseMode);
                    localMediaFolder.setCameraFolder(true);
                    localMediaFolder.setChecked(true);
                    localMediaFolder.setBucketId(-1);
                    this.folderWindow.getFolderData().add(0, localMediaFolder);
                    LocalMediaFolder localMediaFolder2 = new LocalMediaFolder();
                    localMediaFolder2.setName(localMedia.getParentFolderName());
                    localMediaFolder2.setImageNum(isAddSameImp(imageNum) ? localMediaFolder2.getImageNum() : localMediaFolder2.getImageNum() + 1);
                    localMediaFolder2.setFirstImagePath(localMedia.getPath());
                    localMediaFolder2.setBucketId(localMedia.getBucketId());
                    this.folderWindow.getFolderData().add(this.folderWindow.getFolderData().size(), localMediaFolder2);
                } else {
                    String str = (!SdkVersionUtils.checkedAndroid_Q() || !PictureMimeType.isHasVideo(localMedia.getMimeType())) ? "Camera" : Environment.DIRECTORY_MOVIES;
                    int i3 = 0;
                    while (true) {
                        if (i3 >= size) {
                            break;
                        }
                        LocalMediaFolder localMediaFolder3 = this.folderWindow.getFolderData().get(i3);
                        if (localMediaFolder3.getName().startsWith(str)) {
                            localMedia.setBucketId(localMediaFolder3.getBucketId());
                            localMediaFolder3.setFirstImagePath(this.config.cameraPath);
                            localMediaFolder3.setImageNum(isAddSameImp(imageNum) ? localMediaFolder3.getImageNum() : localMediaFolder3.getImageNum() + 1);
                            if (localMediaFolder3.getData() != null && localMediaFolder3.getData().size() > 0) {
                                localMediaFolder3.getData().add(0, localMedia);
                            }
                            z = true;
                        } else {
                            i3++;
                        }
                    }
                    if (!z) {
                        LocalMediaFolder localMediaFolder4 = new LocalMediaFolder();
                        localMediaFolder4.setName(localMedia.getParentFolderName());
                        localMediaFolder4.setImageNum(isAddSameImp(imageNum) ? localMediaFolder4.getImageNum() : localMediaFolder4.getImageNum() + 1);
                        localMediaFolder4.setFirstImagePath(localMedia.getPath());
                        localMediaFolder4.setBucketId(localMedia.getBucketId());
                        this.folderWindow.getFolderData().add(localMediaFolder4);
                        sortFolder(this.folderWindow.getFolderData());
                    }
                }
                FolderPopWindow folderPopWindow = this.folderWindow;
                folderPopWindow.bindFolder(folderPopWindow.getFolderData());
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void notifyAdapterData(LocalMedia localMedia) {
        if (this.mAdapter != null) {
            if (!isAddSameImp(this.folderWindow.getFolder(0) != null ? this.folderWindow.getFolder(0).getImageNum() : 0)) {
                this.mAdapter.getData().add(0, localMedia);
                this.mOpenCameraCount++;
            }
            if (checkVideoLegitimacy(localMedia)) {
                if (this.config.selectionMode == 1) {
                    dispatchHandleSingle(localMedia);
                } else {
                    dispatchHandleMultiple(localMedia);
                }
            }
            this.mAdapter.notifyItemInserted(this.config.isCamera ? 1 : 0);
            PictureImageGridAdapter pictureImageGridAdapter = this.mAdapter;
            pictureImageGridAdapter.notifyItemRangeChanged(this.config.isCamera ? 1 : 0, pictureImageGridAdapter.getSize());
            if (this.config.isPageStrategy) {
                manualSaveFolderForPageModel(localMedia);
            } else {
                manualSaveFolder(localMedia);
            }
            this.mTvEmpty.setVisibility((this.mAdapter.getSize() > 0 || this.config.isSingleDirectReturn) ? 8 : 0);
            if (this.folderWindow.getFolder(0) != null) {
                this.mTvPictureTitle.setTag(R.id.view_count_tag, Integer.valueOf(this.folderWindow.getFolder(0).getImageNum()));
            }
            this.allFolderSize = 0;
        }
    }

    private void onComplete() {
        int i2;
        int i3;
        List<LocalMedia> selectedData = this.mAdapter.getSelectedData();
        int size = selectedData.size();
        LocalMedia localMedia = selectedData.size() > 0 ? selectedData.get(0) : null;
        String mimeType = localMedia != null ? localMedia.getMimeType() : "";
        boolean isHasImage = PictureMimeType.isHasImage(mimeType);
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig.isWithVideoImage) {
            int i4 = 0;
            int i5 = 0;
            for (int i6 = 0; i6 < size; i6++) {
                if (PictureMimeType.isHasVideo(selectedData.get(i6).getMimeType())) {
                    i5++;
                } else {
                    i4++;
                }
            }
            PictureSelectionConfig pictureSelectionConfig2 = this.config;
            if (pictureSelectionConfig2.selectionMode == 2) {
                int i7 = pictureSelectionConfig2.minSelectNum;
                if (i7 <= 0 || i4 >= i7) {
                    int i8 = pictureSelectionConfig2.minVideoSelectNum;
                    if (i8 > 0 && i5 < i8) {
                        showPromptDialog(getString(R.string.picture_min_video_num, new Object[]{Integer.valueOf(i8)}));
                        return;
                    }
                } else {
                    showPromptDialog(getString(R.string.picture_min_img_num, new Object[]{Integer.valueOf(i7)}));
                    return;
                }
            }
        } else if (pictureSelectionConfig.selectionMode == 2) {
            if (PictureMimeType.isHasImage(mimeType) && (i3 = this.config.minSelectNum) > 0 && size < i3) {
                showPromptDialog(getString(R.string.picture_min_img_num, new Object[]{Integer.valueOf(i3)}));
                return;
            } else if (PictureMimeType.isHasVideo(mimeType) && (i2 = this.config.minVideoSelectNum) > 0 && size < i2) {
                showPromptDialog(getString(R.string.picture_min_video_num, new Object[]{Integer.valueOf(i2)}));
                return;
            }
        }
        PictureSelectionConfig pictureSelectionConfig3 = this.config;
        if (pictureSelectionConfig3.returnEmpty && size == 0) {
            if (pictureSelectionConfig3.selectionMode == 2) {
                int i9 = pictureSelectionConfig3.minSelectNum;
                if (i9 <= 0 || size >= i9) {
                    int i10 = pictureSelectionConfig3.minVideoSelectNum;
                    if (i10 > 0 && size < i10) {
                        showPromptDialog(getString(R.string.picture_min_video_num, new Object[]{Integer.valueOf(i10)}));
                        return;
                    }
                } else {
                    showPromptDialog(getString(R.string.picture_min_img_num, new Object[]{Integer.valueOf(i9)}));
                    return;
                }
            }
            OnResultCallbackListener onResultCallbackListener = PictureSelectionConfig.listener;
            if (onResultCallbackListener != null) {
                onResultCallbackListener.onResult(selectedData);
            } else {
                setResult(-1, PictureSelector.putIntentResult(selectedData));
            }
            closeActivity();
        } else if (pictureSelectionConfig3.isCheckOriginalImage) {
            onResult(selectedData);
        } else if (pictureSelectionConfig3.chooseMode != PictureMimeType.ofAll() || !this.config.isWithVideoImage) {
            separateMimeTypeWith(isHasImage, selectedData);
        } else {
            bothMimeTypeWith(isHasImage, selectedData);
        }
    }

    private void onPreview() {
        int i2;
        List<LocalMedia> selectedData = this.mAdapter.getSelectedData();
        ArrayList<? extends Parcelable> arrayList = new ArrayList<>();
        int size = selectedData.size();
        for (int i3 = 0; i3 < size; i3++) {
            arrayList.add(selectedData.get(i3));
        }
        OnCustomImagePreviewCallback onCustomImagePreviewCallback = PictureSelectionConfig.onCustomImagePreviewCallback;
        if (onCustomImagePreviewCallback != null) {
            onCustomImagePreviewCallback.onCustomPreviewCallback(getContext(), selectedData, 0);
            return;
        }
        Bundle bundle = new Bundle();
        bundle.putParcelableArrayList(PictureConfig.EXTRA_PREVIEW_SELECT_LIST, arrayList);
        bundle.putParcelableArrayList(PictureConfig.EXTRA_SELECT_LIST, (ArrayList) selectedData);
        bundle.putBoolean(PictureConfig.EXTRA_BOTTOM_PREVIEW, true);
        bundle.putBoolean(PictureConfig.EXTRA_CHANGE_ORIGINAL, this.config.isCheckOriginalImage);
        bundle.putBoolean(PictureConfig.EXTRA_SHOW_CAMERA, this.mAdapter.isShowCamera());
        bundle.putString(PictureConfig.EXTRA_IS_CURRENT_DIRECTORY, this.mTvPictureTitle.getText().toString());
        Context context = getContext();
        PictureSelectionConfig pictureSelectionConfig = this.config;
        JumpUtils.startPicturePreviewActivity(context, pictureSelectionConfig.isWeChatStyle, bundle, pictureSelectionConfig.selectionMode == 1 ? 69 : UCrop.REQUEST_MULTI_CROP);
        PictureWindowAnimationStyle pictureWindowAnimationStyle = this.config.windowAnimationStyle;
        if (pictureWindowAnimationStyle == null || (i2 = pictureWindowAnimationStyle.activityPreviewEnterAnimation) == 0) {
            i2 = R.anim.picture_anim_enter;
        }
        overridePendingTransition(i2, R.anim.picture_anim_fade_in);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void playAudio() {
        MediaPlayer mediaPlayer2 = this.mediaPlayer;
        if (mediaPlayer2 != null) {
            this.musicSeekBar.setProgress(mediaPlayer2.getCurrentPosition());
            this.musicSeekBar.setMax(this.mediaPlayer.getDuration());
        }
        String charSequence = this.mTvPlayPause.getText().toString();
        int i2 = R.string.picture_play_audio;
        if (charSequence.equals(getString(i2))) {
            this.mTvPlayPause.setText(getString(R.string.picture_pause_audio));
            this.mTvMusicStatus.setText(getString(i2));
            playOrPause();
        } else {
            this.mTvPlayPause.setText(getString(i2));
            this.mTvMusicStatus.setText(getString(R.string.picture_pause_audio));
            playOrPause();
        }
        if (!this.isPlayAudio) {
            Handler handler = this.mHandler;
            if (handler != null) {
                handler.post(this.mRunnable);
            }
            this.isPlayAudio = true;
        }
    }

    private void previewCallback(Intent intent) {
        if (intent != null) {
            PictureSelectionConfig pictureSelectionConfig = this.config;
            if (pictureSelectionConfig.isOriginalControl) {
                pictureSelectionConfig.isCheckOriginalImage = intent.getBooleanExtra(PictureConfig.EXTRA_CHANGE_ORIGINAL, pictureSelectionConfig.isCheckOriginalImage);
                this.mCbOriginal.setChecked(this.config.isCheckOriginalImage);
            }
            ArrayList parcelableArrayListExtra = intent.getParcelableArrayListExtra(PictureConfig.EXTRA_SELECT_LIST);
            if (this.mAdapter != null && parcelableArrayListExtra != null) {
                char c2 = 0;
                if (intent.getBooleanExtra(PictureConfig.EXTRA_COMPLETE_SELECTED, false)) {
                    onChangeData(parcelableArrayListExtra);
                    if (this.config.isWithVideoImage) {
                        int size = parcelableArrayListExtra.size();
                        int i2 = 0;
                        while (true) {
                            if (i2 >= size) {
                                break;
                            } else if (PictureMimeType.isHasImage(parcelableArrayListExtra.get(i2).getMimeType())) {
                                c2 = 1;
                                break;
                            } else {
                                i2++;
                            }
                        }
                        if (c2 > 0) {
                            PictureSelectionConfig pictureSelectionConfig2 = this.config;
                            if (pictureSelectionConfig2.isCompress && !pictureSelectionConfig2.isCheckOriginalImage) {
                                compressImage(parcelableArrayListExtra);
                            }
                        }
                        onResult(parcelableArrayListExtra);
                    } else {
                        String mimeType = parcelableArrayListExtra.size() > 0 ? parcelableArrayListExtra.get(0).getMimeType() : "";
                        if (!this.config.isCompress || !PictureMimeType.isHasImage(mimeType) || this.config.isCheckOriginalImage) {
                            onResult(parcelableArrayListExtra);
                        } else {
                            compressImage(parcelableArrayListExtra);
                        }
                    }
                } else {
                    this.isStartAnimation = true;
                }
                this.mAdapter.bindSelectData(parcelableArrayListExtra);
                this.mAdapter.notifyDataSetChanged();
            }
        }
    }

    private void separateMimeTypeWith(boolean z, List<LocalMedia> list) {
        LocalMedia localMedia = list.size() > 0 ? list.get(0) : null;
        if (localMedia != null) {
            PictureSelectionConfig pictureSelectionConfig = this.config;
            if (!pictureSelectionConfig.enableCrop || !z) {
                if (!pictureSelectionConfig.isCompress || !z) {
                    onResult(list);
                } else {
                    compressImage(list);
                }
            } else if (pictureSelectionConfig.selectionMode == 1) {
                pictureSelectionConfig.originalPath = localMedia.getPath();
                startCrop(this.config.originalPath, localMedia.getMimeType());
            } else {
                ArrayList<CutInfo> arrayList = new ArrayList<>();
                int size = list.size();
                for (int i2 = 0; i2 < size; i2++) {
                    LocalMedia localMedia2 = list.get(i2);
                    if (localMedia2 != null && !TextUtils.isEmpty(localMedia2.getPath())) {
                        CutInfo cutInfo = new CutInfo();
                        cutInfo.setId(localMedia2.getId());
                        cutInfo.setPath(localMedia2.getPath());
                        cutInfo.setImageWidth(localMedia2.getWidth());
                        cutInfo.setImageHeight(localMedia2.getHeight());
                        cutInfo.setMimeType(localMedia2.getMimeType());
                        cutInfo.setDuration(localMedia2.getDuration());
                        cutInfo.setRealPath(localMedia2.getRealPath());
                        arrayList.add(cutInfo);
                    }
                }
                startCrop(arrayList);
            }
        }
    }

    private void setLastCacheFolderData() {
        LocalMediaFolder folder = this.folderWindow.getFolder(ValueOf.toInt(this.mTvPictureTitle.getTag(R.id.view_index_tag)));
        folder.setData(this.mAdapter.getData());
        folder.setCurrentDataPage(this.mPage);
        folder.setHasMore(this.isHasMore);
    }

    private void showDataNull(String str, int i2) {
        if (this.mTvEmpty.getVisibility() == 8 || this.mTvEmpty.getVisibility() == 4) {
            this.mTvEmpty.setCompoundDrawablesRelativeWithIntrinsicBounds(0, i2, 0, 0);
            this.mTvEmpty.setText(str);
            this.mTvEmpty.setVisibility(0);
        }
    }

    private void singleCropHandleResult(Intent intent) {
        Uri output;
        if (intent != null && (output = UCrop.getOutput(intent)) != null) {
            ArrayList arrayList = new ArrayList();
            String path = output.getPath();
            if (this.mAdapter != null) {
                ArrayList parcelableArrayListExtra = intent.getParcelableArrayListExtra(PictureConfig.EXTRA_SELECT_LIST);
                if (parcelableArrayListExtra != null) {
                    this.mAdapter.bindSelectData(parcelableArrayListExtra);
                    this.mAdapter.notifyDataSetChanged();
                }
                List<LocalMedia> selectedData = this.mAdapter.getSelectedData();
                LocalMedia localMedia = null;
                LocalMedia localMedia2 = (selectedData == null || selectedData.size() <= 0) ? null : selectedData.get(0);
                long j2 = 0;
                if (localMedia2 != null) {
                    this.config.originalPath = localMedia2.getPath();
                    localMedia2.setCutPath(path);
                    localMedia2.setChooseModel(this.config.chooseMode);
                    boolean z = !TextUtils.isEmpty(path);
                    if (!SdkVersionUtils.checkedAndroid_Q() || !PictureMimeType.isContent(localMedia2.getPath())) {
                        if (z) {
                            j2 = new File(path).length();
                        }
                        localMedia2.setSize(j2);
                    } else {
                        if (z) {
                            localMedia2.setSize(new File(path).length());
                        } else {
                            if (!TextUtils.isEmpty(localMedia2.getRealPath())) {
                                j2 = new File(localMedia2.getRealPath()).length();
                            }
                            localMedia2.setSize(j2);
                        }
                        localMedia2.setAndroidQToPath(path);
                    }
                    localMedia2.setCut(z);
                    arrayList.add(localMedia2);
                    handlerResult(arrayList);
                    return;
                }
                if (parcelableArrayListExtra != null && parcelableArrayListExtra.size() > 0) {
                    localMedia = (LocalMedia) parcelableArrayListExtra.get(0);
                }
                if (localMedia != null) {
                    this.config.originalPath = localMedia.getPath();
                    localMedia.setCutPath(path);
                    localMedia.setChooseModel(this.config.chooseMode);
                    boolean z2 = !TextUtils.isEmpty(path);
                    if (!SdkVersionUtils.checkedAndroid_Q() || !PictureMimeType.isContent(localMedia.getPath())) {
                        if (z2) {
                            j2 = new File(path).length();
                        }
                        localMedia.setSize(j2);
                    } else {
                        if (z2) {
                            localMedia.setSize(new File(path).length());
                        } else {
                            if (!TextUtils.isEmpty(localMedia.getRealPath())) {
                                j2 = new File(localMedia.getRealPath()).length();
                            }
                            localMedia.setSize(j2);
                        }
                        localMedia.setAndroidQToPath(path);
                    }
                    localMedia.setCut(z2);
                    arrayList.add(localMedia);
                    handlerResult(arrayList);
                }
            }
        }
    }

    private void singleDirectReturnCameraHandleResult(String str) {
        boolean isHasImage = PictureMimeType.isHasImage(str);
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig.enableCrop && isHasImage) {
            String str2 = pictureSelectionConfig.cameraPath;
            pictureSelectionConfig.originalPath = str2;
            startCrop(str2, str);
        } else if (!pictureSelectionConfig.isCompress || !isHasImage) {
            onResult(this.mAdapter.getSelectedData());
        } else {
            compressImage(this.mAdapter.getSelectedData());
        }
    }

    private void singleRadioMediaImage() {
        List<LocalMedia> selectedData = this.mAdapter.getSelectedData();
        if (selectedData != null && selectedData.size() > 0) {
            int position = selectedData.get(0).getPosition();
            selectedData.clear();
            this.mAdapter.notifyItemChanged(position);
        }
    }

    private void startCustomCamera() {
        int i2;
        if (PermissionChecker.checkSelfPermission(this, "android.permission.RECORD_AUDIO")) {
            startActivityForResult(new Intent(this, PictureCustomCameraActivity.class), PictureConfig.REQUEST_CAMERA);
            PictureWindowAnimationStyle pictureWindowAnimationStyle = this.config.windowAnimationStyle;
            if (pictureWindowAnimationStyle == null || (i2 = pictureWindowAnimationStyle.activityEnterAnimation) == 0) {
                i2 = R.anim.picture_anim_enter;
            }
            overridePendingTransition(i2, R.anim.picture_anim_fade_in);
            return;
        }
        PermissionChecker.requestPermissions(this, new String[]{"android.permission.RECORD_AUDIO"}, 4);
    }

    private void synchronousCover() {
        if (this.config.chooseMode == PictureMimeType.ofAll()) {
            PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<Boolean>() {
                /* class com.luck.picture.lib.PictureSelectorActivity.AnonymousClass2 */

                public void onSuccess(Boolean bool) {
                }

                @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                public Boolean doInBackground() {
                    int size = PictureSelectorActivity.this.folderWindow.getFolderData().size();
                    for (int i2 = 0; i2 < size; i2++) {
                        LocalMediaFolder folder = PictureSelectorActivity.this.folderWindow.getFolder(i2);
                        if (folder != null) {
                            folder.setFirstImagePath(LocalMediaPageLoader.getInstance(PictureSelectorActivity.this.getContext(), PictureSelectorActivity.this.config).getFirstCover(folder.getBucketId()));
                        }
                    }
                    return Boolean.TRUE;
                }
            });
        }
    }

    private void updateMediaFolder(List<LocalMediaFolder> list, LocalMedia localMedia) {
        File parentFile = new File(localMedia.getRealPath()).getParentFile();
        if (parentFile != null) {
            int size = list.size();
            for (int i2 = 0; i2 < size; i2++) {
                LocalMediaFolder localMediaFolder = list.get(i2);
                String name = localMediaFolder.getName();
                if (!TextUtils.isEmpty(name) && name.equals(parentFile.getName())) {
                    localMediaFolder.setFirstImagePath(this.config.cameraPath);
                    localMediaFolder.setImageNum(localMediaFolder.getImageNum() + 1);
                    localMediaFolder.setCheckedNum(1);
                    localMediaFolder.getData().add(0, localMedia);
                    return;
                }
            }
        }
    }

    public /* synthetic */ void D(List list, int i2, boolean z) {
        if (!isFinishing()) {
            dismissDialog();
            if (this.mAdapter != null) {
                this.isHasMore = true;
                if (!z || list.size() != 0) {
                    int size = this.mAdapter.getSize();
                    int size2 = list.size();
                    int i3 = this.oldCurrentListSize + size;
                    this.oldCurrentListSize = i3;
                    if (size2 >= size) {
                        if (size <= 0 || size >= size2 || i3 == size2) {
                            this.mAdapter.bindData(list);
                        } else if (isLocalMediaSame((LocalMedia) list.get(0))) {
                            this.mAdapter.bindData(list);
                        } else {
                            this.mAdapter.getData().addAll(list);
                        }
                    }
                    if (this.mAdapter.isDataEmpty()) {
                        showDataNull(getString(R.string.picture_empty), R.drawable.picture_icon_no_data);
                    } else {
                        hideDataNull();
                    }
                } else {
                    onRecyclerViewPreloadMore();
                }
            }
        }
    }

    public /* synthetic */ void E(long j2, List list, int i2, boolean z) {
        if (!isFinishing()) {
            this.isHasMore = z;
            if (z) {
                hideDataNull();
                int size = list.size();
                if (size > 0) {
                    int size2 = this.mAdapter.getSize();
                    this.mAdapter.getData().addAll(list);
                    this.mAdapter.notifyItemRangeChanged(size2, this.mAdapter.getItemCount());
                } else {
                    onRecyclerViewPreloadMore();
                }
                if (size < 10) {
                    RecyclerPreloadView recyclerPreloadView = this.mRecyclerView;
                    recyclerPreloadView.onScrolled(recyclerPreloadView.getScrollX(), this.mRecyclerView.getScrollY());
                }
            } else if (this.mAdapter.isDataEmpty()) {
                showDataNull(getString(j2 == -1 ? R.string.picture_empty : R.string.picture_data_null), R.drawable.picture_icon_no_data);
            }
        }
    }

    public /* synthetic */ void F(List list, int i2, boolean z) {
        if (!isFinishing()) {
            this.isHasMore = true;
            initPageModel(list);
            synchronousCover();
        }
    }

    public void changeImageNumber(List<LocalMedia> list) {
        if (list.size() != 0) {
            this.mTvPictureOk.setEnabled(true);
            this.mTvPictureOk.setSelected(true);
            this.mTvPicturePreview.setEnabled(true);
            this.mTvPicturePreview.setSelected(true);
            PictureParameterStyle pictureParameterStyle = this.config.style;
            if (pictureParameterStyle != null) {
                int i2 = pictureParameterStyle.pictureCompleteTextColor;
                if (i2 != 0) {
                    this.mTvPictureOk.setTextColor(i2);
                }
                int i3 = this.config.style.picturePreviewTextColor;
                if (i3 != 0) {
                    this.mTvPicturePreview.setTextColor(i3);
                }
            }
            PictureParameterStyle pictureParameterStyle2 = this.config.style;
            if (pictureParameterStyle2 == null || TextUtils.isEmpty(pictureParameterStyle2.picturePreviewText)) {
                this.mTvPicturePreview.setText(getString(R.string.picture_preview_num, new Object[]{Integer.valueOf(list.size())}));
            } else {
                this.mTvPicturePreview.setText(this.config.style.picturePreviewText);
            }
            if (this.numComplete) {
                initCompleteText(list.size());
                return;
            }
            if (!this.isStartAnimation) {
                this.mTvPictureImgNum.startAnimation(this.animation);
            }
            this.mTvPictureImgNum.setVisibility(0);
            this.mTvPictureImgNum.setText(String.valueOf(list.size()));
            PictureParameterStyle pictureParameterStyle3 = this.config.style;
            if (pictureParameterStyle3 == null || TextUtils.isEmpty(pictureParameterStyle3.pictureCompleteText)) {
                this.mTvPictureOk.setText(getString(R.string.picture_completed));
            } else {
                this.mTvPictureOk.setText(this.config.style.pictureCompleteText);
            }
            this.isStartAnimation = false;
            return;
        }
        this.mTvPictureOk.setEnabled(this.config.returnEmpty);
        this.mTvPictureOk.setSelected(false);
        this.mTvPicturePreview.setEnabled(false);
        this.mTvPicturePreview.setSelected(false);
        PictureParameterStyle pictureParameterStyle4 = this.config.style;
        if (pictureParameterStyle4 != null) {
            int i4 = pictureParameterStyle4.pictureUnCompleteTextColor;
            if (i4 != 0) {
                this.mTvPictureOk.setTextColor(i4);
            }
            int i5 = this.config.style.pictureUnPreviewTextColor;
            if (i5 != 0) {
                this.mTvPicturePreview.setTextColor(i5);
            }
        }
        PictureParameterStyle pictureParameterStyle5 = this.config.style;
        if (pictureParameterStyle5 == null || TextUtils.isEmpty(pictureParameterStyle5.pictureUnPreviewText)) {
            this.mTvPicturePreview.setText(getString(R.string.picture_preview));
        } else {
            this.mTvPicturePreview.setText(this.config.style.pictureUnPreviewText);
        }
        if (this.numComplete) {
            initCompleteText(list.size());
            return;
        }
        this.mTvPictureImgNum.setVisibility(4);
        PictureParameterStyle pictureParameterStyle6 = this.config.style;
        if (pictureParameterStyle6 == null || TextUtils.isEmpty(pictureParameterStyle6.pictureUnCompleteText)) {
            this.mTvPictureOk.setText(getString(R.string.picture_please_select));
        } else {
            this.mTvPictureOk.setText(this.config.style.pictureUnCompleteText);
        }
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public int getResourceId() {
        return R.layout.picture_selector;
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public void initCompleteText(int i2) {
        String str;
        String str2;
        String str3;
        PictureSelectionConfig pictureSelectionConfig = this.config;
        PictureParameterStyle pictureParameterStyle = pictureSelectionConfig.style;
        boolean z = pictureParameterStyle != null;
        if (pictureSelectionConfig.selectionMode != 1) {
            boolean z2 = z && pictureParameterStyle.isCompleteReplaceNum;
            if (i2 <= 0) {
                TextView textView = this.mTvPictureOk;
                if (!z || TextUtils.isEmpty(pictureParameterStyle.pictureUnCompleteText)) {
                    str = getString(R.string.picture_done_front_num, new Object[]{Integer.valueOf(i2), Integer.valueOf(this.config.maxSelectNum)});
                } else {
                    str = this.config.style.pictureUnCompleteText;
                }
                textView.setText(str);
            } else if (!z2 || TextUtils.isEmpty(pictureParameterStyle.pictureCompleteText)) {
                this.mTvPictureOk.setText(getString(R.string.picture_done_front_num, new Object[]{Integer.valueOf(i2), Integer.valueOf(this.config.maxSelectNum)}));
            } else {
                this.mTvPictureOk.setText(String.format(this.config.style.pictureCompleteText, Integer.valueOf(i2), Integer.valueOf(this.config.maxSelectNum)));
            }
        } else if (i2 <= 0) {
            TextView textView2 = this.mTvPictureOk;
            if (!z || TextUtils.isEmpty(pictureParameterStyle.pictureUnCompleteText)) {
                str3 = getString(R.string.picture_please_select);
            } else {
                str3 = this.config.style.pictureUnCompleteText;
            }
            textView2.setText(str3);
        } else {
            if (!(z && pictureParameterStyle.isCompleteReplaceNum) || TextUtils.isEmpty(pictureParameterStyle.pictureCompleteText)) {
                TextView textView3 = this.mTvPictureOk;
                if (!z || TextUtils.isEmpty(this.config.style.pictureCompleteText)) {
                    str2 = getString(R.string.picture_done);
                } else {
                    str2 = this.config.style.pictureCompleteText;
                }
                textView3.setText(str2);
                return;
            }
            this.mTvPictureOk.setText(String.format(this.config.style.pictureCompleteText, Integer.valueOf(i2), 1));
        }
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public void initPictureSelectorStyle() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        PictureParameterStyle pictureParameterStyle = pictureSelectionConfig.style;
        if (pictureParameterStyle != null) {
            int i2 = pictureParameterStyle.pictureTitleDownResId;
            if (i2 != 0) {
                this.mIvArrow.setImageDrawable(ContextCompat.getDrawable(this, i2));
            }
            int i3 = this.config.style.pictureTitleTextColor;
            if (i3 != 0) {
                this.mTvPictureTitle.setTextColor(i3);
            }
            int i4 = this.config.style.pictureTitleTextSize;
            if (i4 != 0) {
                this.mTvPictureTitle.setTextSize((float) i4);
            }
            PictureParameterStyle pictureParameterStyle2 = this.config.style;
            int i5 = pictureParameterStyle2.pictureRightDefaultTextColor;
            if (i5 != 0) {
                this.mTvPictureRight.setTextColor(i5);
            } else {
                int i6 = pictureParameterStyle2.pictureCancelTextColor;
                if (i6 != 0) {
                    this.mTvPictureRight.setTextColor(i6);
                }
            }
            int i7 = this.config.style.pictureRightTextSize;
            if (i7 != 0) {
                this.mTvPictureRight.setTextSize((float) i7);
            }
            int i8 = this.config.style.pictureLeftBackIcon;
            if (i8 != 0) {
                this.mIvPictureLeftBack.setImageResource(i8);
            }
            int i9 = this.config.style.pictureUnPreviewTextColor;
            if (i9 != 0) {
                this.mTvPicturePreview.setTextColor(i9);
            }
            int i10 = this.config.style.picturePreviewTextSize;
            if (i10 != 0) {
                this.mTvPicturePreview.setTextSize((float) i10);
            }
            int i11 = this.config.style.pictureCheckNumBgStyle;
            if (i11 != 0) {
                this.mTvPictureImgNum.setBackgroundResource(i11);
            }
            int i12 = this.config.style.pictureUnCompleteTextColor;
            if (i12 != 0) {
                this.mTvPictureOk.setTextColor(i12);
            }
            int i13 = this.config.style.pictureCompleteTextSize;
            if (i13 != 0) {
                this.mTvPictureOk.setTextSize((float) i13);
            }
            int i14 = this.config.style.pictureBottomBgColor;
            if (i14 != 0) {
                this.mBottomLayout.setBackgroundColor(i14);
            }
            int i15 = this.config.style.pictureContainerBackgroundColor;
            if (i15 != 0) {
                this.container.setBackgroundColor(i15);
            }
            if (!TextUtils.isEmpty(this.config.style.pictureRightDefaultText)) {
                this.mTvPictureRight.setText(this.config.style.pictureRightDefaultText);
            }
            if (!TextUtils.isEmpty(this.config.style.pictureUnCompleteText)) {
                this.mTvPictureOk.setText(this.config.style.pictureUnCompleteText);
            }
            if (!TextUtils.isEmpty(this.config.style.pictureUnPreviewText)) {
                this.mTvPicturePreview.setText(this.config.style.pictureUnPreviewText);
            }
        } else {
            int i16 = pictureSelectionConfig.downResId;
            if (i16 != 0) {
                this.mIvArrow.setImageDrawable(ContextCompat.getDrawable(this, i16));
            }
            int typeValueColor = AttrsUtils.getTypeValueColor(getContext(), R.attr.picture_bottom_bg);
            if (typeValueColor != 0) {
                this.mBottomLayout.setBackgroundColor(typeValueColor);
            }
        }
        this.titleViewBg.setBackgroundColor(this.colorPrimary);
        PictureSelectionConfig pictureSelectionConfig2 = this.config;
        if (pictureSelectionConfig2.isOriginalControl) {
            PictureParameterStyle pictureParameterStyle3 = pictureSelectionConfig2.style;
            if (pictureParameterStyle3 != null) {
                int i17 = pictureParameterStyle3.pictureOriginalControlStyle;
                if (i17 != 0) {
                    this.mCbOriginal.setButtonDrawable(i17);
                } else {
                    this.mCbOriginal.setButtonDrawable(ContextCompat.getDrawable(this, R.drawable.picture_original_checkbox));
                }
                int i18 = this.config.style.pictureOriginalFontColor;
                if (i18 != 0) {
                    this.mCbOriginal.setTextColor(i18);
                } else {
                    this.mCbOriginal.setTextColor(ContextCompat.getColor(this, R.color.picture_color_53575e));
                }
                int i19 = this.config.style.pictureOriginalTextSize;
                if (i19 != 0) {
                    this.mCbOriginal.setTextSize((float) i19);
                }
            } else {
                this.mCbOriginal.setButtonDrawable(ContextCompat.getDrawable(this, R.drawable.picture_original_checkbox));
                this.mCbOriginal.setTextColor(ContextCompat.getColor(this, R.color.picture_color_53575e));
            }
        }
        this.mAdapter.bindSelectData(this.selectionMedias);
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public void initWidgets() {
        int i2;
        String str;
        super.initWidgets();
        this.container = findViewById(R.id.container);
        this.titleViewBg = findViewById(R.id.titleViewBg);
        this.mIvPictureLeftBack = (ImageView) findViewById(R.id.pictureLeftBack);
        this.mTvPictureTitle = (TextView) findViewById(R.id.picture_title);
        this.mTvPictureRight = (TextView) findViewById(R.id.picture_right);
        this.mTvPictureOk = (TextView) findViewById(R.id.picture_tv_ok);
        this.mCbOriginal = (CheckBox) findViewById(R.id.cb_original);
        this.mIvArrow = (ImageView) findViewById(R.id.ivArrow);
        this.mTvPicturePreview = (TextView) findViewById(R.id.picture_id_preview);
        this.mTvPictureImgNum = (TextView) findViewById(R.id.picture_tvMediaNum);
        this.mRecyclerView = (RecyclerPreloadView) findViewById(R.id.picture_recycler);
        this.mBottomLayout = (RelativeLayout) findViewById(R.id.rl_bottom);
        this.mTvEmpty = (TextView) findViewById(R.id.tv_empty);
        isNumComplete(this.numComplete);
        if (!this.numComplete) {
            this.animation = AnimationUtils.loadAnimation(this, R.anim.picture_anim_modal_in);
        }
        this.mTvPicturePreview.setOnClickListener(this);
        if (this.config.isAutomaticTitleRecyclerTop) {
            this.titleViewBg.setOnClickListener(this);
        }
        int i3 = 8;
        this.mTvPicturePreview.setVisibility((this.config.chooseMode == PictureMimeType.ofAudio() || !this.config.enablePreview) ? 8 : 0);
        RelativeLayout relativeLayout = this.mBottomLayout;
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig.selectionMode != 1 || !pictureSelectionConfig.isSingleDirectReturn) {
            i3 = 0;
        }
        relativeLayout.setVisibility(i3);
        this.mIvPictureLeftBack.setOnClickListener(this);
        this.mTvPictureRight.setOnClickListener(this);
        this.mTvPictureOk.setOnClickListener(this);
        this.mTvPictureImgNum.setOnClickListener(this);
        this.mTvPictureTitle.setOnClickListener(this);
        this.mIvArrow.setOnClickListener(this);
        if (this.config.chooseMode == PictureMimeType.ofAudio()) {
            i2 = R.string.picture_all_audio;
        } else {
            i2 = R.string.picture_camera_roll;
        }
        this.mTvPictureTitle.setText(getString(i2));
        this.mTvPictureTitle.setTag(R.id.view_tag, -1);
        FolderPopWindow folderPopWindow = new FolderPopWindow(this, this.config);
        this.folderWindow = folderPopWindow;
        folderPopWindow.setArrowImageView(this.mIvArrow);
        this.folderWindow.setOnAlbumItemClickListener(this);
        this.mRecyclerView.addItemDecoration(new GridSpacingItemDecoration(this.config.imageSpanCount, ScreenUtils.dip2px(this, 2.0f), false));
        this.mRecyclerView.setLayoutManager(new GridLayoutManager(getContext(), this.config.imageSpanCount));
        if (!this.config.isPageStrategy) {
            this.mRecyclerView.setHasFixedSize(true);
        } else {
            this.mRecyclerView.setReachBottomRow(2);
            this.mRecyclerView.setOnRecyclerViewPreloadListener(this);
        }
        RecyclerView.ItemAnimator itemAnimator = this.mRecyclerView.getItemAnimator();
        if (itemAnimator != null) {
            ((SimpleItemAnimator) itemAnimator).setSupportsChangeAnimations(false);
            this.mRecyclerView.setItemAnimator(null);
        }
        loadAllMediaData();
        TextView textView = this.mTvEmpty;
        if (this.config.chooseMode == PictureMimeType.ofAudio()) {
            str = getString(R.string.picture_audio_empty);
        } else {
            str = getString(R.string.picture_empty);
        }
        textView.setText(str);
        StringUtils.tempTextFont(this.mTvEmpty, this.config.chooseMode);
        PictureImageGridAdapter pictureImageGridAdapter = new PictureImageGridAdapter(getContext(), this.config);
        this.mAdapter = pictureImageGridAdapter;
        pictureImageGridAdapter.setOnPhotoSelectChangedListener(this);
        int i4 = this.config.animationMode;
        if (i4 == 1) {
            this.mRecyclerView.setAdapter(new AlphaInAnimationAdapter(this.mAdapter));
        } else if (i4 != 2) {
            this.mRecyclerView.setAdapter(this.mAdapter);
        } else {
            this.mRecyclerView.setAdapter(new SlideInBottomAnimationAdapter(this.mAdapter));
        }
        if (this.config.isOriginalControl) {
            this.mCbOriginal.setVisibility(0);
            this.mCbOriginal.setChecked(this.config.isCheckOriginalImage);
            this.mCbOriginal.setOnCheckedChangeListener(new b0(this));
        }
    }

    public void multiCropHandleResult(Intent intent) {
        List<CutInfo> multipleOutput;
        if (intent != null && (multipleOutput = UCrop.getMultipleOutput(intent)) != null && multipleOutput.size() != 0) {
            int size = multipleOutput.size();
            boolean checkedAndroid_Q = SdkVersionUtils.checkedAndroid_Q();
            ArrayList parcelableArrayListExtra = intent.getParcelableArrayListExtra(PictureConfig.EXTRA_SELECT_LIST);
            if (parcelableArrayListExtra != null) {
                this.mAdapter.bindSelectData(parcelableArrayListExtra);
                this.mAdapter.notifyDataSetChanged();
            }
            PictureImageGridAdapter pictureImageGridAdapter = this.mAdapter;
            int i2 = 0;
            if ((pictureImageGridAdapter != null ? pictureImageGridAdapter.getSelectedData().size() : 0) == size) {
                List<LocalMedia> selectedData = this.mAdapter.getSelectedData();
                while (i2 < size) {
                    CutInfo cutInfo = multipleOutput.get(i2);
                    LocalMedia localMedia = selectedData.get(i2);
                    localMedia.setCut(!TextUtils.isEmpty(cutInfo.getCutPath()));
                    localMedia.setPath(cutInfo.getPath());
                    localMedia.setMimeType(cutInfo.getMimeType());
                    localMedia.setCutPath(cutInfo.getCutPath());
                    localMedia.setWidth(cutInfo.getImageWidth());
                    localMedia.setHeight(cutInfo.getImageHeight());
                    localMedia.setAndroidQToPath(checkedAndroid_Q ? cutInfo.getCutPath() : localMedia.getAndroidQToPath());
                    localMedia.setSize(!TextUtils.isEmpty(cutInfo.getCutPath()) ? new File(cutInfo.getCutPath()).length() : localMedia.getSize());
                    i2++;
                }
                handlerResult(selectedData);
                return;
            }
            ArrayList arrayList = new ArrayList();
            while (i2 < size) {
                CutInfo cutInfo2 = multipleOutput.get(i2);
                LocalMedia localMedia2 = new LocalMedia();
                localMedia2.setId(cutInfo2.getId());
                localMedia2.setCut(!TextUtils.isEmpty(cutInfo2.getCutPath()));
                localMedia2.setPath(cutInfo2.getPath());
                localMedia2.setCutPath(cutInfo2.getCutPath());
                localMedia2.setMimeType(cutInfo2.getMimeType());
                localMedia2.setWidth(cutInfo2.getImageWidth());
                localMedia2.setHeight(cutInfo2.getImageHeight());
                localMedia2.setDuration(cutInfo2.getDuration());
                localMedia2.setChooseModel(this.config.chooseMode);
                localMedia2.setAndroidQToPath(checkedAndroid_Q ? cutInfo2.getCutPath() : cutInfo2.getAndroidQToPath());
                if (!TextUtils.isEmpty(cutInfo2.getCutPath())) {
                    localMedia2.setSize(new File(cutInfo2.getCutPath()).length());
                } else if (!SdkVersionUtils.checkedAndroid_Q() || !PictureMimeType.isContent(cutInfo2.getPath())) {
                    localMedia2.setSize(new File(cutInfo2.getPath()).length());
                } else {
                    localMedia2.setSize(!TextUtils.isEmpty(cutInfo2.getRealPath()) ? new File(cutInfo2.getRealPath()).length() : 0);
                }
                arrayList.add(localMedia2);
                i2++;
            }
            handlerResult(arrayList);
        }
    }

    @Override // androidx.activity.ComponentActivity, androidx.fragment.app.FragmentActivity
    public void onActivityResult(int i2, int i3, Intent intent) {
        Throwable th;
        ArrayList parcelableArrayListExtra;
        super.onActivityResult(i2, i3, intent);
        if (i3 == -1) {
            if (i2 == 69) {
                singleCropHandleResult(intent);
            } else if (i2 != 166) {
                if (i2 == 609) {
                    multiCropHandleResult(intent);
                } else if (i2 == 909) {
                    dispatchHandleCamera(intent);
                }
            } else if (intent != null && (parcelableArrayListExtra = intent.getParcelableArrayListExtra(PictureConfig.EXTRA_SELECT_LIST)) != null && parcelableArrayListExtra.size() > 0) {
                onResult(parcelableArrayListExtra);
            }
        } else if (i3 == 0) {
            previewCallback(intent);
        } else if (i3 == 96 && intent != null && (th = (Throwable) intent.getSerializableExtra(UCrop.EXTRA_ERROR)) != null) {
            ToastUtils.s(getContext(), th.getMessage());
        }
    }

    @Override // androidx.activity.ComponentActivity
    public void onBackPressed() {
        OnResultCallbackListener onResultCallbackListener;
        super.onBackPressed();
        if (!(this.config == null || (onResultCallbackListener = PictureSelectionConfig.listener) == null)) {
            onResultCallbackListener.onCancel();
        }
        closeActivity();
    }

    @Override // com.luck.picture.lib.listener.OnPhotoSelectChangedListener
    public void onChange(List<LocalMedia> list) {
        changeImageNumber(list);
    }

    public void onChangeData(List<LocalMedia> list) {
    }

    public void onClick(View view) {
        int id = view.getId();
        if (id == R.id.pictureLeftBack || id == R.id.picture_right) {
            FolderPopWindow folderPopWindow = this.folderWindow;
            if (folderPopWindow == null || !folderPopWindow.isShowing()) {
                onBackPressed();
            } else {
                this.folderWindow.dismiss();
            }
        } else if (id == R.id.picture_title || id == R.id.ivArrow) {
            if (this.folderWindow.isShowing()) {
                this.folderWindow.dismiss();
            } else if (!this.folderWindow.isEmpty()) {
                this.folderWindow.showAsDropDown(this.titleViewBg);
                if (!this.config.isSingleDirectReturn) {
                    this.folderWindow.updateFolderCheckStatus(this.mAdapter.getSelectedData());
                }
            }
        } else if (id == R.id.picture_id_preview) {
            onPreview();
        } else if (id == R.id.picture_tv_ok || id == R.id.picture_tvMediaNum) {
            onComplete();
        } else if (id == R.id.titleViewBg && this.config.isAutomaticTitleRecyclerTop) {
            if (SystemClock.uptimeMillis() - this.intervalClickTime >= ((long) CropImageView.DEFAULT_IMAGE_TO_CROP_BOUNDS_ANIM_DURATION)) {
                this.intervalClickTime = SystemClock.uptimeMillis();
            } else if (this.mAdapter.getItemCount() > 0) {
                this.mRecyclerView.scrollToPosition(0);
            }
        }
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, com.luck.picture.lib.PictureBaseActivity, androidx.fragment.app.FragmentActivity
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        if (bundle != null) {
            this.allFolderSize = bundle.getInt(PictureConfig.EXTRA_ALL_FOLDER_SIZE);
            this.oldCurrentListSize = bundle.getInt(PictureConfig.EXTRA_OLD_CURRENT_LIST_SIZE, 0);
            List<LocalMedia> obtainSelectorList = PictureSelector.obtainSelectorList(bundle);
            this.selectionMedias = obtainSelectorList;
            PictureImageGridAdapter pictureImageGridAdapter = this.mAdapter;
            if (pictureImageGridAdapter != null) {
                this.isStartAnimation = true;
                pictureImageGridAdapter.bindSelectData(obtainSelectorList);
            }
        }
    }

    @Override // androidx.appcompat.app.AppCompatActivity, com.luck.picture.lib.PictureBaseActivity, androidx.fragment.app.FragmentActivity
    public void onDestroy() {
        Handler handler;
        super.onDestroy();
        Animation animation2 = this.animation;
        if (animation2 != null) {
            animation2.cancel();
            this.animation = null;
        }
        if (this.mediaPlayer != null && (handler = this.mHandler) != null) {
            handler.removeCallbacks(this.mRunnable);
            this.mediaPlayer.release();
            this.mediaPlayer = null;
        }
    }

    @Override // com.luck.picture.lib.listener.OnAlbumItemClickListener
    public void onItemClick(int i2, boolean z, long j2, String str, List<LocalMedia> list) {
        this.mAdapter.setShowCamera(this.config.isCamera && z);
        this.mTvPictureTitle.setText(str);
        TextView textView = this.mTvPictureTitle;
        int i3 = R.id.view_tag;
        long j3 = ValueOf.toLong(textView.getTag(i3));
        this.mTvPictureTitle.setTag(R.id.view_count_tag, Integer.valueOf(this.folderWindow.getFolder(i2) != null ? this.folderWindow.getFolder(i2).getImageNum() : 0));
        if (!this.config.isPageStrategy) {
            this.mAdapter.bindData(list);
            this.mRecyclerView.smoothScrollToPosition(0);
        } else if (j3 != j2) {
            setLastCacheFolderData();
            if (!isCurrentCacheFolderData(i2)) {
                this.mPage = 1;
                showPleaseDialog();
                LocalMediaPageLoader.getInstance(getContext(), this.config).loadPageMediaData(j2, this.mPage, new x(this));
            }
        }
        this.mTvPictureTitle.setTag(i3, Long.valueOf(j2));
        this.folderWindow.dismiss();
    }

    @Override // com.luck.picture.lib.listener.OnRecyclerViewPreloadMoreListener
    public void onRecyclerViewPreloadMore() {
        loadMoreData();
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ActivityCompat.OnRequestPermissionsResultCallback, com.luck.picture.lib.PictureBaseActivity, androidx.fragment.app.FragmentActivity
    public void onRequestPermissionsResult(int i2, @NonNull String[] strArr, @NonNull int[] iArr) {
        super.onRequestPermissionsResult(i2, strArr, iArr);
        if (i2 != 1) {
            if (i2 != 2) {
                if (i2 != 4) {
                    if (i2 == 5) {
                        if (iArr.length <= 0 || iArr[0] != 0) {
                            showPermissionsDialog(false, getString(R.string.picture_jurisdiction));
                        } else {
                            startCamera();
                        }
                    }
                } else if (iArr.length <= 0 || iArr[0] != 0) {
                    showPermissionsDialog(false, getString(R.string.picture_audio));
                } else {
                    startCustomCamera();
                }
            } else if (iArr.length <= 0 || iArr[0] != 0) {
                showPermissionsDialog(true, getString(R.string.picture_camera));
            } else {
                onTakePhoto();
            }
        } else if (iArr.length <= 0 || iArr[0] != 0) {
            showPermissionsDialog(false, getString(R.string.picture_jurisdiction));
        } else {
            readLocalMedia();
        }
    }

    @Override // androidx.fragment.app.FragmentActivity
    public void onResume() {
        CheckBox checkBox;
        super.onResume();
        if (this.isEnterSetting) {
            if (!PermissionChecker.checkSelfPermission(this, "android.permission.READ_EXTERNAL_STORAGE") || !PermissionChecker.checkSelfPermission(this, "android.permission.WRITE_EXTERNAL_STORAGE")) {
                showPermissionsDialog(false, getString(R.string.picture_jurisdiction));
            } else if (this.mAdapter.isDataEmpty()) {
                readLocalMedia();
            }
            this.isEnterSetting = false;
        }
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig.isOriginalControl && (checkBox = this.mCbOriginal) != null) {
            checkBox.setChecked(pictureSelectionConfig.isCheckOriginalImage);
        }
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, com.luck.picture.lib.PictureBaseActivity
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        PictureImageGridAdapter pictureImageGridAdapter = this.mAdapter;
        if (pictureImageGridAdapter != null) {
            bundle.putInt(PictureConfig.EXTRA_OLD_CURRENT_LIST_SIZE, pictureImageGridAdapter.getSize());
            if (this.folderWindow.getFolderData().size() > 0) {
                bundle.putInt(PictureConfig.EXTRA_ALL_FOLDER_SIZE, this.folderWindow.getFolder(0).getImageNum());
            }
            if (this.mAdapter.getSelectedData() != null) {
                PictureSelector.saveSelectorList(bundle, this.mAdapter.getSelectedData());
            }
        }
    }

    @Override // com.luck.picture.lib.listener.OnPhotoSelectChangedListener
    public void onTakePhoto() {
        if (!PermissionChecker.checkSelfPermission(this, "android.permission.CAMERA")) {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.CAMERA"}, 2);
        } else if (!PermissionChecker.checkSelfPermission(this, "android.permission.READ_EXTERNAL_STORAGE") || !PermissionChecker.checkSelfPermission(this, "android.permission.WRITE_EXTERNAL_STORAGE")) {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.READ_EXTERNAL_STORAGE", "android.permission.WRITE_EXTERNAL_STORAGE"}, 5);
        } else {
            startCamera();
        }
    }

    public void playOrPause() {
        try {
            MediaPlayer mediaPlayer2 = this.mediaPlayer;
            if (mediaPlayer2 == null) {
                return;
            }
            if (mediaPlayer2.isPlaying()) {
                this.mediaPlayer.pause();
            } else {
                this.mediaPlayer.start();
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
    }

    public void readLocalMedia() {
        showPleaseDialog();
        if (this.config.isPageStrategy) {
            LocalMediaPageLoader.getInstance(getContext(), this.config).loadAllMedia(new y(this));
        } else {
            PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<List<LocalMediaFolder>>() {
                /* class com.luck.picture.lib.PictureSelectorActivity.AnonymousClass1 */

                @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                public List<LocalMediaFolder> doInBackground() {
                    return new LocalMediaLoader(PictureSelectorActivity.this.getContext(), PictureSelectorActivity.this.config).loadAllMedia();
                }

                public void onSuccess(List<LocalMediaFolder> list) {
                    PictureSelectorActivity.this.initStandardModel(list);
                }
            });
        }
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public void showPermissionsDialog(boolean z, String str) {
        if (!isFinishing()) {
            PictureCustomDialog pictureCustomDialog = new PictureCustomDialog(getContext(), R.layout.picture_wind_base_dialog);
            pictureCustomDialog.setCancelable(false);
            pictureCustomDialog.setCanceledOnTouchOutside(false);
            Button button = (Button) pictureCustomDialog.findViewById(R.id.btn_commit);
            button.setText(getString(R.string.picture_go_setting));
            ((TextView) pictureCustomDialog.findViewById(R.id.tvTitle)).setText(getString(R.string.picture_prompt));
            ((TextView) pictureCustomDialog.findViewById(R.id.tv_content)).setText(str);
            ((Button) pictureCustomDialog.findViewById(R.id.btn_cancel)).setOnClickListener(new z(this, pictureCustomDialog, z));
            button.setOnClickListener(new u(this, pictureCustomDialog));
            pictureCustomDialog.show();
        }
    }

    public void startCamera() {
        if (!DoubleUtils.isFastDoubleClick()) {
            OnCustomCameraInterfaceListener onCustomCameraInterfaceListener = PictureSelectionConfig.onCustomCameraInterfaceListener;
            if (onCustomCameraInterfaceListener == null) {
                PictureSelectionConfig pictureSelectionConfig = this.config;
                if (pictureSelectionConfig.isUseCustomCamera) {
                    startCustomCamera();
                    return;
                }
                int i2 = pictureSelectionConfig.chooseMode;
                if (i2 == 0) {
                    PhotoItemSelectedDialog newInstance = PhotoItemSelectedDialog.newInstance();
                    newInstance.setOnItemClickListener(this);
                    newInstance.show(getSupportFragmentManager(), "PhotoItemSelectedDialog");
                } else if (i2 == 1) {
                    startOpenCamera();
                } else if (i2 == 2) {
                    startOpenCameraVideo();
                } else if (i2 == 3) {
                    startOpenCameraAudio();
                }
            } else if (this.config.chooseMode == 0) {
                PhotoItemSelectedDialog newInstance2 = PhotoItemSelectedDialog.newInstance();
                newInstance2.setOnItemClickListener(this);
                newInstance2.show(getSupportFragmentManager(), "PhotoItemSelectedDialog");
            } else {
                Context context = getContext();
                PictureSelectionConfig pictureSelectionConfig2 = this.config;
                onCustomCameraInterfaceListener.onCameraClick(context, pictureSelectionConfig2, pictureSelectionConfig2.chooseMode);
                PictureSelectionConfig pictureSelectionConfig3 = this.config;
                pictureSelectionConfig3.cameraMimeType = pictureSelectionConfig3.chooseMode;
            }
        }
    }

    public void startPreview(List<LocalMedia> list, int i2) {
        int i3;
        LocalMedia localMedia = list.get(i2);
        String mimeType = localMedia.getMimeType();
        Bundle bundle = new Bundle();
        ArrayList arrayList = new ArrayList();
        if (PictureMimeType.isHasVideo(mimeType)) {
            PictureSelectionConfig pictureSelectionConfig = this.config;
            if (pictureSelectionConfig.selectionMode != 1 || pictureSelectionConfig.enPreviewVideo) {
                OnVideoSelectedPlayCallback onVideoSelectedPlayCallback = PictureSelectionConfig.customVideoPlayCallback;
                if (onVideoSelectedPlayCallback != null) {
                    onVideoSelectedPlayCallback.startPlayVideo(localMedia);
                    return;
                }
                bundle.putParcelable(PictureConfig.EXTRA_MEDIA_KEY, localMedia);
                JumpUtils.startPictureVideoPlayActivity(getContext(), bundle, PictureConfig.PREVIEW_VIDEO_CODE);
                return;
            }
            arrayList.add(localMedia);
            onResult(arrayList);
        } else if (!PictureMimeType.isHasAudio(mimeType)) {
            OnCustomImagePreviewCallback onCustomImagePreviewCallback = PictureSelectionConfig.onCustomImagePreviewCallback;
            if (onCustomImagePreviewCallback != null) {
                onCustomImagePreviewCallback.onCustomPreviewCallback(getContext(), list, i2);
                return;
            }
            List<LocalMedia> selectedData = this.mAdapter.getSelectedData();
            ImagesObservable.getInstance().savePreviewMediaData(new ArrayList(list));
            bundle.putParcelableArrayList(PictureConfig.EXTRA_SELECT_LIST, (ArrayList) selectedData);
            bundle.putInt("position", i2);
            bundle.putBoolean(PictureConfig.EXTRA_CHANGE_ORIGINAL, this.config.isCheckOriginalImage);
            bundle.putBoolean(PictureConfig.EXTRA_SHOW_CAMERA, this.mAdapter.isShowCamera());
            bundle.putLong(PictureConfig.EXTRA_BUCKET_ID, ValueOf.toLong(this.mTvPictureTitle.getTag(R.id.view_tag)));
            bundle.putInt(PictureConfig.EXTRA_PAGE, this.mPage);
            bundle.putParcelable(PictureConfig.EXTRA_CONFIG, this.config);
            bundle.putInt(PictureConfig.EXTRA_DATA_COUNT, ValueOf.toInt(this.mTvPictureTitle.getTag(R.id.view_count_tag)));
            bundle.putString(PictureConfig.EXTRA_IS_CURRENT_DIRECTORY, this.mTvPictureTitle.getText().toString());
            Context context = getContext();
            PictureSelectionConfig pictureSelectionConfig2 = this.config;
            JumpUtils.startPicturePreviewActivity(context, pictureSelectionConfig2.isWeChatStyle, bundle, pictureSelectionConfig2.selectionMode == 1 ? 69 : UCrop.REQUEST_MULTI_CROP);
            PictureWindowAnimationStyle pictureWindowAnimationStyle = this.config.windowAnimationStyle;
            if (pictureWindowAnimationStyle == null || (i3 = pictureWindowAnimationStyle.activityPreviewEnterAnimation) == 0) {
                i3 = R.anim.picture_anim_enter;
            }
            overridePendingTransition(i3, R.anim.picture_anim_fade_in);
        } else if (this.config.selectionMode == 1) {
            arrayList.add(localMedia);
            onResult(arrayList);
        } else {
            AudioDialog(localMedia.getPath());
        }
    }

    public void stop(String str) {
        MediaPlayer mediaPlayer2 = this.mediaPlayer;
        if (mediaPlayer2 != null) {
            try {
                mediaPlayer2.stop();
                this.mediaPlayer.reset();
                this.mediaPlayer.setDataSource(str);
                this.mediaPlayer.prepare();
                this.mediaPlayer.seekTo(0);
            } catch (Exception e2) {
                e2.printStackTrace();
            }
        }
    }

    public void onPictureClick(LocalMedia localMedia, int i2) {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig.selectionMode != 1 || !pictureSelectionConfig.isSingleDirectReturn) {
            startPreview(this.mAdapter.getData(), i2);
            return;
        }
        ArrayList arrayList = new ArrayList();
        arrayList.add(localMedia);
        if (!this.config.enableCrop || !PictureMimeType.isHasImage(localMedia.getMimeType()) || this.config.isCheckOriginalImage) {
            handlerResult(arrayList);
            return;
        }
        this.mAdapter.bindSelectData(arrayList);
        startCrop(localMedia.getPath(), localMedia.getMimeType());
    }

    @Override // com.luck.picture.lib.listener.OnItemClickListener
    public void onItemClick(View view, int i2) {
        if (i2 == 0) {
            OnCustomCameraInterfaceListener onCustomCameraInterfaceListener = PictureSelectionConfig.onCustomCameraInterfaceListener;
            if (onCustomCameraInterfaceListener != null) {
                onCustomCameraInterfaceListener.onCameraClick(getContext(), this.config, 1);
                this.config.cameraMimeType = PictureMimeType.ofImage();
                return;
            }
            startOpenCamera();
        } else if (i2 == 1) {
            OnCustomCameraInterfaceListener onCustomCameraInterfaceListener2 = PictureSelectionConfig.onCustomCameraInterfaceListener;
            if (onCustomCameraInterfaceListener2 != null) {
                onCustomCameraInterfaceListener2.onCameraClick(getContext(), this.config, 1);
                this.config.cameraMimeType = PictureMimeType.ofVideo();
                return;
            }
            startOpenCameraVideo();
        }
    }
}
