package com.luck.picture.lib;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.os.Environment;
import android.text.TextUtils;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.core.content.ContextCompat;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.immersive.ImmersiveManage;
import com.luck.picture.lib.listener.OnCustomCameraInterfaceListener;
import com.luck.picture.lib.listener.OnResultCallbackListener;
import com.luck.picture.lib.permissions.PermissionChecker;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.BitmapUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.ToastUtils;
import com.luck.picture.lib.tools.ValueOf;
import com.yalantis.ucrop.UCrop;
import d.k.a.a.e0;
import java.io.File;
import java.util.ArrayList;

public class PictureSelectorCameraEmptyActivity extends PictureBaseActivity {
    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void dispatchCameraHandleResult(LocalMedia localMedia) {
        boolean isHasImage = PictureMimeType.isHasImage(localMedia.getMimeType());
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig.enableCrop && isHasImage) {
            String str = pictureSelectionConfig.cameraPath;
            pictureSelectionConfig.originalPath = str;
            startCrop(str, localMedia.getMimeType());
        } else if (!pictureSelectionConfig.isCompress || !isHasImage || pictureSelectionConfig.isCheckOriginalImage) {
            ArrayList arrayList = new ArrayList();
            arrayList.add(localMedia);
            onResult(arrayList);
        } else {
            ArrayList arrayList2 = new ArrayList();
            arrayList2.add(localMedia);
            compressImage(arrayList2);
        }
    }

    private void onTakePhoto() {
        if (PermissionChecker.checkSelfPermission(this, "android.permission.CAMERA")) {
            boolean z = true;
            PictureSelectionConfig pictureSelectionConfig = this.config;
            if (pictureSelectionConfig != null && pictureSelectionConfig.isUseCustomCamera) {
                z = PermissionChecker.checkSelfPermission(this, "android.permission.RECORD_AUDIO");
            }
            if (z) {
                startCamera();
            } else {
                PermissionChecker.requestPermissions(this, new String[]{"android.permission.RECORD_AUDIO"}, 4);
            }
        } else {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.CAMERA"}, 2);
        }
    }

    private void startCamera() {
        int i2 = this.config.chooseMode;
        if (i2 == 0 || i2 == 1) {
            startOpenCamera();
        } else if (i2 == 2) {
            startOpenCameraVideo();
        } else if (i2 == 3) {
            startOpenCameraAudio();
        }
    }

    public void dispatchHandleCamera(final Intent intent) {
        final boolean z = this.config.chooseMode == PictureMimeType.ofAudio();
        PictureSelectionConfig pictureSelectionConfig = this.config;
        pictureSelectionConfig.cameraPath = z ? getAudioPath(intent) : pictureSelectionConfig.cameraPath;
        if (!TextUtils.isEmpty(this.config.cameraPath)) {
            showPleaseDialog();
            PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<LocalMedia>() {
                /* class com.luck.picture.lib.PictureSelectorCameraEmptyActivity.AnonymousClass1 */

                @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                public LocalMedia doInBackground() {
                    LocalMedia localMedia = new LocalMedia();
                    boolean z = z;
                    String str = z ? PictureMimeType.MIME_TYPE_AUDIO : "";
                    int[] iArr = new int[2];
                    long j2 = 0;
                    if (!z) {
                        if (PictureMimeType.isContent(PictureSelectorCameraEmptyActivity.this.config.cameraPath)) {
                            String path = PictureFileUtils.getPath(PictureSelectorCameraEmptyActivity.this.getContext(), Uri.parse(PictureSelectorCameraEmptyActivity.this.config.cameraPath));
                            if (!TextUtils.isEmpty(path)) {
                                File file = new File(path);
                                String mimeType = PictureMimeType.getMimeType(PictureSelectorCameraEmptyActivity.this.config.cameraMimeType);
                                localMedia.setSize(file.length());
                                str = mimeType;
                            }
                            if (PictureMimeType.isHasImage(str)) {
                                iArr = MediaUtils.getImageSizeForUrlToAndroidQ(PictureSelectorCameraEmptyActivity.this.getContext(), PictureSelectorCameraEmptyActivity.this.config.cameraPath);
                            } else if (PictureMimeType.isHasVideo(str)) {
                                iArr = MediaUtils.getVideoSizeForUri(PictureSelectorCameraEmptyActivity.this.getContext(), Uri.parse(PictureSelectorCameraEmptyActivity.this.config.cameraPath));
                                j2 = MediaUtils.extractDuration(PictureSelectorCameraEmptyActivity.this.getContext(), SdkVersionUtils.checkedAndroid_Q(), PictureSelectorCameraEmptyActivity.this.config.cameraPath);
                            }
                            int lastIndexOf = PictureSelectorCameraEmptyActivity.this.config.cameraPath.lastIndexOf("/") + 1;
                            localMedia.setId(lastIndexOf > 0 ? ValueOf.toLong(PictureSelectorCameraEmptyActivity.this.config.cameraPath.substring(lastIndexOf)) : -1);
                            localMedia.setRealPath(path);
                            Intent intent = intent;
                            localMedia.setAndroidQToPath(intent != null ? intent.getStringExtra(PictureConfig.EXTRA_MEDIA_PATH) : null);
                        } else {
                            File file2 = new File(PictureSelectorCameraEmptyActivity.this.config.cameraPath);
                            str = PictureMimeType.getMimeType(PictureSelectorCameraEmptyActivity.this.config.cameraMimeType);
                            localMedia.setSize(file2.length());
                            if (PictureMimeType.isHasImage(str)) {
                                BitmapUtils.rotateImage(PictureFileUtils.readPictureDegree(PictureSelectorCameraEmptyActivity.this.getContext(), PictureSelectorCameraEmptyActivity.this.config.cameraPath), PictureSelectorCameraEmptyActivity.this.config.cameraPath);
                                iArr = MediaUtils.getImageSizeForUrl(PictureSelectorCameraEmptyActivity.this.config.cameraPath);
                            } else if (PictureMimeType.isHasVideo(str)) {
                                iArr = MediaUtils.getVideoSizeForUrl(PictureSelectorCameraEmptyActivity.this.config.cameraPath);
                                j2 = MediaUtils.extractDuration(PictureSelectorCameraEmptyActivity.this.getContext(), SdkVersionUtils.checkedAndroid_Q(), PictureSelectorCameraEmptyActivity.this.config.cameraPath);
                            }
                            localMedia.setId(System.currentTimeMillis());
                        }
                        localMedia.setPath(PictureSelectorCameraEmptyActivity.this.config.cameraPath);
                        localMedia.setDuration(j2);
                        localMedia.setMimeType(str);
                        localMedia.setWidth(iArr[0]);
                        localMedia.setHeight(iArr[1]);
                        if (!SdkVersionUtils.checkedAndroid_Q() || !PictureMimeType.isHasVideo(localMedia.getMimeType())) {
                            localMedia.setParentFolderName("Camera");
                        } else {
                            localMedia.setParentFolderName(Environment.DIRECTORY_MOVIES);
                        }
                        localMedia.setChooseModel(PictureSelectorCameraEmptyActivity.this.config.chooseMode);
                        localMedia.setBucketId(MediaUtils.getCameraFirstBucketId(PictureSelectorCameraEmptyActivity.this.getContext()));
                        Context context = PictureSelectorCameraEmptyActivity.this.getContext();
                        PictureSelectionConfig pictureSelectionConfig = PictureSelectorCameraEmptyActivity.this.config;
                        MediaUtils.setOrientationSynchronous(context, localMedia, pictureSelectionConfig.isAndroidQChangeWH, pictureSelectionConfig.isAndroidQChangeVideoWH);
                    }
                    return localMedia;
                }

                public void onSuccess(LocalMedia localMedia) {
                    int dCIMLastImageId;
                    PictureSelectorCameraEmptyActivity.this.dismissDialog();
                    if (!SdkVersionUtils.checkedAndroid_Q()) {
                        PictureSelectorCameraEmptyActivity pictureSelectorCameraEmptyActivity = PictureSelectorCameraEmptyActivity.this;
                        if (pictureSelectorCameraEmptyActivity.config.isFallbackVersion3) {
                            new PictureMediaScannerConnection(pictureSelectorCameraEmptyActivity.getContext(), PictureSelectorCameraEmptyActivity.this.config.cameraPath);
                        } else {
                            pictureSelectorCameraEmptyActivity.sendBroadcast(new Intent("android.intent.action.MEDIA_SCANNER_SCAN_FILE", Uri.fromFile(new File(PictureSelectorCameraEmptyActivity.this.config.cameraPath))));
                        }
                    }
                    PictureSelectorCameraEmptyActivity.this.dispatchCameraHandleResult(localMedia);
                    if (!SdkVersionUtils.checkedAndroid_Q() && PictureMimeType.isHasImage(localMedia.getMimeType()) && (dCIMLastImageId = MediaUtils.getDCIMLastImageId(PictureSelectorCameraEmptyActivity.this.getContext())) != -1) {
                        MediaUtils.removeMedia(PictureSelectorCameraEmptyActivity.this.getContext(), dCIMLastImageId);
                    }
                }
            });
        }
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public int getResourceId() {
        return R.layout.picture_empty;
    }

    @Override // com.luck.picture.lib.PictureBaseActivity
    public void immersive() {
        int i2 = R.color.picture_color_transparent;
        ImmersiveManage.immersiveAboveAPI23(this, ContextCompat.getColor(this, i2), ContextCompat.getColor(this, i2), this.openWhiteStatusBar);
    }

    @Override // androidx.activity.ComponentActivity, androidx.fragment.app.FragmentActivity
    public void onActivityResult(int i2, int i3, @Nullable Intent intent) {
        OnResultCallbackListener onResultCallbackListener;
        super.onActivityResult(i2, i3, intent);
        if (i3 == -1) {
            if (i2 == 69) {
                singleCropHandleResult(intent);
            } else if (i2 == 909) {
                dispatchHandleCamera(intent);
            }
        } else if (i3 == 0) {
            if (!(this.config == null || (onResultCallbackListener = PictureSelectionConfig.listener) == null)) {
                onResultCallbackListener.onCancel();
            }
            closeActivity();
        } else if (i3 == 96 && intent != null) {
            ToastUtils.s(getContext(), ((Throwable) intent.getSerializableExtra(UCrop.EXTRA_ERROR)).getMessage());
        }
    }

    @Override // androidx.activity.ComponentActivity
    public void onBackPressed() {
        super.onBackPressed();
        closeActivity();
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, com.luck.picture.lib.PictureBaseActivity, androidx.fragment.app.FragmentActivity
    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig == null) {
            closeActivity();
        } else if (!pictureSelectionConfig.isUseCustomCamera) {
            if (bundle == null) {
                if (!PermissionChecker.checkSelfPermission(this, "android.permission.READ_EXTERNAL_STORAGE") || !PermissionChecker.checkSelfPermission(this, "android.permission.WRITE_EXTERNAL_STORAGE")) {
                    PermissionChecker.requestPermissions(this, new String[]{"android.permission.READ_EXTERNAL_STORAGE", "android.permission.WRITE_EXTERNAL_STORAGE"}, 1);
                } else {
                    OnCustomCameraInterfaceListener onCustomCameraInterfaceListener = PictureSelectionConfig.onCustomCameraInterfaceListener;
                    if (onCustomCameraInterfaceListener == null) {
                        onTakePhoto();
                    } else if (this.config.chooseMode == 2) {
                        onCustomCameraInterfaceListener.onCameraClick(getContext(), this.config, 2);
                    } else {
                        onCustomCameraInterfaceListener.onCameraClick(getContext(), this.config, 1);
                    }
                }
            }
            setTheme(R.style.Picture_Theme_Translucent);
        }
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ActivityCompat.OnRequestPermissionsResultCallback, com.luck.picture.lib.PictureBaseActivity, androidx.fragment.app.FragmentActivity
    public void onRequestPermissionsResult(int i2, @NonNull String[] strArr, @NonNull int[] iArr) {
        super.onRequestPermissionsResult(i2, strArr, iArr);
        if (i2 != 1) {
            if (i2 != 2) {
                if (i2 == 4) {
                    if (iArr.length <= 0 || iArr[0] != 0) {
                        closeActivity();
                        ToastUtils.s(getContext(), getString(R.string.picture_audio));
                        return;
                    }
                    onTakePhoto();
                }
            } else if (iArr.length <= 0 || iArr[0] != 0) {
                closeActivity();
                ToastUtils.s(getContext(), getString(R.string.picture_camera));
            } else {
                onTakePhoto();
            }
        } else if (iArr.length <= 0 || iArr[0] != 0) {
            ToastUtils.s(getContext(), getString(R.string.picture_jurisdiction));
            closeActivity();
        } else {
            PermissionChecker.requestPermissions(this, new String[]{"android.permission.CAMERA"}, 2);
        }
    }

    public void singleCropHandleResult(Intent intent) {
        int i2;
        if (intent != null) {
            ArrayList arrayList = new ArrayList();
            Uri output = UCrop.getOutput(intent);
            if (output != null) {
                String path = output.getPath();
                boolean isEmpty = TextUtils.isEmpty(path);
                PictureSelectionConfig pictureSelectionConfig = this.config;
                LocalMedia localMedia = new LocalMedia(pictureSelectionConfig.cameraPath, 0, false, pictureSelectionConfig.isCamera ? 1 : 0, 0, pictureSelectionConfig.chooseMode);
                if (SdkVersionUtils.checkedAndroid_Q()) {
                    int lastIndexOf = this.config.cameraPath.lastIndexOf("/") + 1;
                    localMedia.setId(lastIndexOf > 0 ? ValueOf.toLong(this.config.cameraPath.substring(lastIndexOf)) : -1);
                    localMedia.setAndroidQToPath(path);
                    if (!isEmpty) {
                        localMedia.setSize(new File(path).length());
                    } else if (PictureMimeType.isContent(this.config.cameraPath)) {
                        String path2 = PictureFileUtils.getPath(this, Uri.parse(this.config.cameraPath));
                        localMedia.setSize(!TextUtils.isEmpty(path2) ? new File(path2).length() : 0);
                    } else {
                        localMedia.setSize(new File(this.config.cameraPath).length());
                    }
                } else {
                    localMedia.setId(System.currentTimeMillis());
                    localMedia.setSize(new File(isEmpty ? localMedia.getPath() : path).length());
                }
                localMedia.setCut(!isEmpty);
                localMedia.setCutPath(path);
                localMedia.setMimeType(PictureMimeType.getImageMimeType(path));
                localMedia.setOrientation(-1);
                int i3 = 0;
                if (PictureMimeType.isContent(localMedia.getPath())) {
                    if (PictureMimeType.isHasVideo(localMedia.getMimeType())) {
                        int[] videoSizeForUri = MediaUtils.getVideoSizeForUri(getContext(), Uri.parse(localMedia.getPath()));
                        i3 = videoSizeForUri[0];
                        i2 = videoSizeForUri[1];
                    } else if (PictureMimeType.isHasImage(localMedia.getMimeType())) {
                        int[] imageSizeForUri = MediaUtils.getImageSizeForUri(getContext(), Uri.parse(localMedia.getPath()));
                        i3 = imageSizeForUri[0];
                        i2 = imageSizeForUri[1];
                    }
                    localMedia.setWidth(i3);
                    localMedia.setHeight(i2);
                    Context context = getContext();
                    PictureSelectionConfig pictureSelectionConfig2 = this.config;
                    MediaUtils.setOrientationAsynchronous(context, localMedia, pictureSelectionConfig2.isAndroidQChangeWH, pictureSelectionConfig2.isAndroidQChangeVideoWH, new e0(this, arrayList));
                }
                if (PictureMimeType.isHasVideo(localMedia.getMimeType())) {
                    int[] videoSizeForUrl = MediaUtils.getVideoSizeForUrl(localMedia.getPath());
                    i3 = videoSizeForUrl[0];
                    i2 = videoSizeForUrl[1];
                } else if (PictureMimeType.isHasImage(localMedia.getMimeType())) {
                    int[] imageSizeForUrl = MediaUtils.getImageSizeForUrl(localMedia.getPath());
                    i3 = imageSizeForUrl[0];
                    i2 = imageSizeForUrl[1];
                }
                localMedia.setWidth(i3);
                localMedia.setHeight(i2);
                Context context2 = getContext();
                PictureSelectionConfig pictureSelectionConfig22 = this.config;
                MediaUtils.setOrientationAsynchronous(context2, localMedia, pictureSelectionConfig22.isAndroidQChangeWH, pictureSelectionConfig22.isAndroidQChangeVideoWH, new e0(this, arrayList));
                i2 = 0;
                localMedia.setWidth(i3);
                localMedia.setHeight(i2);
                Context context22 = getContext();
                PictureSelectionConfig pictureSelectionConfig222 = this.config;
                MediaUtils.setOrientationAsynchronous(context22, localMedia, pictureSelectionConfig222.isAndroidQChangeWH, pictureSelectionConfig222.isAndroidQChangeVideoWH, new e0(this, arrayList));
            }
        }
    }
}
