package com.luck.picture.lib.widget;

import android.content.Context;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.PopupWindow;
import androidx.core.content.ContextCompat;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import com.luck.picture.lib.R;
import com.luck.picture.lib.adapter.PictureAlbumDirectoryAdapter;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.listener.OnAlbumItemClickListener;
import com.luck.picture.lib.style.PictureParameterStyle;
import com.luck.picture.lib.tools.AnimUtils;
import com.luck.picture.lib.tools.AttrsUtils;
import com.luck.picture.lib.tools.ScreenUtils;
import d.k.a.a.l0.a;
import java.util.List;

public class FolderPopWindow extends PopupWindow {
    private PictureAlbumDirectoryAdapter adapter;
    private int chooseMode;
    private PictureSelectionConfig config;
    private Context context;
    private Drawable drawableDown;
    private Drawable drawableUp;
    private boolean isDismiss = false;
    private ImageView ivArrowView;
    private RecyclerView mRecyclerView;
    private int maxHeight;
    private View rootView;
    private View rootViewBg;
    private View window;

    public FolderPopWindow(Context context2, PictureSelectionConfig pictureSelectionConfig) {
        this.context = context2;
        this.config = pictureSelectionConfig;
        this.chooseMode = pictureSelectionConfig.chooseMode;
        View inflate = LayoutInflater.from(context2).inflate(R.layout.picture_window_folder, (ViewGroup) null);
        this.window = inflate;
        setContentView(inflate);
        setWidth(-1);
        setHeight(-2);
        setAnimationStyle(R.style.PictureThemeWindowStyle);
        setFocusable(true);
        setOutsideTouchable(true);
        update();
        PictureParameterStyle pictureParameterStyle = pictureSelectionConfig.style;
        if (pictureParameterStyle != null) {
            int i2 = pictureParameterStyle.pictureTitleUpResId;
            if (i2 != 0) {
                this.drawableUp = ContextCompat.getDrawable(context2, i2);
            }
            int i3 = pictureSelectionConfig.style.pictureTitleDownResId;
            if (i3 != 0) {
                this.drawableDown = ContextCompat.getDrawable(context2, i3);
            }
        } else if (pictureSelectionConfig.isWeChatStyle) {
            this.drawableUp = ContextCompat.getDrawable(context2, R.drawable.picture_icon_wechat_up);
            this.drawableDown = ContextCompat.getDrawable(context2, R.drawable.picture_icon_wechat_down);
        } else {
            int i4 = pictureSelectionConfig.upResId;
            if (i4 != 0) {
                this.drawableUp = ContextCompat.getDrawable(context2, i4);
            } else {
                this.drawableUp = AttrsUtils.getTypeValueDrawable(context2, R.attr.picture_arrow_up_icon);
            }
            int i5 = pictureSelectionConfig.downResId;
            if (i5 != 0) {
                this.drawableDown = ContextCompat.getDrawable(context2, i5);
            } else {
                this.drawableDown = AttrsUtils.getTypeValueDrawable(context2, R.attr.picture_arrow_down_icon);
            }
        }
        this.maxHeight = (int) (((double) ScreenUtils.getScreenHeight(context2)) * 0.6d);
        initView();
    }

    public void bindFolder(List<LocalMediaFolder> list) {
        this.adapter.setChooseMode(this.chooseMode);
        this.adapter.bindFolderData(list);
        this.mRecyclerView.getLayoutParams().height = (list == null || list.size() <= 8) ? -2 : this.maxHeight;
    }

    public void dismiss() {
        if (!this.isDismiss) {
            this.rootViewBg.animate().alpha(0.0f).setDuration(50).start();
            this.ivArrowView.setImageDrawable(this.drawableDown);
            AnimUtils.rotateArrow(this.ivArrowView, false);
            this.isDismiss = true;
            super.dismiss();
            this.isDismiss = false;
        }
    }

    public LocalMediaFolder getFolder(int i2) {
        if (this.adapter.getFolderData().size() <= 0 || i2 >= this.adapter.getFolderData().size()) {
            return null;
        }
        return this.adapter.getFolderData().get(i2);
    }

    public List<LocalMediaFolder> getFolderData() {
        return this.adapter.getFolderData();
    }

    public void initView() {
        this.rootViewBg = this.window.findViewById(R.id.rootViewBg);
        this.adapter = new PictureAlbumDirectoryAdapter(this.config);
        RecyclerView recyclerView = (RecyclerView) this.window.findViewById(R.id.folder_list);
        this.mRecyclerView = recyclerView;
        recyclerView.setLayoutManager(new LinearLayoutManager(this.context));
        this.mRecyclerView.setAdapter(this.adapter);
        this.rootView = this.window.findViewById(R.id.rootView);
        this.rootViewBg.setOnClickListener(new a(this));
    }

    public boolean isEmpty() {
        return this.adapter.getFolderData().size() == 0;
    }

    public void setArrowImageView(ImageView imageView) {
        this.ivArrowView = imageView;
    }

    public void setOnAlbumItemClickListener(OnAlbumItemClickListener onAlbumItemClickListener) {
        this.adapter.setOnAlbumItemClickListener(onAlbumItemClickListener);
    }

    public void showAsDropDown(View view) {
        try {
            if (Build.VERSION.SDK_INT == 24) {
                int[] iArr = new int[2];
                view.getLocationInWindow(iArr);
                showAtLocation(view, 0, 0, iArr[1] + view.getHeight());
            } else {
                super.showAsDropDown(view);
            }
            this.isDismiss = false;
            this.ivArrowView.setImageDrawable(this.drawableUp);
            AnimUtils.rotateArrow(this.ivArrowView, true);
            this.rootViewBg.animate().alpha(1.0f).setDuration(250).setStartDelay(250).start();
        } catch (Exception e2) {
            e2.printStackTrace();
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:11:0x0040, code lost:
        r5.setCheckedNum(1);
     */
    public void updateFolderCheckStatus(List<LocalMedia> list) {
        try {
            List<LocalMediaFolder> folderData = this.adapter.getFolderData();
            int size = folderData.size();
            int size2 = list.size();
            for (int i2 = 0; i2 < size; i2++) {
                LocalMediaFolder localMediaFolder = folderData.get(i2);
                localMediaFolder.setCheckedNum(0);
                int i3 = 0;
                while (true) {
                    if (i3 >= size2) {
                        break;
                    } else if (localMediaFolder.getName().equals(list.get(i3).getParentFolderName())) {
                        break;
                    } else if (localMediaFolder.getBucketId() == -1) {
                        break;
                    } else {
                        i3++;
                    }
                }
            }
            this.adapter.bindFolderData(folderData);
        } catch (Exception e2) {
            e2.printStackTrace();
        }
    }
}
