package com.tbruyelle.rxpermissions2;

import android.annotation.TargetApi;
import android.app.Activity;
import android.os.Build;
import android.text.TextUtils;
import androidx.annotation.NonNull;
import androidx.annotation.VisibleForTesting;
import androidx.appcompat.widget.ActivityChooserView;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentActivity;
import androidx.fragment.app.FragmentManager;
import f.a.a0.h;
import f.a.b0.b.a;
import f.a.b0.e.d.g;
import f.a.b0.e.d.i;
import f.a.b0.e.d.m;
import f.a.o;
import f.a.q;
import f.a.r;
import io.reactivex.internal.functions.Functions;
import io.reactivex.internal.operators.observable.ObservableConcatMap;
import io.reactivex.internal.util.ErrorMode;
import io.reactivex.subjects.PublishSubject;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

public class RxPermissions {
    public static final String TAG = "RxPermissions";
    public static final Object TRIGGER = new Object();
    @VisibleForTesting
    public Lazy<RxPermissionsFragment> mRxPermissionsFragment;

    @FunctionalInterface
    public interface Lazy<V> {
        V get();
    }

    public RxPermissions(@NonNull FragmentActivity fragmentActivity) {
        this.mRxPermissionsFragment = getLazySingleton(fragmentActivity.getSupportFragmentManager());
    }

    private RxPermissionsFragment findRxPermissionsFragment(@NonNull FragmentManager fragmentManager) {
        return (RxPermissionsFragment) fragmentManager.findFragmentByTag(TAG);
    }

    @NonNull
    private Lazy<RxPermissionsFragment> getLazySingleton(@NonNull final FragmentManager fragmentManager) {
        return new Lazy<RxPermissionsFragment>() {
            /* class com.tbruyelle.rxpermissions2.RxPermissions.AnonymousClass1 */
            private RxPermissionsFragment rxPermissionsFragment;

            @Override // com.tbruyelle.rxpermissions2.RxPermissions.Lazy
            public synchronized RxPermissionsFragment get() {
                if (this.rxPermissionsFragment == null) {
                    this.rxPermissionsFragment = RxPermissions.this.getRxPermissionsFragment(fragmentManager);
                }
                return this.rxPermissionsFragment;
            }
        };
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private RxPermissionsFragment getRxPermissionsFragment(@NonNull FragmentManager fragmentManager) {
        RxPermissionsFragment findRxPermissionsFragment = findRxPermissionsFragment(fragmentManager);
        if (!(findRxPermissionsFragment == null)) {
            return findRxPermissionsFragment;
        }
        RxPermissionsFragment rxPermissionsFragment = new RxPermissionsFragment();
        fragmentManager.beginTransaction().add(rxPermissionsFragment, TAG).commitNow();
        return rxPermissionsFragment;
    }

    private o<?> oneOf(o<?> oVar, o<?> oVar2) {
        if (oVar == null) {
            return o.f(TRIGGER);
        }
        Objects.requireNonNull(oVar2, "source2 is null");
        return o.d(oVar, oVar2).c(Functions.f5370a, false, 2);
    }

    private o<?> pending(String... strArr) {
        for (String str : strArr) {
            if (!this.mRxPermissionsFragment.get().containsByPermission(str)) {
                return g.f4963d;
            }
        }
        return o.f(TRIGGER);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @TargetApi(23)
    private o<Permission> requestImplementation(String... strArr) {
        ArrayList arrayList = new ArrayList(strArr.length);
        ArrayList arrayList2 = new ArrayList();
        for (String str : strArr) {
            this.mRxPermissionsFragment.get().log("Requesting permission " + str);
            if (isGranted(str)) {
                arrayList.add(new m(new Permission(str, true, false)));
            } else if (isRevoked(str)) {
                arrayList.add(new m(new Permission(str, false, false)));
            } else {
                PublishSubject<Permission> subjectByPermission = this.mRxPermissionsFragment.get().getSubjectByPermission(str);
                if (subjectByPermission == null) {
                    arrayList2.add(str);
                    subjectByPermission = new PublishSubject<>();
                    this.mRxPermissionsFragment.get().setSubjectForPermission(str, subjectByPermission);
                }
                arrayList.add(subjectByPermission);
            }
        }
        if (!arrayList2.isEmpty()) {
            requestPermissionsFromFragment((String[]) arrayList2.toArray(new String[arrayList2.size()]));
        }
        i iVar = new i(arrayList);
        int i2 = f.a.g.f5068d;
        a.b(i2, "prefetch");
        return new ObservableConcatMap(iVar, Functions.f5370a, i2, ErrorMode.IMMEDIATE);
    }

    @TargetApi(23)
    private boolean shouldShowRequestPermissionRationaleImplementation(Activity activity, String... strArr) {
        for (String str : strArr) {
            if (!(isGranted(str) || activity.shouldShowRequestPermissionRationale(str))) {
                return false;
            }
        }
        return true;
    }

    public <T> r<T, Boolean> ensure(final String... strArr) {
        return new r<T, Boolean>() {
            /* class com.tbruyelle.rxpermissions2.RxPermissions.AnonymousClass2 */

            @Override // f.a.r
            public q<Boolean> apply(o<T> oVar) {
                return RxPermissions.this.request(oVar, strArr).a(strArr.length).c(new h<List<Permission>, q<Boolean>>() {
                    /* class com.tbruyelle.rxpermissions2.RxPermissions.AnonymousClass2.AnonymousClass1 */

                    public q<Boolean> apply(List<Permission> list) {
                        if (list.isEmpty()) {
                            return g.f4963d;
                        }
                        for (Permission permission : list) {
                            if (!permission.granted) {
                                return o.f(Boolean.FALSE);
                            }
                        }
                        return o.f(Boolean.TRUE);
                    }
                }, false, ActivityChooserView.ActivityChooserViewAdapter.MAX_ACTIVITY_COUNT_UNLIMITED);
            }
        };
    }

    public <T> r<T, Permission> ensureEach(final String... strArr) {
        return new r<T, Permission>() {
            /* class com.tbruyelle.rxpermissions2.RxPermissions.AnonymousClass3 */

            @Override // f.a.r
            public q<Permission> apply(o<T> oVar) {
                return RxPermissions.this.request(oVar, strArr);
            }
        };
    }

    public <T> r<T, Permission> ensureEachCombined(final String... strArr) {
        return new r<T, Permission>() {
            /* class com.tbruyelle.rxpermissions2.RxPermissions.AnonymousClass4 */

            @Override // f.a.r
            public q<Permission> apply(o<T> oVar) {
                return RxPermissions.this.request(oVar, strArr).a(strArr.length).c(new h<List<Permission>, q<Permission>>() {
                    /* class com.tbruyelle.rxpermissions2.RxPermissions.AnonymousClass4.AnonymousClass1 */

                    public q<Permission> apply(List<Permission> list) {
                        if (list.isEmpty()) {
                            return g.f4963d;
                        }
                        return new m(new Permission(list));
                    }
                }, false, ActivityChooserView.ActivityChooserViewAdapter.MAX_ACTIVITY_COUNT_UNLIMITED);
            }
        };
    }

    public boolean isGranted(String str) {
        return !isMarshmallow() || this.mRxPermissionsFragment.get().isGranted(str);
    }

    public boolean isMarshmallow() {
        return Build.VERSION.SDK_INT >= 23;
    }

    public boolean isRevoked(String str) {
        return isMarshmallow() && this.mRxPermissionsFragment.get().isRevoked(str);
    }

    public void onRequestPermissionsResult(String[] strArr, int[] iArr) {
        this.mRxPermissionsFragment.get().onRequestPermissionsResult(strArr, iArr, new boolean[strArr.length]);
    }

    public o<Boolean> request(String... strArr) {
        return o.f(TRIGGER).b(ensure(strArr));
    }

    public o<Permission> requestEach(String... strArr) {
        return o.f(TRIGGER).b(ensureEach(strArr));
    }

    public o<Permission> requestEachCombined(String... strArr) {
        return o.f(TRIGGER).b(ensureEachCombined(strArr));
    }

    @TargetApi(23)
    public void requestPermissionsFromFragment(String[] strArr) {
        StringBuilder n = d.b.a.a.a.n("requestPermissionsFromFragment ");
        n.append(TextUtils.join(", ", strArr));
        this.mRxPermissionsFragment.get().log(n.toString());
        this.mRxPermissionsFragment.get().requestPermissions(strArr);
    }

    public void setLogging(boolean z) {
        this.mRxPermissionsFragment.get().setLogging(z);
    }

    public o<Boolean> shouldShowRequestPermissionRationale(Activity activity, String... strArr) {
        if (!isMarshmallow()) {
            return o.f(Boolean.FALSE);
        }
        return o.f(Boolean.valueOf(shouldShowRequestPermissionRationaleImplementation(activity, strArr)));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private o<Permission> request(o<?> oVar, final String... strArr) {
        if (strArr != null && strArr.length != 0) {
            return oneOf(oVar, pending(strArr)).c(new h<Object, o<Permission>>() {
                /* class com.tbruyelle.rxpermissions2.RxPermissions.AnonymousClass5 */

                @Override // f.a.a0.h
                public o<Permission> apply(Object obj) {
                    return RxPermissions.this.requestImplementation(strArr);
                }
            }, false, ActivityChooserView.ActivityChooserViewAdapter.MAX_ACTIVITY_COUNT_UNLIMITED);
        }
        throw new IllegalArgumentException("RxPermissions.request/requestEach requires at least one input permission");
    }

    public RxPermissions(@NonNull Fragment fragment) {
        this.mRxPermissionsFragment = getLazySingleton(fragment.getChildFragmentManager());
    }
}
