package com.yalantis.ucrop;

import android.content.Context;
import android.graphics.Bitmap;
import android.net.Uri;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.recyclerview.widget.RecyclerView;
import com.yalantis.ucrop.callback.BitmapLoadCallback;
import com.yalantis.ucrop.model.CutInfo;
import com.yalantis.ucrop.model.ExifInfo;
import com.yalantis.ucrop.util.BitmapLoadUtils;
import com.yalantis.ucrop.util.MimeType;
import com.yalantis.ucrop.util.SdkUtils;
import java.io.File;
import java.util.List;

public class PicturePhotoGalleryAdapter extends RecyclerView.Adapter<ViewHolder> {
    private Context context;
    private List<CutInfo> list;
    private OnItemClickListener listener;
    private LayoutInflater mInflater;
    private final int maxImageHeight = 220;
    private final int maxImageWidth = 200;

    public interface OnItemClickListener {
        void onItemClick(int i2, View view);
    }

    public static class ViewHolder extends RecyclerView.ViewHolder {
        public ImageView iv_dot;
        public ImageView mIvPhoto;
        public ImageView mIvVideo;
        public TextView tvGif;

        public ViewHolder(View view) {
            super(view);
            this.mIvPhoto = (ImageView) view.findViewById(R.id.iv_photo);
            this.mIvVideo = (ImageView) view.findViewById(R.id.iv_video);
            this.iv_dot = (ImageView) view.findViewById(R.id.iv_dot);
            this.tvGif = (TextView) view.findViewById(R.id.tv_gif);
        }
    }

    public PicturePhotoGalleryAdapter(Context context2, List<CutInfo> list2) {
        this.mInflater = LayoutInflater.from(context2);
        this.context = context2;
        this.list = list2;
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public int getItemCount() {
        List<CutInfo> list2 = this.list;
        if (list2 != null) {
            return list2.size();
        }
        return 0;
    }

    public void setData(List<CutInfo> list2) {
        this.list = list2;
        notifyDataSetChanged();
    }

    public void setOnItemClickListener(OnItemClickListener onItemClickListener) {
        this.listener = onItemClickListener;
    }

    public void onBindViewHolder(final ViewHolder viewHolder, int i2) {
        CutInfo cutInfo = this.list.get(i2);
        String path = cutInfo != null ? cutInfo.getPath() : "";
        int i3 = 0;
        if (cutInfo.isCut()) {
            viewHolder.iv_dot.setVisibility(0);
            viewHolder.iv_dot.setImageResource(R.drawable.ucrop_oval_true);
        } else {
            viewHolder.iv_dot.setVisibility(4);
        }
        if (MimeType.isHasVideo(cutInfo.getMimeType())) {
            viewHolder.mIvPhoto.setVisibility(8);
            viewHolder.mIvVideo.setVisibility(0);
            viewHolder.mIvVideo.setImageResource(R.drawable.ucrop_ic_default_video);
            return;
        }
        viewHolder.mIvPhoto.setVisibility(0);
        viewHolder.mIvVideo.setVisibility(8);
        Uri parse = (SdkUtils.isQ() || MimeType.isHttp(path)) ? Uri.parse(path) : Uri.fromFile(new File(path));
        TextView textView = viewHolder.tvGif;
        if (!MimeType.isGif(cutInfo.getMimeType())) {
            i3 = 8;
        }
        textView.setVisibility(i3);
        BitmapLoadUtils.decodeBitmapInBackground(this.context, parse, cutInfo.getHttpOutUri(), 200, 220, new BitmapLoadCallback() {
            /* class com.yalantis.ucrop.PicturePhotoGalleryAdapter.AnonymousClass1 */

            @Override // com.yalantis.ucrop.callback.BitmapLoadCallback
            public void onBitmapLoaded(@NonNull Bitmap bitmap, @NonNull ExifInfo exifInfo, @NonNull String str, @Nullable String str2) {
                ImageView imageView = viewHolder.mIvPhoto;
                if (imageView != null && bitmap != null) {
                    imageView.setImageBitmap(bitmap);
                }
            }

            @Override // com.yalantis.ucrop.callback.BitmapLoadCallback
            public void onFailure(@NonNull Exception exc) {
                ImageView imageView = viewHolder.mIvPhoto;
                if (imageView != null) {
                    imageView.setImageResource(R.color.ucrop_color_ba3);
                }
            }
        });
        viewHolder.itemView.setOnClickListener(new View.OnClickListener() {
            /* class com.yalantis.ucrop.PicturePhotoGalleryAdapter.AnonymousClass2 */

            public void onClick(View view) {
                if (PicturePhotoGalleryAdapter.this.listener != null) {
                    PicturePhotoGalleryAdapter.this.listener.onItemClick(viewHolder.getAdapterPosition(), view);
                }
            }
        });
    }

    @Override // androidx.recyclerview.widget.RecyclerView.Adapter
    public ViewHolder onCreateViewHolder(ViewGroup viewGroup, int i2) {
        return new ViewHolder(this.mInflater.inflate(R.layout.ucrop_picture_gf_adapter_edit_list, viewGroup, false));
    }
}
