package com.yalantis.ucrop.task;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Matrix;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.ParcelFileDescriptor;
import android.text.TextUtils;
import android.util.Log;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.core.content.ContextCompat;
import com.yalantis.ucrop.callback.BitmapLoadCallback;
import com.yalantis.ucrop.model.ExifInfo;
import com.yalantis.ucrop.util.BitmapLoadUtils;
import com.yalantis.ucrop.util.FileUtils;
import com.yalantis.ucrop.util.MimeType;
import com.yalantis.ucrop.util.SdkUtils;
import d.b.a.a.a;
import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileDescriptor;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.lang.ref.WeakReference;
import java.net.URL;
import java.util.Objects;

public class BitmapLoadTask extends AsyncTask<Void, Void, BitmapWorkerResult> {
    private static final String TAG = "BitmapWorkerTask";
    private final BitmapLoadCallback mBitmapLoadCallback;
    private WeakReference<Context> mContextWeakReference;
    private Uri mInputUri;
    private Uri mOutputUri;
    private final int mRequiredHeight;
    private final int mRequiredWidth;

    public BitmapLoadTask(@NonNull Context context, @NonNull Uri uri, @Nullable Uri uri2, int i2, int i3, BitmapLoadCallback bitmapLoadCallback) {
        this.mContextWeakReference = new WeakReference<>(context);
        this.mInputUri = uri;
        this.mOutputUri = uri2;
        this.mRequiredWidth = i2;
        this.mRequiredHeight = i3;
        this.mBitmapLoadCallback = bitmapLoadCallback;
    }

    private void copyFile(@NonNull Uri uri, @Nullable Uri uri2) {
        Throwable th;
        InputStream inputStream;
        Log.d(TAG, "copyFile");
        Objects.requireNonNull(uri2, "Output Uri is null - cannot copy image");
        FileOutputStream fileOutputStream = null;
        try {
            inputStream = getContext().getContentResolver().openInputStream(uri);
            try {
                FileOutputStream fileOutputStream2 = new FileOutputStream(new File(uri2.getPath()));
                if (inputStream != null) {
                    try {
                        byte[] bArr = new byte[1024];
                        while (true) {
                            int read = inputStream.read(bArr);
                            if (read > 0) {
                                fileOutputStream2.write(bArr, 0, read);
                            } else {
                                BitmapLoadUtils.close(fileOutputStream2);
                                BitmapLoadUtils.close(inputStream);
                                this.mInputUri = this.mOutputUri;
                                return;
                            }
                        }
                    } catch (Throwable th2) {
                        th = th2;
                        fileOutputStream = fileOutputStream2;
                        BitmapLoadUtils.close(fileOutputStream);
                        BitmapLoadUtils.close(inputStream);
                        this.mInputUri = this.mOutputUri;
                        throw th;
                    }
                } else {
                    throw new NullPointerException("InputStream for given input Uri is null");
                }
            } catch (Throwable th3) {
                th = th3;
                BitmapLoadUtils.close(fileOutputStream);
                BitmapLoadUtils.close(inputStream);
                this.mInputUri = this.mOutputUri;
                throw th;
            }
        } catch (Throwable th4) {
            th = th4;
            inputStream = null;
            BitmapLoadUtils.close(fileOutputStream);
            BitmapLoadUtils.close(inputStream);
            this.mInputUri = this.mOutputUri;
            throw th;
        }
    }

    private void downloadFile(@NonNull Uri uri, @Nullable Uri uri2) {
        OutputStream outputStream;
        Throwable th;
        BufferedInputStream bufferedInputStream;
        Exception e2;
        Log.d(TAG, "downloadFile");
        Objects.requireNonNull(uri2, "Output Uri is null - cannot download image");
        BufferedOutputStream bufferedOutputStream = null;
        try {
            URL url = new URL(uri.toString());
            byte[] bArr = new byte[1024];
            bufferedInputStream = new BufferedInputStream(url.openStream());
            try {
                outputStream = getContext().getContentResolver().openOutputStream(uri2);
                if (outputStream != null) {
                    try {
                        BufferedOutputStream bufferedOutputStream2 = new BufferedOutputStream(outputStream);
                        while (true) {
                            try {
                                int read = bufferedInputStream.read(bArr);
                                if (read <= -1) {
                                    break;
                                }
                                bufferedOutputStream2.write(bArr, 0, read);
                            } catch (Exception e3) {
                                e2 = e3;
                                bufferedOutputStream = bufferedOutputStream2;
                                try {
                                    e2.printStackTrace();
                                    this.mInputUri = this.mOutputUri;
                                    BitmapLoadUtils.close(bufferedOutputStream);
                                    BitmapLoadUtils.close(bufferedInputStream);
                                    BitmapLoadUtils.close(outputStream);
                                } catch (Throwable th2) {
                                    th = th2;
                                    this.mInputUri = this.mOutputUri;
                                    BitmapLoadUtils.close(bufferedOutputStream);
                                    BitmapLoadUtils.close(bufferedInputStream);
                                    BitmapLoadUtils.close(outputStream);
                                    throw th;
                                }
                            } catch (Throwable th3) {
                                th = th3;
                                bufferedOutputStream = bufferedOutputStream2;
                                this.mInputUri = this.mOutputUri;
                                BitmapLoadUtils.close(bufferedOutputStream);
                                BitmapLoadUtils.close(bufferedInputStream);
                                BitmapLoadUtils.close(outputStream);
                                throw th;
                            }
                        }
                        bufferedOutputStream2.flush();
                        bufferedOutputStream = bufferedOutputStream2;
                    } catch (Exception e4) {
                        e2 = e4;
                        e2.printStackTrace();
                        this.mInputUri = this.mOutputUri;
                        BitmapLoadUtils.close(bufferedOutputStream);
                        BitmapLoadUtils.close(bufferedInputStream);
                        BitmapLoadUtils.close(outputStream);
                    }
                }
            } catch (Exception e5) {
                e2 = e5;
                outputStream = null;
                e2.printStackTrace();
                this.mInputUri = this.mOutputUri;
                BitmapLoadUtils.close(bufferedOutputStream);
                BitmapLoadUtils.close(bufferedInputStream);
                BitmapLoadUtils.close(outputStream);
            } catch (Throwable th4) {
                th = th4;
                outputStream = null;
                this.mInputUri = this.mOutputUri;
                BitmapLoadUtils.close(bufferedOutputStream);
                BitmapLoadUtils.close(bufferedInputStream);
                BitmapLoadUtils.close(outputStream);
                throw th;
            }
        } catch (Exception e6) {
            e2 = e6;
            outputStream = null;
            bufferedInputStream = null;
            e2.printStackTrace();
            this.mInputUri = this.mOutputUri;
            BitmapLoadUtils.close(bufferedOutputStream);
            BitmapLoadUtils.close(bufferedInputStream);
            BitmapLoadUtils.close(outputStream);
        } catch (Throwable th5) {
            th = th5;
            outputStream = null;
            bufferedInputStream = null;
            this.mInputUri = this.mOutputUri;
            BitmapLoadUtils.close(bufferedOutputStream);
            BitmapLoadUtils.close(bufferedInputStream);
            BitmapLoadUtils.close(outputStream);
            throw th;
        }
        this.mInputUri = this.mOutputUri;
        BitmapLoadUtils.close(bufferedOutputStream);
        BitmapLoadUtils.close(bufferedInputStream);
        BitmapLoadUtils.close(outputStream);
    }

    private Context getContext() {
        return this.mContextWeakReference.get();
    }

    private String getFilePath() {
        if (ContextCompat.checkSelfPermission(getContext(), "android.permission.READ_EXTERNAL_STORAGE") == 0) {
            return FileUtils.getPath(getContext(), this.mInputUri);
        }
        return null;
    }

    private void processInputUri() {
        String scheme = this.mInputUri.getScheme();
        Log.d(TAG, "Uri scheme: " + scheme);
        if ("http".equals(scheme) || "https".equals(scheme)) {
            try {
                downloadFile(this.mInputUri, this.mOutputUri);
            } catch (IOException | NullPointerException e2) {
                Log.e(TAG, "Downloading failed", e2);
                throw e2;
            }
        } else if ("content".equals(scheme)) {
            String filePath = getFilePath();
            if (TextUtils.isEmpty(filePath) || !new File(filePath).exists()) {
                try {
                    copyFile(this.mInputUri, this.mOutputUri);
                } catch (IOException | NullPointerException e3) {
                    Log.e(TAG, "Copying failed", e3);
                    throw e3;
                }
            } else {
                this.mInputUri = SdkUtils.isQ() ? this.mInputUri : Uri.fromFile(new File(filePath));
            }
        } else if (!"file".equals(scheme)) {
            Log.e(TAG, "Invalid Uri scheme " + scheme);
            throw new IllegalArgumentException(a.g("Invalid Uri scheme", scheme));
        }
    }

    @NonNull
    public BitmapWorkerResult doInBackground(Void... voidArr) {
        if (this.mInputUri == null) {
            return new BitmapWorkerResult(new NullPointerException("Input Uri cannot be null"));
        }
        try {
            processInputUri();
            try {
                ParcelFileDescriptor openFileDescriptor = getContext().getContentResolver().openFileDescriptor(this.mInputUri, "r");
                if (openFileDescriptor != null) {
                    FileDescriptor fileDescriptor = openFileDescriptor.getFileDescriptor();
                    BitmapFactory.Options options = new BitmapFactory.Options();
                    options.inJustDecodeBounds = true;
                    BitmapFactory.decodeFileDescriptor(fileDescriptor, null, options);
                    if (options.outWidth == -1 || options.outHeight == -1) {
                        StringBuilder n = a.n("Bounds for bitmap could not be retrieved from the Uri: [");
                        n.append(this.mInputUri);
                        n.append("]");
                        return new BitmapWorkerResult(new IllegalArgumentException(n.toString()));
                    }
                    options.inSampleSize = BitmapLoadUtils.calculateInSampleSize(options, this.mRequiredWidth, this.mRequiredHeight);
                    boolean z = false;
                    options.inJustDecodeBounds = false;
                    Bitmap bitmap = null;
                    while (!z) {
                        try {
                            bitmap = BitmapFactory.decodeFileDescriptor(fileDescriptor, null, options);
                            z = true;
                        } catch (OutOfMemoryError e2) {
                            Log.e(TAG, "doInBackground: BitmapFactory.decodeFileDescriptor: ", e2);
                            options.inSampleSize *= 2;
                        }
                    }
                    if (bitmap == null) {
                        StringBuilder n2 = a.n("Bitmap could not be decoded from the Uri: [");
                        n2.append(this.mInputUri);
                        n2.append("]");
                        return new BitmapWorkerResult(new IllegalArgumentException(n2.toString()));
                    }
                    BitmapLoadUtils.close(openFileDescriptor);
                    int exifOrientation = BitmapLoadUtils.getExifOrientation(getContext(), this.mInputUri);
                    int exifToDegrees = BitmapLoadUtils.exifToDegrees(exifOrientation);
                    int exifToTranslation = BitmapLoadUtils.exifToTranslation(exifOrientation);
                    ExifInfo exifInfo = new ExifInfo(exifOrientation, exifToDegrees, exifToTranslation);
                    Matrix matrix = new Matrix();
                    if (exifToDegrees != 0) {
                        matrix.preRotate((float) exifToDegrees);
                    }
                    if (exifToTranslation != 1) {
                        matrix.postScale((float) exifToTranslation, 1.0f);
                    }
                    if (!matrix.isIdentity()) {
                        return new BitmapWorkerResult(BitmapLoadUtils.transformBitmap(bitmap, matrix), exifInfo);
                    }
                    return new BitmapWorkerResult(bitmap, exifInfo);
                }
                StringBuilder n3 = a.n("ParcelFileDescriptor was null for given Uri: [");
                n3.append(this.mInputUri);
                n3.append("]");
                return new BitmapWorkerResult(new NullPointerException(n3.toString()));
            } catch (FileNotFoundException e3) {
                return new BitmapWorkerResult(e3);
            }
        } catch (IOException | NullPointerException e4) {
            return new BitmapWorkerResult(e4);
        }
    }

    public void onPostExecute(@NonNull BitmapWorkerResult bitmapWorkerResult) {
        Exception exc = bitmapWorkerResult.mBitmapWorkerException;
        if (exc == null) {
            String uri = this.mInputUri.toString();
            BitmapLoadCallback bitmapLoadCallback = this.mBitmapLoadCallback;
            Bitmap bitmap = bitmapWorkerResult.mBitmapResult;
            ExifInfo exifInfo = bitmapWorkerResult.mExifInfo;
            if (!MimeType.isContent(uri)) {
                uri = this.mInputUri.getPath();
            }
            Uri uri2 = this.mOutputUri;
            bitmapLoadCallback.onBitmapLoaded(bitmap, exifInfo, uri, uri2 == null ? null : uri2.getPath());
            return;
        }
        this.mBitmapLoadCallback.onFailure(exc);
    }

    public static class BitmapWorkerResult {
        public Bitmap mBitmapResult;
        public Exception mBitmapWorkerException;
        public ExifInfo mExifInfo;

        public BitmapWorkerResult(@NonNull Bitmap bitmap, @NonNull ExifInfo exifInfo) {
            this.mBitmapResult = bitmap;
            this.mExifInfo = exifInfo;
        }

        public BitmapWorkerResult(@NonNull Exception exc) {
            this.mBitmapWorkerException = exc;
        }
    }
}
