package androidx.camera.core;

import android.content.ContentValues;
import android.net.Uri;
import android.os.Build;
import android.util.Log;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.camera.core.ImageCapture;
import androidx.camera.core.ImageUtil;
import androidx.camera.core.impl.utils.Exif;
import b.a.a.e0;
import b.a.a.f0;
import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.nio.ByteBuffer;
import java.util.concurrent.Executor;
import java.util.concurrent.RejectedExecutionException;

public final class ImageSaver implements Runnable {
    private static final int COPY_BUFFER_SIZE = 1024;
    private static final int NOT_PENDING = 0;
    private static final int PENDING = 1;
    private static final String TAG = "ImageSaver";
    private static final String TEMP_FILE_PREFIX = "CameraX";
    private static final String TEMP_FILE_SUFFIX = ".tmp";
    public final OnImageSavedCallback mCallback;
    private final Executor mExecutor;
    private final ImageProxy mImage;
    private final int mOrientation;
    @NonNull
    private final ImageCapture.OutputFileOptions mOutputFileOptions;

    /* renamed from: androidx.camera.core.ImageSaver$1  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass1 {
        public static final /* synthetic */ int[] $SwitchMap$androidx$camera$core$ImageUtil$CodecFailedException$FailureType;

        /* JADX WARNING: Can't wrap try/catch for region: R(6:0|1|2|3|4|(3:5|6|8)) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0011 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:5:0x001c */
        static {
            ImageUtil.CodecFailedException.FailureType.values();
            int[] iArr = new int[3];
            $SwitchMap$androidx$camera$core$ImageUtil$CodecFailedException$FailureType = iArr;
            iArr[ImageUtil.CodecFailedException.FailureType.ENCODE_FAILED.ordinal()] = 1;
            $SwitchMap$androidx$camera$core$ImageUtil$CodecFailedException$FailureType[ImageUtil.CodecFailedException.FailureType.DECODE_FAILED.ordinal()] = 2;
            try {
                $SwitchMap$androidx$camera$core$ImageUtil$CodecFailedException$FailureType[ImageUtil.CodecFailedException.FailureType.UNKNOWN.ordinal()] = 3;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public interface OnImageSavedCallback {
        void onError(SaveError saveError, String str, @Nullable Throwable th);

        void onImageSaved(@NonNull ImageCapture.OutputFileResults outputFileResults);
    }

    public enum SaveError {
        FILE_IO_FAILED,
        ENCODE_FAILED,
        CROP_FAILED,
        UNKNOWN
    }

    public ImageSaver(ImageProxy imageProxy, @NonNull ImageCapture.OutputFileOptions outputFileOptions, int i2, Executor executor, OnImageSavedCallback onImageSavedCallback) {
        this.mImage = imageProxy;
        this.mOutputFileOptions = outputFileOptions;
        this.mOrientation = i2;
        this.mCallback = onImageSavedCallback;
        this.mExecutor = executor;
    }

    private void copyTempFileToOutputStream(@NonNull File file, @NonNull OutputStream outputStream) {
        FileInputStream fileInputStream = new FileInputStream(file);
        try {
            byte[] bArr = new byte[1024];
            while (true) {
                int read = fileInputStream.read(bArr);
                if (read > 0) {
                    outputStream.write(bArr, 0, read);
                } else {
                    fileInputStream.close();
                    return;
                }
            }
        } catch (Throwable th) {
            th.addSuppressed(th);
        }
        throw th;
    }

    private boolean copyTempFileToUri(@NonNull File file, @NonNull Uri uri) {
        OutputStream openOutputStream = this.mOutputFileOptions.getContentResolver().openOutputStream(uri);
        if (openOutputStream == null) {
            if (openOutputStream != null) {
                openOutputStream.close();
            }
            return false;
        }
        try {
            copyTempFileToOutputStream(file, openOutputStream);
            openOutputStream.close();
            return true;
        } catch (Throwable th) {
            th.addSuppressed(th);
        }
        throw th;
    }

    private boolean isSaveToFile() {
        return this.mOutputFileOptions.getFile() != null;
    }

    private boolean isSaveToMediaStore() {
        return (this.mOutputFileOptions.getSaveCollection() == null || this.mOutputFileOptions.getContentResolver() == null || this.mOutputFileOptions.getContentValues() == null) ? false : true;
    }

    private boolean isSaveToOutputStream() {
        return this.mOutputFileOptions.getOutputStream() != null;
    }

    private void postError(SaveError saveError, String str, @Nullable Throwable th) {
        try {
            this.mExecutor.execute(new f0(this, saveError, str, th));
        } catch (RejectedExecutionException unused) {
            Log.e(TAG, "Application executor rejected executing OnImageSavedCallback.onError callback. Skipping.");
        }
    }

    private void postSuccess(@Nullable Uri uri) {
        try {
            this.mExecutor.execute(new e0(this, uri));
        } catch (RejectedExecutionException unused) {
            Log.e(TAG, "Application executor rejected executing OnImageSavedCallback.onImageSaved callback. Skipping.");
        }
    }

    private void setContentValuePending(@NonNull ContentValues contentValues, int i2) {
        if (Build.VERSION.SDK_INT >= 29) {
            contentValues.put("is_pending", Integer.valueOf(i2));
        }
    }

    private void setUriNotPending(@NonNull Uri uri) {
        if (Build.VERSION.SDK_INT >= 29) {
            ContentValues contentValues = new ContentValues();
            setContentValuePending(contentValues, 0);
            this.mOutputFileOptions.getContentResolver().update(uri, contentValues, null, null);
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r9v0, types: [androidx.camera.core.ImageSaver] */
    /* JADX WARN: Type inference failed for: r1v4, types: [java.lang.Throwable] */
    /* JADX WARN: Type inference failed for: r1v12, types: [java.lang.Throwable] */
    /* JADX WARNING: Code restructure failed: missing block: B:51:0x0102, code lost:
        if (isSaveToFile() == false) goto L_0x0104;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:52:0x0104, code lost:
        r0.delete();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:81:0x014e, code lost:
        if (isSaveToFile() == false) goto L_0x0104;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:85:0x015e, code lost:
        if (isSaveToFile() == false) goto L_0x0104;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:86:0x0161, code lost:
        if (r6 == null) goto L_0x0167;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:87:0x0163, code lost:
        postError(r6, r7, r2);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:88:0x0167, code lost:
        postSuccess(r5);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:96:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:97:?, code lost:
        return;
     */
    /* JADX WARNING: Removed duplicated region for block: B:63:0x011a A[SYNTHETIC, Splitter:B:63:0x011a] */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x0138 A[Catch:{ all -> 0x0129 }] */
    /* JADX WARNING: Removed duplicated region for block: B:79:0x0144 A[Catch:{ all -> 0x0129 }] */
    /* JADX WARNING: Unknown variable types count: 2 */
    public void run() {
        File file;
        String str;
        SaveError saveError;
        Uri uri;
        ImageUtil.CodecFailedException codecFailedException;
        int ordinal;
        String str2;
        SaveError saveError2;
        Throwable th;
        Throwable th2;
        ContentValues contentValues;
        try {
            if (isSaveToFile()) {
                file = this.mOutputFileOptions.getFile();
            } else {
                file = File.createTempFile(TEMP_FILE_PREFIX, TEMP_FILE_SUFFIX);
            }
            ImageUtil.CodecFailedException e2 = null;
            try {
                ImageProxy imageProxy = this.mImage;
                try {
                    FileOutputStream fileOutputStream = new FileOutputStream(file);
                    try {
                        fileOutputStream.write(ImageUtil.imageToJpegByteArray(this.mImage));
                        Exif createFromFile = Exif.createFromFile(file);
                        createFromFile.attachTimestamp();
                        if (this.mImage.getFormat() == 256) {
                            ByteBuffer buffer = this.mImage.getPlanes()[0].getBuffer();
                            buffer.rewind();
                            byte[] bArr = new byte[buffer.capacity()];
                            buffer.get(bArr);
                            createFromFile.setOrientation(Exif.createFromInputStream(new ByteArrayInputStream(bArr)).getOrientation());
                        } else {
                            createFromFile.rotate(this.mOrientation);
                        }
                        ImageCapture.Metadata metadata = this.mOutputFileOptions.getMetadata();
                        if (metadata.isReversedHorizontal()) {
                            createFromFile.flipHorizontally();
                        }
                        if (metadata.isReversedVertical()) {
                            createFromFile.flipVertically();
                        }
                        if (metadata.getLocation() != null) {
                            createFromFile.attachLocation(this.mOutputFileOptions.getMetadata().getLocation());
                        }
                        createFromFile.save();
                        if (isSaveToMediaStore()) {
                            if (this.mOutputFileOptions.getContentValues() != null) {
                                contentValues = new ContentValues(this.mOutputFileOptions.getContentValues());
                            } else {
                                contentValues = new ContentValues();
                            }
                            setContentValuePending(contentValues, 1);
                            uri = this.mOutputFileOptions.getContentResolver().insert(this.mOutputFileOptions.getSaveCollection(), contentValues);
                            if (uri == null) {
                                try {
                                    saveError = SaveError.FILE_IO_FAILED;
                                    str = "Failed to insert URI.";
                                } catch (Throwable th3) {
                                    th2 = th3;
                                    try {
                                        fileOutputStream.close();
                                    } catch (Throwable th4) {
                                        th2.addSuppressed(th4);
                                    }
                                    throw th2;
                                }
                            } else {
                                if (!copyTempFileToUri(file, uri)) {
                                    saveError = SaveError.FILE_IO_FAILED;
                                    str = "Failed to save to URI.";
                                } else {
                                    saveError = null;
                                    str = null;
                                }
                                setUriNotPending(uri);
                            }
                        } else {
                            if (isSaveToOutputStream()) {
                                copyTempFileToOutputStream(file, this.mOutputFileOptions.getOutputStream());
                            }
                            uri = null;
                            saveError = null;
                            str = null;
                        }
                    } catch (Throwable th5) {
                        th2 = th5;
                        fileOutputStream.close();
                        throw th2;
                    }
                    try {
                        fileOutputStream.close();
                        if (imageProxy != null) {
                            try {
                                imageProxy.close();
                            } catch (IOException | IllegalArgumentException e3) {
                                codecFailedException = e3;
                                e2 = codecFailedException;
                                saveError = SaveError.FILE_IO_FAILED;
                                str = "Failed to write or close the file";
                            } catch (ImageUtil.CodecFailedException e4) {
                                e2 = e4;
                                try {
                                    ordinal = e2.getFailureType().ordinal();
                                    if (ordinal != 0) {
                                        saveError2 = SaveError.ENCODE_FAILED;
                                        str2 = "Failed to encode mImage";
                                    } else if (ordinal != 1) {
                                        saveError2 = SaveError.UNKNOWN;
                                        str2 = "Failed to transcode mImage";
                                    } else {
                                        saveError2 = SaveError.CROP_FAILED;
                                        str2 = "Failed to crop mImage";
                                    }
                                    saveError = saveError2;
                                    str = str2;
                                } catch (Throwable th6) {
                                    if (!isSaveToFile()) {
                                        file.delete();
                                    }
                                    throw th6;
                                }
                            }
                        }
                    } catch (Throwable th7) {
                        th = th7;
                        if (imageProxy != null) {
                        }
                        throw th;
                    }
                } catch (Throwable th8) {
                    th = th8;
                    if (imageProxy != null) {
                        try {
                            imageProxy.close();
                        } catch (Throwable th9) {
                            th.addSuppressed(th9);
                        }
                    }
                    throw th;
                }
            } catch (IOException | IllegalArgumentException e5) {
                uri = null;
                codecFailedException = e5;
                e2 = codecFailedException;
                saveError = SaveError.FILE_IO_FAILED;
                str = "Failed to write or close the file";
            } catch (ImageUtil.CodecFailedException e6) {
                uri = null;
                e2 = e6;
                ordinal = e2.getFailureType().ordinal();
                if (ordinal != 0) {
                }
                saveError = saveError2;
                str = str2;
            }
        } catch (IOException e7) {
            postError(SaveError.FILE_IO_FAILED, "Failed to create temp file", e7);
        }
    }
}
