package androidx.camera.view;

import android.content.Context;
import android.util.AttributeSet;
import android.view.View;
import android.widget.FrameLayout;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.UiThread;
import androidx.annotation.VisibleForTesting;
import androidx.camera.core.CameraInfo;
import androidx.camera.core.CameraSelector;
import androidx.camera.core.MeteringPointFactory;
import androidx.camera.core.Preview;
import androidx.camera.core.impl.utils.Threads;
import androidx.camera.view.preview.transform.PreviewTransform;
import androidx.core.util.Preconditions;

public class PreviewView extends FrameLayout {
    private static final ImplementationMode DEFAULT_IMPL_MODE = ImplementationMode.SURFACE_VIEW;
    @Nullable
    @VisibleForTesting
    public PreviewViewImplementation mImplementation;
    private final View.OnLayoutChangeListener mOnLayoutChangeListener;
    @NonNull
    private ImplementationMode mPreferredImplementationMode;
    @NonNull
    private PreviewTransform mPreviewTransform;

    /* renamed from: androidx.camera.view.PreviewView$2  reason: invalid class name */
    public static /* synthetic */ class AnonymousClass2 {
        public static final /* synthetic */ int[] $SwitchMap$androidx$camera$view$PreviewView$ImplementationMode;

        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0011 */
        static {
            ImplementationMode.values();
            int[] iArr = new int[2];
            $SwitchMap$androidx$camera$view$PreviewView$ImplementationMode = iArr;
            iArr[ImplementationMode.SURFACE_VIEW.ordinal()] = 1;
            try {
                $SwitchMap$androidx$camera$view$PreviewView$ImplementationMode[ImplementationMode.TEXTURE_VIEW.ordinal()] = 2;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    public enum ImplementationMode {
        SURFACE_VIEW,
        TEXTURE_VIEW
    }

    public enum ScaleType {
        FILL_START,
        FILL_CENTER,
        FILL_END,
        FIT_START,
        FIT_CENTER,
        FIT_END
    }

    public PreviewView(@NonNull Context context) {
        this(context, null);
    }

    @NonNull
    private PreviewViewImplementation computeImplementation(@NonNull ImplementationMode implementationMode) {
        int ordinal = implementationMode.ordinal();
        if (ordinal == 0) {
            return new SurfaceViewImplementation();
        }
        if (ordinal == 1) {
            return new TextureViewImplementation();
        }
        throw new IllegalStateException("Unsupported implementation mode " + implementationMode);
    }

    @NonNull
    private ImplementationMode computeImplementationMode(@Nullable CameraInfo cameraInfo, @NonNull ImplementationMode implementationMode) {
        return (cameraInfo == null || cameraInfo.getImplementationType().equals(CameraInfo.IMPLEMENTATION_TYPE_CAMERA2_LEGACY)) ? ImplementationMode.TEXTURE_VIEW : implementationMode;
    }

    @NonNull
    public MeteringPointFactory createMeteringPointFactory(@NonNull CameraSelector cameraSelector) {
        Preconditions.checkNotNull(this.mImplementation);
        return new PreviewViewMeteringPointFactory(getDisplay(), cameraSelector, this.mImplementation.getResolution(), this.mPreviewTransform.getScaleType(), getWidth(), getHeight());
    }

    @NonNull
    @UiThread
    public Preview.SurfaceProvider createSurfaceProvider(@Nullable CameraInfo cameraInfo) {
        Threads.checkMainThread();
        removeAllViews();
        PreviewViewImplementation computeImplementation = computeImplementation(computeImplementationMode(cameraInfo, this.mPreferredImplementationMode));
        this.mImplementation = computeImplementation;
        computeImplementation.init(this, this.mPreviewTransform);
        return this.mImplementation.getSurfaceProvider();
    }

    @NonNull
    public ImplementationMode getPreferredImplementationMode() {
        return this.mPreferredImplementationMode;
    }

    @NonNull
    public ScaleType getScaleType() {
        return this.mPreviewTransform.getScaleType();
    }

    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        addOnLayoutChangeListener(this.mOnLayoutChangeListener);
    }

    public void onDetachedFromWindow() {
        super.onDetachedFromWindow();
        removeOnLayoutChangeListener(this.mOnLayoutChangeListener);
    }

    public void setPreferredImplementationMode(@NonNull ImplementationMode implementationMode) {
        this.mPreferredImplementationMode = implementationMode;
    }

    public void setScaleType(@NonNull ScaleType scaleType) {
        this.mPreviewTransform.setScaleType(scaleType);
        PreviewViewImplementation previewViewImplementation = this.mImplementation;
        if (previewViewImplementation != null) {
            previewViewImplementation.redrawPreview();
        }
    }

    public PreviewView(@NonNull Context context, @Nullable AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public PreviewView(@NonNull Context context, @Nullable AttributeSet attributeSet, int i2) {
        this(context, attributeSet, i2, 0);
    }

    public PreviewView(@NonNull Context context, @Nullable AttributeSet attributeSet, int i2, int i3) {
        super(context, attributeSet, i2, i3);
        this.mPreferredImplementationMode = DEFAULT_IMPL_MODE;
        this.mPreviewTransform = new PreviewTransform();
        this.mOnLayoutChangeListener = new View.OnLayoutChangeListener() {
            /* class androidx.camera.view.PreviewView.AnonymousClass1 */

            public void onLayoutChange(View view, int i2, int i3, int i4, int i5, int i6, int i7, int i8, int i9) {
                PreviewViewImplementation previewViewImplementation = PreviewView.this.mImplementation;
                if (previewViewImplementation != null) {
                    previewViewImplementation.redrawPreview();
                }
            }
        };
    }
}
