package com.luck.picture.lib;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.view.View;
import android.widget.TextView;
import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import com.luck.picture.lib.app.PictureAppMaster;
import com.luck.picture.lib.compress.Luban;
import com.luck.picture.lib.compress.OnCompressListener;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.dialog.PictureCustomDialog;
import com.luck.picture.lib.dialog.PictureLoadingDialog;
import com.luck.picture.lib.engine.PictureSelectorEngine;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.immersive.ImmersiveManage;
import com.luck.picture.lib.immersive.NavBarUtils;
import com.luck.picture.lib.language.PictureLanguageUtils;
import com.luck.picture.lib.listener.OnResultCallbackListener;
import com.luck.picture.lib.model.LocalMediaPageLoader;
import com.luck.picture.lib.permissions.PermissionChecker;
import com.luck.picture.lib.style.PictureCropParameterStyle;
import com.luck.picture.lib.style.PictureParameterStyle;
import com.luck.picture.lib.style.PictureWindowAnimationStyle;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.AndroidQTransformUtils;
import com.luck.picture.lib.tools.AttrsUtils;
import com.luck.picture.lib.tools.DateUtils;
import com.luck.picture.lib.tools.DoubleUtils;
import com.luck.picture.lib.tools.MediaUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.StringUtils;
import com.luck.picture.lib.tools.ToastUtils;
import com.luck.picture.lib.tools.VoiceUtils;
import com.yalantis.ucrop.UCrop;
import com.yalantis.ucrop.model.CutInfo;
import d.k.a.a.a;
import d.k.a.a.b;
import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

public abstract class PictureBaseActivity extends AppCompatActivity {

    /* renamed from: d  reason: collision with root package name */
    public static final /* synthetic */ int f987d = 0;
    public int colorPrimary;
    public int colorPrimaryDark;
    public PictureSelectionConfig config;
    public View container;
    private int index = 0;
    public boolean isHasMore = true;
    public boolean isOnSaveInstanceState;
    public Handler mHandler;
    public PictureLoadingDialog mLoadingDialog;
    public int mPage = 1;
    public boolean numComplete;
    public boolean openWhiteStatusBar;
    public List<LocalMedia> selectionMedias;

    private UCrop.Options basicOptions() {
        return basicOptions(null);
    }

    private void checkConfigNull() {
        if (this.config == null) {
            this.config = PictureSelectionConfig.getInstance();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void compressToLuban(final List<LocalMedia> list) {
        if (this.config.synOrAsy) {
            PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<List<File>>() {
                /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass2 */

                @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                public List<File> doInBackground() {
                    return Luban.with(PictureBaseActivity.this.getContext()).loadMediaData(list).isCamera(PictureBaseActivity.this.config.camera).setTargetDir(PictureBaseActivity.this.config.compressSavePath).setCompressQuality(PictureBaseActivity.this.config.compressQuality).setFocusAlpha(PictureBaseActivity.this.config.focusAlpha).setNewCompressFileName(PictureBaseActivity.this.config.renameCompressFileName).ignoreBy(PictureBaseActivity.this.config.minimumCompressSize).get();
                }

                public void onSuccess(List<File> list) {
                    if (list == null || list.size() <= 0 || list.size() != list.size()) {
                        PictureBaseActivity.this.onResult(list);
                    } else {
                        PictureBaseActivity.this.handleCompressCallBack(list, list);
                    }
                }
            });
        } else {
            Luban.with(this).loadMediaData(list).ignoreBy(this.config.minimumCompressSize).isCamera(this.config.camera).setCompressQuality(this.config.compressQuality).setTargetDir(this.config.compressSavePath).setFocusAlpha(this.config.focusAlpha).setNewCompressFileName(this.config.renameCompressFileName).setCompressListener(new OnCompressListener() {
                /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass3 */

                @Override // com.luck.picture.lib.compress.OnCompressListener
                public void onError(Throwable th) {
                    PictureBaseActivity.this.onResult(list);
                }

                @Override // com.luck.picture.lib.compress.OnCompressListener
                public void onStart() {
                }

                @Override // com.luck.picture.lib.compress.OnCompressListener
                public void onSuccess(List<LocalMedia> list) {
                    PictureBaseActivity.this.onResult(list);
                }
            }).launch();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleCompressCallBack(List<LocalMedia> list, List<File> list2) {
        if (list == null || list2 == null) {
            closeActivity();
            return;
        }
        boolean checkedAndroid_Q = SdkVersionUtils.checkedAndroid_Q();
        int size = list.size();
        if (list2.size() == size) {
            for (int i2 = 0; i2 < size; i2++) {
                File file = list2.get(i2);
                if (file != null) {
                    String absolutePath = file.getAbsolutePath();
                    LocalMedia localMedia = list.get(i2);
                    boolean z = true;
                    boolean z2 = !TextUtils.isEmpty(absolutePath) && PictureMimeType.isHasHttp(absolutePath);
                    boolean isHasVideo = PictureMimeType.isHasVideo(localMedia.getMimeType());
                    if (isHasVideo || z2) {
                        z = false;
                    }
                    localMedia.setCompressed(z);
                    if (isHasVideo || z2) {
                        absolutePath = null;
                    }
                    localMedia.setCompressPath(absolutePath);
                    if (checkedAndroid_Q) {
                        localMedia.setAndroidQToPath(localMedia.getCompressPath());
                    }
                }
            }
        }
        onResult(list);
    }

    private void initConfig() {
        List<LocalMedia> list = this.config.selectionMedias;
        if (list == null) {
            list = new ArrayList<>();
        }
        this.selectionMedias = list;
        PictureSelectionConfig pictureSelectionConfig = this.config;
        PictureParameterStyle pictureParameterStyle = pictureSelectionConfig.style;
        if (pictureParameterStyle != null) {
            this.openWhiteStatusBar = pictureParameterStyle.isChangeStatusBarFontColor;
            int i2 = pictureParameterStyle.pictureTitleBarBackgroundColor;
            if (i2 != 0) {
                this.colorPrimary = i2;
            }
            int i3 = pictureParameterStyle.pictureStatusBarColor;
            if (i3 != 0) {
                this.colorPrimaryDark = i3;
            }
            this.numComplete = pictureParameterStyle.isOpenCompletedNumStyle;
            pictureSelectionConfig.checkNumMode = pictureParameterStyle.isOpenCheckNumStyle;
        } else {
            boolean z = pictureSelectionConfig.isChangeStatusBarFontColor;
            this.openWhiteStatusBar = z;
            if (!z) {
                this.openWhiteStatusBar = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_statusFontColor);
            }
            boolean z2 = this.config.isOpenStyleNumComplete;
            this.numComplete = z2;
            if (!z2) {
                this.numComplete = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_style_numComplete);
            }
            PictureSelectionConfig pictureSelectionConfig2 = this.config;
            boolean z3 = pictureSelectionConfig2.isOpenStyleCheckNumMode;
            pictureSelectionConfig2.checkNumMode = z3;
            if (!z3) {
                pictureSelectionConfig2.checkNumMode = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_style_checkNumMode);
            }
            int i4 = this.config.titleBarBackgroundColor;
            if (i4 != 0) {
                this.colorPrimary = i4;
            } else {
                this.colorPrimary = AttrsUtils.getTypeValueColor(this, R.attr.colorPrimary);
            }
            int i5 = this.config.pictureStatusBarColor;
            if (i5 != 0) {
                this.colorPrimaryDark = i5;
            } else {
                this.colorPrimaryDark = AttrsUtils.getTypeValueColor(this, R.attr.colorPrimaryDark);
            }
        }
        if (this.config.openClickSound) {
            VoiceUtils.getInstance().init(getContext());
        }
    }

    private void newCreateEngine() {
        PictureSelectorEngine pictureSelectorEngine;
        if (PictureSelectionConfig.imageEngine == null && (pictureSelectorEngine = PictureAppMaster.getInstance().getPictureSelectorEngine()) != null) {
            PictureSelectionConfig.imageEngine = pictureSelectorEngine.createEngine();
        }
    }

    private void newCreateResultCallbackListener() {
        PictureSelectorEngine pictureSelectorEngine;
        if (this.config.isCallbackMode && PictureSelectionConfig.listener == null && (pictureSelectorEngine = PictureAppMaster.getInstance().getPictureSelectorEngine()) != null) {
            PictureSelectionConfig.listener = pictureSelectorEngine.getResultCallbackListener();
        }
    }

    private void onResultToAndroidAsy(final List<LocalMedia> list) {
        PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<List<LocalMedia>>() {
            /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass6 */

            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public List<LocalMedia> doInBackground() {
                int size = list.size();
                for (int i2 = 0; i2 < size; i2++) {
                    LocalMedia localMedia = (LocalMedia) list.get(i2);
                    if (localMedia != null && !TextUtils.isEmpty(localMedia.getPath())) {
                        if (!(!localMedia.isCut() && !localMedia.isCompressed() && TextUtils.isEmpty(localMedia.getAndroidQToPath())) || !PictureMimeType.isContent(localMedia.getPath())) {
                            if (localMedia.isCut() && localMedia.isCompressed()) {
                                localMedia.setAndroidQToPath(localMedia.getCompressPath());
                            }
                        } else if (!PictureMimeType.isHasHttp(localMedia.getPath())) {
                            localMedia.setAndroidQToPath(AndroidQTransformUtils.copyPathToAndroidQ(PictureBaseActivity.this.getContext(), localMedia.getPath(), localMedia.getWidth(), localMedia.getHeight(), localMedia.getMimeType(), PictureBaseActivity.this.config.cameraFileName));
                        }
                        if (PictureBaseActivity.this.config.isCheckOriginalImage) {
                            localMedia.setOriginal(true);
                            localMedia.setOriginalPath(localMedia.getAndroidQToPath());
                        }
                    }
                }
                return list;
            }

            public void onSuccess(List<LocalMedia> list) {
                PictureBaseActivity.this.dismissDialog();
                if (list != null) {
                    PictureBaseActivity pictureBaseActivity = PictureBaseActivity.this;
                    PictureSelectionConfig pictureSelectionConfig = pictureBaseActivity.config;
                    if (pictureSelectionConfig.camera && pictureSelectionConfig.selectionMode == 2 && pictureBaseActivity.selectionMedias != null) {
                        list.addAll(list.size() > 0 ? list.size() - 1 : 0, PictureBaseActivity.this.selectionMedias);
                    }
                    OnResultCallbackListener onResultCallbackListener = PictureSelectionConfig.listener;
                    if (onResultCallbackListener != null) {
                        onResultCallbackListener.onResult(list);
                    } else {
                        PictureBaseActivity.this.setResult(-1, PictureSelector.putIntentResult(list));
                    }
                    PictureBaseActivity.this.closeActivity();
                }
            }
        });
    }

    private void releaseResultListener() {
        if (this.config != null) {
            PictureSelectionConfig.destroy();
            LocalMediaPageLoader.setInstanceNull();
            PictureThreadUtils.cancel(PictureThreadUtils.getIoPool());
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startMultipleCropActivity(CutInfo cutInfo, int i2, UCrop.Options options) {
        Uri uri;
        String str;
        String path = cutInfo.getPath();
        String mimeType = cutInfo.getMimeType();
        boolean isHasHttp = PictureMimeType.isHasHttp(path);
        if (!TextUtils.isEmpty(cutInfo.getAndroidQToPath())) {
            uri = Uri.fromFile(new File(cutInfo.getAndroidQToPath()));
        } else {
            uri = (isHasHttp || SdkVersionUtils.checkedAndroid_Q()) ? Uri.parse(path) : Uri.fromFile(new File(path));
        }
        String replace = mimeType.replace("image/", ".");
        String diskCacheDir = PictureFileUtils.getDiskCacheDir(this);
        if (TextUtils.isEmpty(this.config.renameCropFileName)) {
            str = DateUtils.getCreateFileName("IMG_CROP_") + replace;
        } else {
            PictureSelectionConfig pictureSelectionConfig = this.config;
            if (pictureSelectionConfig.camera || i2 == 1) {
                str = pictureSelectionConfig.renameCropFileName;
            } else {
                str = StringUtils.rename(pictureSelectionConfig.renameCropFileName);
            }
        }
        UCrop withOptions = UCrop.of(uri, Uri.fromFile(new File(diskCacheDir, str))).withOptions(options);
        PictureWindowAnimationStyle pictureWindowAnimationStyle = this.config.windowAnimationStyle;
        withOptions.startAnimationMultipleCropActivity(this, pictureWindowAnimationStyle != null ? pictureWindowAnimationStyle.activityCropEnterAnimation : R.anim.picture_anim_enter);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startSingleCropActivity(String str, String str2, String str3, UCrop.Options options) {
        String str4;
        Uri uri;
        boolean isHasHttp = PictureMimeType.isHasHttp(str);
        String replace = str3.replace("image/", ".");
        String diskCacheDir = PictureFileUtils.getDiskCacheDir(getContext());
        if (TextUtils.isEmpty(this.config.renameCropFileName)) {
            str4 = DateUtils.getCreateFileName("IMG_CROP_") + replace;
        } else {
            str4 = this.config.renameCropFileName;
        }
        File file = new File(diskCacheDir, str4);
        if (!TextUtils.isEmpty(str2)) {
            uri = Uri.fromFile(new File(str2));
        } else {
            uri = (isHasHttp || SdkVersionUtils.checkedAndroid_Q()) ? Uri.parse(str) : Uri.fromFile(new File(str));
        }
        UCrop withOptions = UCrop.of(uri, Uri.fromFile(file)).withOptions(options);
        PictureWindowAnimationStyle pictureWindowAnimationStyle = this.config.windowAnimationStyle;
        withOptions.startAnimationActivity(this, pictureWindowAnimationStyle != null ? pictureWindowAnimationStyle.activityCropEnterAnimation : R.anim.picture_anim_enter);
    }

    @Override // androidx.appcompat.app.AppCompatActivity
    public void attachBaseContext(Context context) {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig == null) {
            super.attachBaseContext(context);
        } else {
            super.attachBaseContext(PictureContextWrapper.wrap(context, pictureSelectionConfig.language));
        }
    }

    public void closeActivity() {
        int i2;
        finish();
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig.camera) {
            overridePendingTransition(0, R.anim.picture_anim_fade_out);
        } else {
            PictureWindowAnimationStyle pictureWindowAnimationStyle = pictureSelectionConfig.windowAnimationStyle;
            if (pictureWindowAnimationStyle == null || (i2 = pictureWindowAnimationStyle.activityExitAnimation) == 0) {
                i2 = R.anim.picture_anim_exit;
            }
            overridePendingTransition(0, i2);
        }
        if (this.config.camera) {
            if ((getContext() instanceof PictureSelectorCameraEmptyActivity) || (getContext() instanceof PictureCustomCameraActivity)) {
                releaseResultListener();
            }
        } else if (getContext() instanceof PictureSelectorActivity) {
            releaseResultListener();
            if (this.config.openClickSound) {
                VoiceUtils.getInstance().releaseSoundPool();
            }
        }
    }

    public void compressImage(final List<LocalMedia> list) {
        showPleaseDialog();
        if (PictureSelectionConfig.cacheResourcesEngine != null) {
            PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<List<LocalMedia>>() {
                /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass1 */

                @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                public List<LocalMedia> doInBackground() {
                    int size = list.size();
                    for (int i2 = 0; i2 < size; i2++) {
                        LocalMedia localMedia = (LocalMedia) list.get(i2);
                        if (localMedia != null && !PictureMimeType.isHasHttp(localMedia.getPath())) {
                            localMedia.setAndroidQToPath(PictureSelectionConfig.cacheResourcesEngine.onCachePath(PictureBaseActivity.this.getContext(), localMedia.getPath()));
                        }
                    }
                    return list;
                }

                public void onSuccess(List<LocalMedia> list) {
                    PictureBaseActivity.this.compressToLuban(list);
                }
            });
        } else {
            compressToLuban(list);
        }
    }

    public void createNewFolder(List<LocalMediaFolder> list) {
        int i2;
        if (list.size() == 0) {
            LocalMediaFolder localMediaFolder = new LocalMediaFolder();
            if (this.config.chooseMode == PictureMimeType.ofAudio()) {
                i2 = R.string.picture_all_audio;
            } else {
                i2 = R.string.picture_camera_roll;
            }
            localMediaFolder.setName(getString(i2));
            localMediaFolder.setFirstImagePath("");
            localMediaFolder.setCameraFolder(true);
            localMediaFolder.setBucketId(-1);
            localMediaFolder.setChecked(true);
            list.add(localMediaFolder);
        }
    }

    public void dismissDialog() {
        if (!isFinishing()) {
            try {
                PictureLoadingDialog pictureLoadingDialog = this.mLoadingDialog;
                if (pictureLoadingDialog != null && pictureLoadingDialog.isShowing()) {
                    this.mLoadingDialog.dismiss();
                }
            } catch (Exception e2) {
                this.mLoadingDialog = null;
                e2.printStackTrace();
            }
        }
    }

    public String getAudioPath(Intent intent) {
        if (intent == null || this.config.chooseMode != PictureMimeType.ofAudio()) {
            return "";
        }
        try {
            Uri data = intent.getData();
            if (data != null) {
                return MediaUtils.getAudioFilePathFromUri(getContext(), data);
            }
            return "";
        } catch (Exception e2) {
            e2.printStackTrace();
            return "";
        }
    }

    public Context getContext() {
        return this;
    }

    public LocalMediaFolder getImageFolder(String str, String str2, List<LocalMediaFolder> list) {
        if (!PictureMimeType.isContent(str)) {
            str2 = str;
        }
        File parentFile = new File(str2).getParentFile();
        for (LocalMediaFolder localMediaFolder : list) {
            if (parentFile != null && localMediaFolder.getName().equals(parentFile.getName())) {
                return localMediaFolder;
            }
        }
        LocalMediaFolder localMediaFolder2 = new LocalMediaFolder();
        localMediaFolder2.setName(parentFile != null ? parentFile.getName() : "");
        localMediaFolder2.setFirstImagePath(str);
        list.add(localMediaFolder2);
        return localMediaFolder2;
    }

    public abstract int getResourceId();

    public void handlerResult(List<LocalMedia> list) {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (!pictureSelectionConfig.isCompress || pictureSelectionConfig.isCheckOriginalImage) {
            onResult(list);
        } else {
            compressImage(list);
        }
    }

    public void immersive() {
        ImmersiveManage.immersiveAboveAPI23(this, this.colorPrimaryDark, this.colorPrimary, this.openWhiteStatusBar);
    }

    public void initCompleteText(int i2) {
    }

    public void initCompleteText(List<LocalMedia> list) {
    }

    public void initPictureSelectorStyle() {
    }

    public void initWidgets() {
    }

    public boolean isImmersive() {
        return true;
    }

    public boolean isRequestedOrientation() {
        return true;
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity, androidx.fragment.app.FragmentActivity
    public void onCreate(Bundle bundle) {
        int i2;
        if (bundle != null) {
            this.config = (PictureSelectionConfig) bundle.getParcelable(PictureConfig.EXTRA_CONFIG);
        }
        if (this.config == null) {
            this.config = getIntent() != null ? (PictureSelectionConfig) getIntent().getParcelableExtra(PictureConfig.EXTRA_CONFIG) : this.config;
        }
        checkConfigNull();
        PictureLanguageUtils.setAppLanguage(getContext(), this.config.language);
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (!pictureSelectionConfig.camera) {
            int i3 = pictureSelectionConfig.themeStyleId;
            if (i3 == 0) {
                i3 = R.style.picture_default_style;
            }
            setTheme(i3);
        }
        if (bundle == null) {
            bundle = new Bundle();
        }
        super.onCreate(bundle);
        newCreateEngine();
        newCreateResultCallbackListener();
        if (isRequestedOrientation()) {
            setNewRequestedOrientation();
        }
        this.mHandler = new Handler(Looper.getMainLooper());
        initConfig();
        if (isImmersive()) {
            immersive();
        }
        PictureParameterStyle pictureParameterStyle = this.config.style;
        if (!(pictureParameterStyle == null || (i2 = pictureParameterStyle.pictureNavBarColor) == 0)) {
            NavBarUtils.setNavBarColor(this, i2);
        }
        int resourceId = getResourceId();
        if (resourceId != 0) {
            setContentView(resourceId);
        }
        initWidgets();
        initPictureSelectorStyle();
        this.isOnSaveInstanceState = false;
    }

    @Override // androidx.appcompat.app.AppCompatActivity, androidx.fragment.app.FragmentActivity
    public void onDestroy() {
        PictureLoadingDialog pictureLoadingDialog = this.mLoadingDialog;
        if (pictureLoadingDialog != null) {
            pictureLoadingDialog.dismiss();
            this.mLoadingDialog = null;
        }
        super.onDestroy();
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ActivityCompat.OnRequestPermissionsResultCallback, androidx.fragment.app.FragmentActivity
    public void onRequestPermissionsResult(int i2, @NonNull String[] strArr, @NonNull int[] iArr) {
        super.onRequestPermissionsResult(i2, strArr, iArr);
        if (i2 != 3) {
            return;
        }
        if (iArr[0] == 0) {
            Intent intent = new Intent("android.provider.MediaStore.RECORD_SOUND");
            if (intent.resolveActivity(getPackageManager()) != null) {
                startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
                return;
            }
            return;
        }
        ToastUtils.s(getContext(), getString(R.string.picture_audio));
    }

    public void onResult(List<LocalMedia> list) {
        if (!SdkVersionUtils.checkedAndroid_Q() || !this.config.isAndroidQTransform) {
            dismissDialog();
            PictureSelectionConfig pictureSelectionConfig = this.config;
            if (pictureSelectionConfig.camera && pictureSelectionConfig.selectionMode == 2 && this.selectionMedias != null) {
                list.addAll(list.size() > 0 ? list.size() - 1 : 0, this.selectionMedias);
            }
            if (this.config.isCheckOriginalImage) {
                int size = list.size();
                for (int i2 = 0; i2 < size; i2++) {
                    LocalMedia localMedia = list.get(i2);
                    localMedia.setOriginal(true);
                    localMedia.setOriginalPath(localMedia.getPath());
                }
            }
            OnResultCallbackListener onResultCallbackListener = PictureSelectionConfig.listener;
            if (onResultCallbackListener != null) {
                onResultCallbackListener.onResult(list);
            } else {
                setResult(-1, PictureSelector.putIntentResult(list));
            }
            closeActivity();
            return;
        }
        showPleaseDialog();
        onResultToAndroidAsy(list);
    }

    @Override // androidx.activity.ComponentActivity, androidx.core.app.ComponentActivity
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        this.isOnSaveInstanceState = true;
        bundle.putParcelable(PictureConfig.EXTRA_CONFIG, this.config);
    }

    public void setNewRequestedOrientation() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        if (pictureSelectionConfig != null && !pictureSelectionConfig.camera) {
            setRequestedOrientation(pictureSelectionConfig.requestedOrientation);
        }
    }

    public void showPermissionsDialog(boolean z, String str) {
    }

    public void showPleaseDialog() {
        try {
            if (!isFinishing()) {
                if (this.mLoadingDialog == null) {
                    this.mLoadingDialog = new PictureLoadingDialog(getContext());
                }
                if (this.mLoadingDialog.isShowing()) {
                    this.mLoadingDialog.dismiss();
                }
                this.mLoadingDialog.show();
            }
        } catch (Exception e2) {
            e2.printStackTrace();
        }
    }

    public void showPromptDialog(String str) {
        if (!isFinishing()) {
            PictureCustomDialog pictureCustomDialog = new PictureCustomDialog(getContext(), R.layout.picture_prompt_dialog);
            ((TextView) pictureCustomDialog.findViewById(R.id.tv_content)).setText(str);
            ((TextView) pictureCustomDialog.findViewById(R.id.btnOk)).setOnClickListener(new b(this, pictureCustomDialog));
            pictureCustomDialog.show();
        }
    }

    public void sortFolder(List<LocalMediaFolder> list) {
        Collections.sort(list, a.f4207d);
    }

    public void startCrop(final String str, final String str2) {
        if (!DoubleUtils.isFastDoubleClick()) {
            if (TextUtils.isEmpty(str)) {
                ToastUtils.s(this, getString(R.string.picture_not_crop_data));
                return;
            }
            final UCrop.Options basicOptions = basicOptions();
            if (PictureSelectionConfig.cacheResourcesEngine != null) {
                PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<String>() {
                    /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass4 */

                    @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                    public String doInBackground() {
                        return PictureSelectionConfig.cacheResourcesEngine.onCachePath(PictureBaseActivity.this.getContext(), str);
                    }

                    public void onSuccess(String str) {
                        PictureBaseActivity.this.startSingleCropActivity(str, str, str2, basicOptions);
                    }
                });
            } else {
                startSingleCropActivity(str, null, str2, basicOptions);
            }
        }
    }

    public void startOpenCamera() {
        Uri uri;
        String str;
        Intent intent = new Intent("android.media.action.IMAGE_CAPTURE");
        if (intent.resolveActivity(getPackageManager()) != null) {
            if (SdkVersionUtils.checkedAndroid_Q()) {
                uri = MediaUtils.createImageUri(getApplicationContext(), this.config.suffixType);
                if (uri != null) {
                    this.config.cameraPath = uri.toString();
                } else {
                    ToastUtils.s(getContext(), "open is camera error，the uri is empty ");
                    if (this.config.camera) {
                        closeActivity();
                        return;
                    }
                    return;
                }
            } else {
                PictureSelectionConfig pictureSelectionConfig = this.config;
                int i2 = pictureSelectionConfig.chooseMode;
                if (i2 == 0) {
                    i2 = 1;
                }
                if (!TextUtils.isEmpty(pictureSelectionConfig.cameraFileName)) {
                    boolean isSuffixOfImage = PictureMimeType.isSuffixOfImage(this.config.cameraFileName);
                    PictureSelectionConfig pictureSelectionConfig2 = this.config;
                    pictureSelectionConfig2.cameraFileName = !isSuffixOfImage ? StringUtils.renameSuffix(pictureSelectionConfig2.cameraFileName, ".jpg") : pictureSelectionConfig2.cameraFileName;
                    PictureSelectionConfig pictureSelectionConfig3 = this.config;
                    boolean z = pictureSelectionConfig3.camera;
                    str = pictureSelectionConfig3.cameraFileName;
                    if (!z) {
                        str = StringUtils.rename(str);
                    }
                } else {
                    str = "";
                }
                Context applicationContext = getApplicationContext();
                PictureSelectionConfig pictureSelectionConfig4 = this.config;
                File createCameraFile = PictureFileUtils.createCameraFile(applicationContext, i2, str, pictureSelectionConfig4.suffixType, pictureSelectionConfig4.outPutCameraPath);
                if (createCameraFile != null) {
                    this.config.cameraPath = createCameraFile.getAbsolutePath();
                    uri = PictureFileUtils.parUri(this, createCameraFile);
                } else {
                    ToastUtils.s(getContext(), "open is camera error，the uri is empty ");
                    if (this.config.camera) {
                        closeActivity();
                        return;
                    }
                    return;
                }
            }
            this.config.cameraMimeType = PictureMimeType.ofImage();
            if (this.config.isCameraAroundState) {
                intent.putExtra(PictureConfig.CAMERA_FACING, 1);
            }
            intent.putExtra("output", uri);
            startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
        }
    }

    public void startOpenCameraAudio() {
        if (PermissionChecker.checkSelfPermission(this, "android.permission.RECORD_AUDIO")) {
            Intent intent = new Intent("android.provider.MediaStore.RECORD_SOUND");
            if (intent.resolveActivity(getPackageManager()) != null) {
                this.config.cameraMimeType = PictureMimeType.ofAudio();
                startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
                return;
            }
            return;
        }
        PermissionChecker.requestPermissions(this, new String[]{"android.permission.RECORD_AUDIO"}, 3);
    }

    public void startOpenCameraVideo() {
        Uri uri;
        String str;
        Intent intent = new Intent("android.media.action.VIDEO_CAPTURE");
        if (intent.resolveActivity(getPackageManager()) != null) {
            if (SdkVersionUtils.checkedAndroid_Q()) {
                uri = MediaUtils.createVideoUri(getApplicationContext(), this.config.suffixType);
                if (uri != null) {
                    this.config.cameraPath = uri.toString();
                } else {
                    ToastUtils.s(getContext(), "open is camera error，the uri is empty ");
                    if (this.config.camera) {
                        closeActivity();
                        return;
                    }
                    return;
                }
            } else {
                PictureSelectionConfig pictureSelectionConfig = this.config;
                int i2 = pictureSelectionConfig.chooseMode;
                if (i2 == 0) {
                    i2 = 2;
                }
                if (!TextUtils.isEmpty(pictureSelectionConfig.cameraFileName)) {
                    boolean isSuffixOfImage = PictureMimeType.isSuffixOfImage(this.config.cameraFileName);
                    PictureSelectionConfig pictureSelectionConfig2 = this.config;
                    pictureSelectionConfig2.cameraFileName = isSuffixOfImage ? StringUtils.renameSuffix(pictureSelectionConfig2.cameraFileName, ".mp4") : pictureSelectionConfig2.cameraFileName;
                    PictureSelectionConfig pictureSelectionConfig3 = this.config;
                    boolean z = pictureSelectionConfig3.camera;
                    str = pictureSelectionConfig3.cameraFileName;
                    if (!z) {
                        str = StringUtils.rename(str);
                    }
                } else {
                    str = "";
                }
                Context applicationContext = getApplicationContext();
                PictureSelectionConfig pictureSelectionConfig4 = this.config;
                File createCameraFile = PictureFileUtils.createCameraFile(applicationContext, i2, str, pictureSelectionConfig4.suffixType, pictureSelectionConfig4.outPutCameraPath);
                if (createCameraFile != null) {
                    this.config.cameraPath = createCameraFile.getAbsolutePath();
                    uri = PictureFileUtils.parUri(this, createCameraFile);
                } else {
                    ToastUtils.s(getContext(), "open is camera error，the uri is empty ");
                    if (this.config.camera) {
                        closeActivity();
                        return;
                    }
                    return;
                }
            }
            this.config.cameraMimeType = PictureMimeType.ofVideo();
            intent.putExtra("output", uri);
            if (this.config.isCameraAroundState) {
                intent.putExtra(PictureConfig.CAMERA_FACING, 1);
            }
            intent.putExtra(PictureConfig.EXTRA_QUICK_CAPTURE, this.config.isQuickCapture);
            intent.putExtra("android.intent.extra.durationLimit", this.config.recordVideoSecond);
            intent.putExtra("android.intent.extra.videoQuality", this.config.videoQuality);
            startActivityForResult(intent, PictureConfig.REQUEST_CAMERA);
        }
    }

    private UCrop.Options basicOptions(ArrayList<CutInfo> arrayList) {
        int i2;
        int i3;
        boolean z;
        int i4;
        int i5;
        PictureSelectionConfig pictureSelectionConfig = this.config;
        PictureCropParameterStyle pictureCropParameterStyle = pictureSelectionConfig.cropStyle;
        int i6 = 0;
        if (pictureCropParameterStyle != null) {
            i4 = pictureCropParameterStyle.cropTitleBarBackgroundColor;
            if (i4 == 0) {
                i4 = 0;
            }
            i3 = pictureCropParameterStyle.cropStatusBarColorPrimaryDark;
            if (i3 == 0) {
                i3 = 0;
            }
            i2 = pictureCropParameterStyle.cropTitleColor;
            if (i2 == 0) {
                i2 = 0;
            }
            z = pictureCropParameterStyle.isChangeStatusBarFontColor;
        } else {
            i4 = pictureSelectionConfig.cropTitleBarBackgroundColor;
            if (i4 == 0) {
                i4 = AttrsUtils.getTypeValueColor(this, R.attr.picture_crop_toolbar_bg);
            }
            int i7 = this.config.cropStatusBarColorPrimaryDark;
            if (i7 == 0) {
                i7 = AttrsUtils.getTypeValueColor(this, R.attr.picture_crop_status_color);
            }
            i3 = i7;
            int i8 = this.config.cropTitleColor;
            if (i8 == 0) {
                i8 = AttrsUtils.getTypeValueColor(this, R.attr.picture_crop_title_color);
            }
            i2 = i8;
            z = this.config.isChangeStatusBarFontColor;
            if (!z) {
                z = AttrsUtils.getTypeValueBoolean(this, R.attr.picture_statusFontColor);
            }
        }
        UCrop.Options options = this.config.uCropOptions;
        if (options == null) {
            options = new UCrop.Options();
        }
        options.isOpenWhiteStatusBar(z);
        options.setToolbarColor(i4);
        options.setStatusBarColor(i3);
        options.setToolbarWidgetColor(i2);
        options.setCircleDimmedLayer(this.config.circleDimmedLayer);
        options.setDimmedLayerColor(this.config.circleDimmedColor);
        options.setDimmedLayerBorderColor(this.config.circleDimmedBorderColor);
        options.setCircleStrokeWidth(this.config.circleStrokeWidth);
        options.setShowCropFrame(this.config.showCropFrame);
        options.setDragFrameEnabled(this.config.isDragFrame);
        options.setShowCropGrid(this.config.showCropGrid);
        options.setScaleEnabled(this.config.scaleEnabled);
        options.setRotateEnabled(this.config.rotateEnabled);
        options.isMultipleSkipCrop(this.config.isMultipleSkipCrop);
        options.setHideBottomControls(this.config.hideBottomControls);
        options.setCompressionQuality(this.config.cropCompressQuality);
        options.setRenameCropFileName(this.config.renameCropFileName);
        options.isCamera(this.config.camera);
        options.setCutListData(arrayList);
        options.isWithVideoImage(this.config.isWithVideoImage);
        options.setFreeStyleCropEnabled(this.config.freeStyleCropEnabled);
        PictureWindowAnimationStyle pictureWindowAnimationStyle = this.config.windowAnimationStyle;
        options.setCropExitAnimation(pictureWindowAnimationStyle != null ? pictureWindowAnimationStyle.activityCropExitAnimation : 0);
        PictureCropParameterStyle pictureCropParameterStyle2 = this.config.cropStyle;
        if (pictureCropParameterStyle2 != null) {
            i6 = pictureCropParameterStyle2.cropNavBarColor;
        }
        options.setNavBarColor(i6);
        PictureSelectionConfig pictureSelectionConfig2 = this.config;
        options.withAspectRatio((float) pictureSelectionConfig2.aspect_ratio_x, (float) pictureSelectionConfig2.aspect_ratio_y);
        options.isMultipleRecyclerAnimation(this.config.isMultipleRecyclerAnimation);
        PictureSelectionConfig pictureSelectionConfig3 = this.config;
        int i9 = pictureSelectionConfig3.cropWidth;
        if (i9 > 0 && (i5 = pictureSelectionConfig3.cropHeight) > 0) {
            options.withMaxResultSize(i9, i5);
        }
        return options;
    }

    public void startCrop(final ArrayList<CutInfo> arrayList) {
        if (!DoubleUtils.isFastDoubleClick()) {
            if (arrayList == null || arrayList.size() == 0) {
                ToastUtils.s(this, getString(R.string.picture_not_crop_data));
                return;
            }
            final UCrop.Options basicOptions = basicOptions(arrayList);
            final int size = arrayList.size();
            int i2 = 0;
            this.index = 0;
            if (this.config.chooseMode == PictureMimeType.ofAll() && this.config.isWithVideoImage) {
                if (PictureMimeType.isHasVideo(size > 0 ? arrayList.get(this.index).getMimeType() : "")) {
                    while (true) {
                        if (i2 < size) {
                            CutInfo cutInfo = arrayList.get(i2);
                            if (cutInfo != null && PictureMimeType.isHasImage(cutInfo.getMimeType())) {
                                this.index = i2;
                                break;
                            }
                            i2++;
                        } else {
                            break;
                        }
                    }
                }
            }
            if (PictureSelectionConfig.cacheResourcesEngine != null) {
                PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<List<CutInfo>>() {
                    /* class com.luck.picture.lib.PictureBaseActivity.AnonymousClass5 */

                    @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
                    public List<CutInfo> doInBackground() {
                        for (int i2 = 0; i2 < size; i2++) {
                            CutInfo cutInfo = (CutInfo) arrayList.get(i2);
                            String onCachePath = PictureSelectionConfig.cacheResourcesEngine.onCachePath(PictureBaseActivity.this.getContext(), cutInfo.getPath());
                            if (!TextUtils.isEmpty(onCachePath)) {
                                cutInfo.setAndroidQToPath(onCachePath);
                            }
                        }
                        return arrayList;
                    }

                    public void onSuccess(List<CutInfo> list) {
                        if (PictureBaseActivity.this.index < size) {
                            PictureBaseActivity pictureBaseActivity = PictureBaseActivity.this;
                            pictureBaseActivity.startMultipleCropActivity(list.get(pictureBaseActivity.index), size, basicOptions);
                        }
                    }
                });
                return;
            }
            int i3 = this.index;
            if (i3 < size) {
                startMultipleCropActivity(arrayList.get(i3), size, basicOptions);
            }
        }
    }
}
