package com.luck.picture.lib.model;

import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.provider.MediaStore;
import android.text.TextUtils;
import android.util.Log;
import com.luck.picture.lib.R;
import com.luck.picture.lib.config.PictureMimeType;
import com.luck.picture.lib.config.PictureSelectionConfig;
import com.luck.picture.lib.entity.LocalMedia;
import com.luck.picture.lib.entity.LocalMediaFolder;
import com.luck.picture.lib.entity.MediaData;
import com.luck.picture.lib.listener.OnQueryDataResultListener;
import com.luck.picture.lib.thread.PictureThreadUtils;
import com.luck.picture.lib.tools.PictureFileUtils;
import com.luck.picture.lib.tools.SdkVersionUtils;
import com.luck.picture.lib.tools.ValueOf;
import d.b.a.a.a;
import d.k.a.a.k0.b;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Locale;

public final class LocalMediaPageLoader {
    private static final int AUDIO_DURATION = 500;
    private static final String COLUMN_BUCKET_DISPLAY_NAME = "bucket_display_name";
    private static final String COLUMN_BUCKET_ID = "bucket_id";
    private static final String COLUMN_COUNT = "count";
    private static final long FILE_SIZE_UNIT = 1048576;
    private static final String GROUP_BY_BUCKET_Id = " GROUP BY (bucket_id";
    private static final String NOT_GIF = "!='image/gif' AND mime_type!='image/*'";
    private static final String NOT_GIF_UNKNOWN = "!='image/*'";
    private static final String ORDER_BY = "_id DESC";
    private static final String[] PROJECTION = {"_id", "_data", "bucket_id", COLUMN_BUCKET_DISPLAY_NAME, "mime_type", "COUNT(*) AS count"};
    private static final String[] PROJECTION_29 = {"_id", "bucket_id", COLUMN_BUCKET_DISPLAY_NAME, "mime_type"};
    private static final String[] PROJECTION_PAGE = {"_id", "_data", "mime_type", "width", "height", "duration", "_size", COLUMN_BUCKET_DISPLAY_NAME, "_display_name", "bucket_id"};
    private static final Uri QUERY_URI = MediaStore.Files.getContentUri("external");
    private static final String SELECTION = "(media_type=? ) AND _size>0) GROUP BY (bucket_id";
    private static final String SELECTION_29 = "media_type=?  AND _size>0";
    private static final String[] SELECTION_ALL_ARGS = {String.valueOf(1), String.valueOf(3)};
    private static final String SELECTION_NOT_GIF = "(media_type=? AND mime_type!='image/gif' AND mime_type!='image/*') AND _size>0) GROUP BY (bucket_id";
    private static final String SELECTION_NOT_GIF_29 = "media_type=? AND mime_type!='image/gif' AND mime_type!='image/*' AND _size>0";
    private static final String SELECTION_SPECIFIED_FORMAT = "(media_type=? AND mime_type";
    private static final String SELECTION_SPECIFIED_FORMAT_29 = "media_type=? AND mime_type";
    private static final String TAG = "LocalMediaPageLoader";

    /* renamed from: a  reason: collision with root package name */
    public static final /* synthetic */ int f990a = 0;
    private static LocalMediaPageLoader instance;
    private PictureSelectionConfig config;
    private Context mContext;

    public LocalMediaPageLoader(Context context, PictureSelectionConfig pictureSelectionConfig) {
        this.mContext = context;
        this.config = pictureSelectionConfig;
    }

    private String getDurationCondition(long j2, long j3) {
        int i2 = this.config.videoMaxSecond;
        long j4 = i2 == 0 ? Long.MAX_VALUE : (long) i2;
        if (j2 != 0) {
            j4 = Math.min(j4, j2);
        }
        Locale locale = Locale.CHINA;
        Object[] objArr = new Object[3];
        objArr[0] = Long.valueOf(Math.max(j3, (long) this.config.videoMinSecond));
        objArr[1] = Math.max(j3, (long) this.config.videoMinSecond) == 0 ? "" : "=";
        objArr[2] = Long.valueOf(j4);
        return String.format(locale, "%d <%s duration and duration <= %d", objArr);
    }

    /* access modifiers changed from: private */
    public static String getFirstUri(Cursor cursor) {
        return getRealPathAndroid_Q(cursor.getLong(cursor.getColumnIndex("_id")));
    }

    /* access modifiers changed from: private */
    public static String getFirstUrl(Cursor cursor) {
        return cursor.getString(cursor.getColumnIndex("_data"));
    }

    public static LocalMediaPageLoader getInstance(Context context, PictureSelectionConfig pictureSelectionConfig) {
        if (instance == null) {
            synchronized (LocalMediaPageLoader.class) {
                if (instance == null) {
                    instance = new LocalMediaPageLoader(context.getApplicationContext(), pictureSelectionConfig);
                }
            }
        }
        return instance;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getPageSelection(long j2) {
        String durationCondition = getDurationCondition(0, 0);
        boolean z = !TextUtils.isEmpty(this.config.specifiedFormat);
        int i2 = this.config.chooseMode;
        String str = " AND mime_type!='image/gif' AND mime_type!='image/*'";
        String str2 = "";
        if (i2 != 0) {
            if (i2 != 1) {
                if (i2 != 2 && i2 != 3) {
                    return null;
                }
                if (j2 == -1) {
                    if (z) {
                        StringBuilder n = a.n("(media_type=? AND mime_type='");
                        n.append(this.config.specifiedFormat);
                        n.append("' AND ");
                        n.append(durationCondition);
                        n.append(") AND ");
                        return a.j(n, "_size", ">0");
                    }
                    return "(media_type=? AND " + durationCondition + ") AND " + "_size" + ">0";
                } else if (z) {
                    StringBuilder n2 = a.n("(media_type=? AND mime_type='");
                    n2.append(this.config.specifiedFormat);
                    n2.append("' AND ");
                    n2.append(durationCondition);
                    n2.append(") AND ");
                    return a.l(n2, "bucket_id", "=? AND ", "_size", ">0");
                } else {
                    StringBuilder sb = new StringBuilder();
                    sb.append("(media_type=? AND ");
                    sb.append(durationCondition);
                    sb.append(") AND ");
                    sb.append("bucket_id");
                    sb.append("=? AND ");
                    return a.j(sb, "_size", ">0");
                }
            } else if (j2 == -1) {
                if (z) {
                    StringBuilder n3 = a.n("(media_type=?");
                    if (!this.config.isGif) {
                        str2 = a.j(a.n(" AND mime_type!='image/gif' AND mime_type!='image/*' AND mime_type='"), this.config.specifiedFormat, "'");
                    }
                    return a.l(n3, str2, ") AND ", "_size", ">0");
                }
                StringBuilder n4 = a.n("(media_type=?");
                if (this.config.isGif) {
                    str = str2;
                }
                return a.l(n4, str, ") AND ", "_size", ">0");
            } else if (z) {
                StringBuilder n5 = a.n("(media_type=?");
                if (!this.config.isGif) {
                    str2 = a.j(a.n(" AND mime_type!='image/gif' AND mime_type!='image/*' AND mime_type='"), this.config.specifiedFormat, "'");
                }
                n5.append(str2);
                n5.append(") AND ");
                n5.append("bucket_id");
                n5.append("=? AND ");
                return a.j(n5, "_size", ">0");
            } else {
                StringBuilder n6 = a.n("(media_type=?");
                if (this.config.isGif) {
                    str = str2;
                }
                n6.append(str);
                n6.append(") AND ");
                n6.append("bucket_id");
                n6.append("=? AND ");
                return a.j(n6, "_size", ">0");
            }
        } else if (j2 == -1) {
            StringBuilder n7 = a.n("(media_type=?");
            if (this.config.isGif) {
                str = str2;
            }
            n7.append(str);
            n7.append(" OR ");
            n7.append("media_type");
            n7.append("=? AND ");
            return a.l(n7, durationCondition, ") AND ", "_size", ">0");
        } else {
            StringBuilder n8 = a.n("(media_type=?");
            if (this.config.isGif) {
                str = str2;
            }
            n8.append(str);
            n8.append(" OR ");
            n8.append("media_type");
            n8.append("=? AND ");
            n8.append(durationCondition);
            n8.append(") AND ");
            n8.append("bucket_id");
            n8.append("=? AND ");
            return a.j(n8, "_size", ">0");
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String[] getPageSelectionArgs(long j2) {
        int i2 = this.config.chooseMode;
        if (i2 != 0) {
            if (i2 == 1) {
                return getSelectionArgsForPageSingleMediaType(1, j2);
            }
            if (i2 == 2) {
                return getSelectionArgsForPageSingleMediaType(3, j2);
            }
            if (i2 != 3) {
                return null;
            }
            return getSelectionArgsForPageSingleMediaType(2, j2);
        } else if (j2 == -1) {
            return new String[]{String.valueOf(1), String.valueOf(3)};
        } else {
            return new String[]{String.valueOf(1), String.valueOf(3), ValueOf.toString(Long.valueOf(j2))};
        }
    }

    /* access modifiers changed from: private */
    public static String getRealPathAndroid_Q(long j2) {
        return QUERY_URI.buildUpon().appendPath(ValueOf.toString(Long.valueOf(j2))).build().toString();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String getSelection() {
        PictureSelectionConfig pictureSelectionConfig = this.config;
        int i2 = pictureSelectionConfig.chooseMode;
        if (i2 == 0) {
            return getSelectionArgsForAllMediaCondition(getDurationCondition(0, 0), this.config.isGif);
        }
        if (i2 != 1) {
            if (i2 != 2) {
                if (i2 != 3) {
                    return null;
                }
                if (TextUtils.isEmpty(pictureSelectionConfig.specifiedFormat)) {
                    return getSelectionArgsForSingleMediaCondition(getDurationCondition(0, 500));
                }
                if (SdkVersionUtils.checkedAndroid_Q()) {
                    return a.l(a.n("media_type=? AND mime_type='"), this.config.specifiedFormat, "' AND ", "_size", ">0");
                }
                StringBuilder n = a.n("(media_type=? AND mime_type='");
                n.append(this.config.specifiedFormat);
                n.append("') AND ");
                n.append("_size");
                n.append(">0)");
                n.append(GROUP_BY_BUCKET_Id);
                return n.toString();
            } else if (TextUtils.isEmpty(pictureSelectionConfig.specifiedFormat)) {
                return getSelectionArgsForSingleMediaCondition(getDurationCondition(0, 0));
            } else {
                if (SdkVersionUtils.checkedAndroid_Q()) {
                    return a.l(a.n("media_type=? AND mime_type='"), this.config.specifiedFormat, "' AND ", "_size", ">0");
                }
                StringBuilder n2 = a.n("(media_type=? AND mime_type='");
                n2.append(this.config.specifiedFormat);
                n2.append("') AND ");
                n2.append("_size");
                n2.append(">0)");
                n2.append(GROUP_BY_BUCKET_Id);
                return n2.toString();
            }
        } else if (TextUtils.isEmpty(pictureSelectionConfig.specifiedFormat)) {
            return SdkVersionUtils.checkedAndroid_Q() ? this.config.isGif ? SELECTION_29 : SELECTION_NOT_GIF_29 : this.config.isGif ? SELECTION : SELECTION_NOT_GIF;
        } else {
            if (SdkVersionUtils.checkedAndroid_Q()) {
                return a.l(a.n("media_type=? AND mime_type='"), this.config.specifiedFormat, "' AND ", "_size", ">0");
            }
            StringBuilder n3 = a.n("(media_type=? AND mime_type='");
            n3.append(this.config.specifiedFormat);
            n3.append("') AND ");
            n3.append("_size");
            n3.append(">0)");
            n3.append(GROUP_BY_BUCKET_Id);
            return n3.toString();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String[] getSelectionArgs() {
        int i2 = this.config.chooseMode;
        if (i2 == 0) {
            return SELECTION_ALL_ARGS;
        }
        if (i2 == 1) {
            return getSelectionArgsForSingleMediaType(1);
        }
        if (i2 == 2) {
            return getSelectionArgsForSingleMediaType(3);
        }
        if (i2 != 3) {
            return null;
        }
        return getSelectionArgsForSingleMediaType(2);
    }

    private static String getSelectionArgsForAllMediaCondition(String str, boolean z) {
        String str2 = "";
        if (SdkVersionUtils.checkedAndroid_Q()) {
            StringBuilder n = a.n("(media_type=?");
            if (!z) {
                str2 = " AND mime_type!='image/gif' AND mime_type!='image/*'";
            }
            n.append(str2);
            n.append(" OR ");
            n.append("media_type");
            n.append("=? AND ");
            return a.l(n, str, ") AND ", "_size", ">0");
        }
        StringBuilder n2 = a.n("(media_type=?");
        if (!z) {
            str2 = " AND mime_type!='image/gif' AND mime_type!='image/*'";
        }
        n2.append(str2);
        n2.append(" OR ");
        n2.append("media_type=? AND ");
        n2.append(str);
        return a.l(n2, ") AND ", "_size", ">0)", GROUP_BY_BUCKET_Id);
    }

    private static String[] getSelectionArgsForPageSingleMediaType(int i2, long j2) {
        if (j2 == -1) {
            return new String[]{String.valueOf(i2)};
        }
        return new String[]{String.valueOf(i2), ValueOf.toString(Long.valueOf(j2))};
    }

    private static String getSelectionArgsForSingleMediaCondition(String str) {
        if (SdkVersionUtils.checkedAndroid_Q()) {
            return a.g("media_type=? AND _size>0 AND ", str);
        }
        return "(media_type=?) AND _size>0 AND " + str + ")" + GROUP_BY_BUCKET_Id;
    }

    private static String[] getSelectionArgsForSingleMediaType(int i2) {
        return new String[]{String.valueOf(i2)};
    }

    public static void setInstanceNull() {
        instance = null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void sortFolder(List<LocalMediaFolder> list) {
        Collections.sort(list, b.f4270d);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:24:0x0064, code lost:
        if (r10.isClosed() == false) goto L_0x0076;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:32:0x0074, code lost:
        if (r10.isClosed() == false) goto L_0x0076;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:33:0x0076, code lost:
        r10.close();
     */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x0070  */
    public String getFirstCover(long j2) {
        Throwable th;
        Cursor cursor;
        Exception e2;
        String str;
        Cursor cursor2 = null;
        try {
            cursor = this.mContext.getContentResolver().query(QUERY_URI, new String[]{"_id", "_data"}, getPageSelection(j2), getPageSelectionArgs(j2), "_id DESC limit 1 offset 0");
            if (cursor != null) {
                try {
                    if (cursor.getCount() > 0) {
                        if (cursor.moveToFirst()) {
                            long j3 = cursor.getLong(cursor.getColumnIndexOrThrow("_id"));
                            if (SdkVersionUtils.checkedAndroid_Q()) {
                                str = getRealPathAndroid_Q(j3);
                            } else {
                                str = cursor.getString(cursor.getColumnIndexOrThrow("_data"));
                            }
                            if (!cursor.isClosed()) {
                                cursor.close();
                            }
                            return str;
                        }
                        if (!cursor.isClosed()) {
                            cursor.close();
                        }
                        return null;
                    }
                } catch (Exception e3) {
                    e2 = e3;
                    try {
                        e2.printStackTrace();
                        if (cursor != null) {
                        }
                        return null;
                    } catch (Throwable th2) {
                        th = th2;
                        cursor2 = cursor;
                        if (cursor2 != null && !cursor2.isClosed()) {
                            cursor2.close();
                        }
                        throw th;
                    }
                }
            }
            if (cursor != null) {
            }
        } catch (Exception e4) {
            e2 = e4;
            cursor = null;
            e2.printStackTrace();
            if (cursor != null) {
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            cursor2.close();
            throw th;
        }
        return null;
    }

    public void loadAllMedia(final OnQueryDataResultListener onQueryDataResultListener) {
        PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<List<LocalMediaFolder>>() {
            /* class com.luck.picture.lib.model.LocalMediaPageLoader.AnonymousClass2 */

            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public List<LocalMediaFolder> doInBackground() {
                int i2;
                String str;
                long j2;
                Cursor query = LocalMediaPageLoader.this.mContext.getContentResolver().query(LocalMediaPageLoader.QUERY_URI, SdkVersionUtils.checkedAndroid_Q() ? LocalMediaPageLoader.PROJECTION_29 : LocalMediaPageLoader.PROJECTION, LocalMediaPageLoader.this.getSelection(), LocalMediaPageLoader.this.getSelectionArgs(), LocalMediaPageLoader.ORDER_BY);
                if (query != null) {
                    try {
                        int count = query.getCount();
                        ArrayList arrayList = new ArrayList();
                        if (count > 0) {
                            if (SdkVersionUtils.checkedAndroid_Q()) {
                                HashMap hashMap = new HashMap();
                                while (query.moveToNext()) {
                                    long j3 = query.getLong(query.getColumnIndex("bucket_id"));
                                    Long l = (Long) hashMap.get(Long.valueOf(j3));
                                    if (l == null) {
                                        j2 = 1L;
                                    } else {
                                        j2 = Long.valueOf(l.longValue() + 1);
                                    }
                                    hashMap.put(Long.valueOf(j3), j2);
                                }
                                if (query.moveToFirst()) {
                                    HashSet hashSet = new HashSet();
                                    i2 = 0;
                                    do {
                                        long j4 = query.getLong(query.getColumnIndex("bucket_id"));
                                        if (!hashSet.contains(Long.valueOf(j4))) {
                                            LocalMediaFolder localMediaFolder = new LocalMediaFolder();
                                            localMediaFolder.setBucketId(j4);
                                            String string = query.getString(query.getColumnIndex(LocalMediaPageLoader.COLUMN_BUCKET_DISPLAY_NAME));
                                            long longValue = ((Long) hashMap.get(Long.valueOf(j4))).longValue();
                                            long j5 = query.getLong(query.getColumnIndex("_id"));
                                            localMediaFolder.setName(string);
                                            localMediaFolder.setImageNum(ValueOf.toInt(Long.valueOf(longValue)));
                                            localMediaFolder.setFirstImagePath(LocalMediaPageLoader.getRealPathAndroid_Q(j5));
                                            arrayList.add(localMediaFolder);
                                            hashSet.add(Long.valueOf(j4));
                                            i2 = (int) (((long) i2) + longValue);
                                        }
                                    } while (query.moveToNext());
                                } else {
                                    i2 = 0;
                                }
                            } else {
                                query.moveToFirst();
                                int i3 = 0;
                                do {
                                    LocalMediaFolder localMediaFolder2 = new LocalMediaFolder();
                                    long j6 = query.getLong(query.getColumnIndex("bucket_id"));
                                    String string2 = query.getString(query.getColumnIndex(LocalMediaPageLoader.COLUMN_BUCKET_DISPLAY_NAME));
                                    int i4 = query.getInt(query.getColumnIndex("count"));
                                    localMediaFolder2.setBucketId(j6);
                                    localMediaFolder2.setFirstImagePath(query.getString(query.getColumnIndex("_data")));
                                    localMediaFolder2.setName(string2);
                                    localMediaFolder2.setImageNum(i4);
                                    arrayList.add(localMediaFolder2);
                                    i3 += i4;
                                } while (query.moveToNext());
                                i2 = i3;
                            }
                            LocalMediaPageLoader.this.sortFolder(arrayList);
                            LocalMediaFolder localMediaFolder3 = new LocalMediaFolder();
                            localMediaFolder3.setImageNum(i2);
                            localMediaFolder3.setChecked(true);
                            localMediaFolder3.setBucketId(-1);
                            if (query.moveToFirst()) {
                                localMediaFolder3.setFirstImagePath(SdkVersionUtils.checkedAndroid_Q() ? LocalMediaPageLoader.getFirstUri(query) : LocalMediaPageLoader.getFirstUrl(query));
                            }
                            if (LocalMediaPageLoader.this.config.chooseMode == PictureMimeType.ofAudio()) {
                                str = LocalMediaPageLoader.this.mContext.getString(R.string.picture_all_audio);
                            } else {
                                str = LocalMediaPageLoader.this.mContext.getString(R.string.picture_camera_roll);
                            }
                            localMediaFolder3.setName(str);
                            localMediaFolder3.setOfAllType(LocalMediaPageLoader.this.config.chooseMode);
                            localMediaFolder3.setCameraFolder(true);
                            arrayList.add(0, localMediaFolder3);
                            if (!query.isClosed()) {
                                query.close();
                            }
                            return arrayList;
                        }
                    } catch (Exception e2) {
                        e2.printStackTrace();
                        String str2 = LocalMediaPageLoader.TAG;
                        Log.i(str2, "loadAllMedia Data Error: " + e2.getMessage());
                        if (!query.isClosed()) {
                            query.close();
                        }
                        return null;
                    } catch (Throwable th) {
                        if (!query.isClosed()) {
                            query.close();
                        }
                        throw th;
                    }
                }
                if (query != null && !query.isClosed()) {
                    query.close();
                }
                return new ArrayList();
            }

            public void onSuccess(List<LocalMediaFolder> list) {
                OnQueryDataResultListener onQueryDataResultListener = onQueryDataResultListener;
                if (onQueryDataResultListener != null && list != null) {
                    onQueryDataResultListener.onComplete(list, 1, false);
                }
            }
        });
    }

    public void loadPageMediaData(long j2, int i2, int i3, OnQueryDataResultListener onQueryDataResultListener) {
        loadPageMediaData(j2, i2, i3, this.config.pageSize, onQueryDataResultListener);
    }

    public void loadPageMediaData(long j2, int i2, OnQueryDataResultListener onQueryDataResultListener) {
        int i3 = this.config.pageSize;
        loadPageMediaData(j2, i2, i3, i3, onQueryDataResultListener);
    }

    public void loadPageMediaData(final long j2, final int i2, final int i3, final int i4, final OnQueryDataResultListener onQueryDataResultListener) {
        PictureThreadUtils.executeByIo(new PictureThreadUtils.SimpleTask<MediaData>() {
            /* class com.luck.picture.lib.model.LocalMediaPageLoader.AnonymousClass1 */

            @Override // com.luck.picture.lib.thread.PictureThreadUtils.Task
            public MediaData doInBackground() {
                Throwable th;
                Cursor cursor;
                Exception e2;
                String str;
                Cursor cursor2 = null;
                try {
                    char c2 = 1;
                    if (i2 == -1) {
                        str = LocalMediaPageLoader.ORDER_BY;
                    } else {
                        str = "_id DESC limit " + i3 + " offset " + ((i2 - 1) * i4);
                    }
                    cursor = LocalMediaPageLoader.this.mContext.getContentResolver().query(LocalMediaPageLoader.QUERY_URI, LocalMediaPageLoader.PROJECTION_PAGE, LocalMediaPageLoader.this.getPageSelection(j2), LocalMediaPageLoader.this.getPageSelectionArgs(j2), str);
                    if (cursor != null) {
                        try {
                            ArrayList arrayList = new ArrayList();
                            char c3 = 0;
                            if (cursor.getCount() > 0) {
                                cursor.moveToFirst();
                                while (true) {
                                    long j2 = cursor.getLong(cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[c3]));
                                    String string = cursor.getString(cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[c2]));
                                    String realPathAndroid_Q = SdkVersionUtils.checkedAndroid_Q() ? LocalMediaPageLoader.getRealPathAndroid_Q(j2) : string;
                                    if (!LocalMediaPageLoader.this.config.isFilterInvalidFile || PictureFileUtils.isFileExists(string)) {
                                        String string2 = cursor.getString(cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[2]));
                                        if (TextUtils.isEmpty(string2)) {
                                            string2 = PictureMimeType.ofJPEG();
                                        }
                                        if (string2.endsWith("image/*")) {
                                            if (PictureMimeType.isContent(realPathAndroid_Q)) {
                                                string2 = PictureMimeType.getImageMimeType(string);
                                            } else {
                                                string2 = PictureMimeType.getImageMimeType(realPathAndroid_Q);
                                            }
                                            if (!LocalMediaPageLoader.this.config.isGif && PictureMimeType.isGif(string2)) {
                                            }
                                        }
                                        int i2 = cursor.getInt(cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[3]));
                                        int i3 = cursor.getInt(cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[4]));
                                        long j3 = cursor.getLong(cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[5]));
                                        long j4 = cursor.getLong(cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[6]));
                                        String string3 = cursor.getString(cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[7]));
                                        String string4 = cursor.getString(cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[8]));
                                        long j5 = cursor.getLong(cursor.getColumnIndexOrThrow(LocalMediaPageLoader.PROJECTION_PAGE[9]));
                                        if (LocalMediaPageLoader.this.config.filterFileSize <= 0.0f || ((float) j4) <= LocalMediaPageLoader.this.config.filterFileSize * 1048576.0f) {
                                            if (PictureMimeType.isHasVideo(string2)) {
                                                if (LocalMediaPageLoader.this.config.videoMinSecond <= 0 || j3 >= ((long) LocalMediaPageLoader.this.config.videoMinSecond)) {
                                                    if (LocalMediaPageLoader.this.config.videoMaxSecond <= 0 || j3 <= ((long) LocalMediaPageLoader.this.config.videoMaxSecond)) {
                                                        if (j3 != 0) {
                                                            if (j4 <= 0) {
                                                            }
                                                        }
                                                    }
                                                }
                                            }
                                            arrayList.add(new LocalMedia(j2, realPathAndroid_Q, string, string4, string3, j3, LocalMediaPageLoader.this.config.chooseMode, string2, i2, i3, j4, j5));
                                        }
                                    }
                                    if (!cursor.moveToNext()) {
                                        break;
                                    }
                                    c2 = 1;
                                    c3 = 0;
                                }
                            }
                            MediaData mediaData = new MediaData(cursor.getCount() > 0, arrayList);
                            if (!cursor.isClosed()) {
                                cursor.close();
                            }
                            return mediaData;
                        } catch (Exception e3) {
                            e2 = e3;
                            try {
                                e2.printStackTrace();
                                Log.i(LocalMediaPageLoader.TAG, "loadMedia Page Data Error: " + e2.getMessage());
                                if (cursor != null && !cursor.isClosed()) {
                                    cursor.close();
                                }
                                return null;
                            } catch (Throwable th2) {
                                th = th2;
                                cursor2 = cursor;
                                cursor2.close();
                                throw th;
                            }
                        }
                    } else {
                        if (cursor != null && !cursor.isClosed()) {
                            cursor.close();
                        }
                        return null;
                    }
                } catch (Exception e4) {
                    e2 = e4;
                    cursor = null;
                    e2.printStackTrace();
                    Log.i(LocalMediaPageLoader.TAG, "loadMedia Page Data Error: " + e2.getMessage());
                    cursor.close();
                    return null;
                } catch (Throwable th3) {
                    th = th3;
                    if (cursor2 != null && !cursor2.isClosed()) {
                        cursor2.close();
                    }
                    throw th;
                }
            }

            public void onSuccess(MediaData mediaData) {
                OnQueryDataResultListener onQueryDataResultListener = onQueryDataResultListener;
                if (onQueryDataResultListener != null && mediaData != null) {
                    onQueryDataResultListener.onComplete(mediaData.data, i2, mediaData.isHasNextMore);
                }
            }
        });
    }
}
