package kotlin;

import kotlin.Result;
import kotlin.jvm.functions.Function0;
import kotlin.jvm.functions.Function1;
import kotlin.jvm.internal.Intrinsics;

public final class ResultKt {
    public static final Object createFailure(Throwable th) {
        Intrinsics.checkParameterIsNotNull(th, "exception");
        return new Result.Failure(th);
    }

    public static final void throwOnFailure(Object obj) {
        if (obj instanceof Result.Failure) {
            throw ((Result.Failure) obj).exception;
        }
    }

    private static final <R> Object runCatching(Function0<? extends R> function0) {
        try {
            Result.Companion companion = Result.Companion;
            return Result.m5constructorimpl(function0.invoke());
        } catch (Throwable th) {
            Result.Companion companion2 = Result.Companion;
            return Result.m5constructorimpl(createFailure(th));
        }
    }

    private static final <T, R> Object runCatching(T t, Function1<? super T, ? extends R> function1) {
        try {
            Result.Companion companion = Result.Companion;
            return Result.m5constructorimpl(function1.invoke(t));
        } catch (Throwable th) {
            Result.Companion companion2 = Result.Companion;
            return Result.m5constructorimpl(createFailure(th));
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r0v0, resolved type: java.lang.Object */
    /* JADX WARN: Multi-variable type inference failed */
    private static final <T> T getOrThrow(Object obj) {
        throwOnFailure(obj);
        return obj;
    }

    /* JADX DEBUG: Multi-variable search result rejected for r1v0, resolved type: java.lang.Object */
    /* JADX WARN: Multi-variable type inference failed */
    private static final <R, T extends R> R getOrElse(Object obj, Function1<? super Throwable, ? extends R> function1) {
        Throwable r0 = Result.m8exceptionOrNullimpl(obj);
        return r0 == null ? obj : (R) function1.invoke(r0);
    }

    /* JADX DEBUG: Multi-variable search result rejected for r1v0, resolved type: java.lang.Object */
    /* JADX WARN: Multi-variable type inference failed */
    private static final <R, T extends R> R getOrDefault(Object obj, R r) {
        return Result.m11isFailureimpl(obj) ? r : obj;
    }

    private static final <R, T> R fold(Object obj, Function1<? super T, ? extends R> function1, Function1<? super Throwable, ? extends R> function12) {
        Throwable r0 = Result.m8exceptionOrNullimpl(obj);
        return r0 == null ? (R) function1.invoke(obj) : (R) function12.invoke(r0);
    }

    private static final <R, T> Object map(Object obj, Function1<? super T, ? extends R> function1) {
        if (!Result.m12isSuccessimpl(obj)) {
            return Result.m5constructorimpl(obj);
        }
        Result.Companion companion = Result.Companion;
        return Result.m5constructorimpl(function1.invoke(obj));
    }

    private static final <R, T> Object mapCatching(Object obj, Function1<? super T, ? extends R> function1) {
        if (!Result.m12isSuccessimpl(obj)) {
            return Result.m5constructorimpl(obj);
        }
        try {
            Result.Companion companion = Result.Companion;
            return Result.m5constructorimpl(function1.invoke(obj));
        } catch (Throwable th) {
            Result.Companion companion2 = Result.Companion;
            return Result.m5constructorimpl(createFailure(th));
        }
    }

    private static final <R, T extends R> Object recover(Object obj, Function1<? super Throwable, ? extends R> function1) {
        Throwable r0 = Result.m8exceptionOrNullimpl(obj);
        if (r0 == null) {
            return obj;
        }
        Result.Companion companion = Result.Companion;
        return Result.m5constructorimpl(function1.invoke(r0));
    }

    private static final <R, T extends R> Object recoverCatching(Object obj, Function1<? super Throwable, ? extends R> function1) {
        Throwable r0 = Result.m8exceptionOrNullimpl(obj);
        if (r0 == null) {
            return obj;
        }
        try {
            Result.Companion companion = Result.Companion;
            return Result.m5constructorimpl(function1.invoke(r0));
        } catch (Throwable th) {
            Result.Companion companion2 = Result.Companion;
            return Result.m5constructorimpl(createFailure(th));
        }
    }

    private static final <T> Object onFailure(Object obj, Function1<? super Throwable, Unit> function1) {
        Throwable r0 = Result.m8exceptionOrNullimpl(obj);
        if (r0 != null) {
            function1.invoke(r0);
        }
        return obj;
    }

    private static final <T> Object onSuccess(Object obj, Function1<? super T, Unit> function1) {
        if (Result.m12isSuccessimpl(obj)) {
            function1.invoke(obj);
        }
        return obj;
    }
}
