package kotlin.time;

import java.util.concurrent.TimeUnit;
import kotlin.jvm.internal.DefaultConstructorMarker;
import kotlin.jvm.internal.Intrinsics;

public abstract class AbstractLongClock implements Clock {
    private final TimeUnit unit;

    /* access modifiers changed from: protected */
    public abstract long read();

    public AbstractLongClock(TimeUnit timeUnit) {
        Intrinsics.checkParameterIsNotNull(timeUnit, "unit");
        this.unit = timeUnit;
    }

    /* access modifiers changed from: protected */
    public final TimeUnit getUnit() {
        return this.unit;
    }

    private static final class LongClockMark extends ClockMark {
        private final AbstractLongClock clock;
        private final double offset;
        private final long startedAt;

        private LongClockMark(long j, AbstractLongClock abstractLongClock, double d) {
            this.startedAt = j;
            this.clock = abstractLongClock;
            this.offset = d;
        }

        public /* synthetic */ LongClockMark(long j, AbstractLongClock abstractLongClock, double d, DefaultConstructorMarker defaultConstructorMarker) {
            this(j, abstractLongClock, d);
        }

        @Override // kotlin.time.ClockMark
        public double elapsedNow() {
            return Duration.m953minusLRDsOJo(DurationKt.toDuration(this.clock.read() - this.startedAt, this.clock.getUnit()), this.offset);
        }

        @Override // kotlin.time.ClockMark
        /* renamed from: plus-LRDsOJo  reason: not valid java name */
        public ClockMark m924plusLRDsOJo(double d) {
            return new LongClockMark(this.startedAt, this.clock, Duration.m954plusLRDsOJo(this.offset, d), null);
        }
    }

    @Override // kotlin.time.Clock
    public ClockMark markNow() {
        return new LongClockMark(read(), this, Duration.Companion.getZERO(), null);
    }
}
